@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -24,6 +24,11 @@
 
 include("./include/global.php");
 
+/* find out if we are logged in as a 'guest user' or not, if we are redirect away from password change */
+if (db_fetch_cell("select id from user_auth where username='" . read_config_option("guest_user") . "'") == $_SESSION["sess_user_id"]) {
+	header("Location: index.php");
+}
+
 $user = db_fetch_row("select * from user_auth where id=" . $_SESSION["sess_user_id"]);
 
 /* default to !bad_password */
@@ -49,11 +54,13 @@ case 'changepassword':
 		if (sizeof(db_fetch_assoc("select user_auth_realm.realm_id from user_auth_realm where user_auth_realm.user_id = '" . $_SESSION["sess_user_id"] . "' and user_auth_realm.realm_id = '" . $realm_id . "'")) > 0) {
 			switch ($user["login_opts"]) {
 				case '1': /* referer */
-					header("Location: " . $_POST["ref"]); break;
+					header("Location: " . sanitize_uri($_POST["ref"])); break;
 				case '2': /* default console page */
 					header("Location: index.php"); break;
 				case '3': /* default graph page */
 					header("Location: graph_view.php"); break;
+				default:
+					api_plugin_hook_function('login_options_navigate', $user['login_opts']);
 			}
 		}else{
 			header("Location: graph_view.php");
@@ -66,10 +73,17 @@ case 'changepassword':
 
 	break;
 }
+
+if (api_plugin_hook_function('custom_password', OPER_MODE_NATIVE) == OPER_MODE_RESKIN) {
+	exit;
+}
+
 ?>
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <head>
 	<title>Login to cacti</title>
+	<meta http-equiv="Content-Type" content="text/html;charset=utf-8">
 	<STYLE TYPE="text/css">
 	<!--
 		BODY, TABLE, TR, TD {font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 12px;}
@@ -90,19 +104,19 @@ case 'changepassword':
 		<td colspan="2"><img src="images/auth_login.gif" border="0" alt=""></td>
 	</tr>
 	<?php if ($bad_password == true) {?>
-	<tr height="10"><td></td></tr>
+	<tr style="height:10px;"><td></td></tr>
 	<tr>
 		<td colspan="2"><font color="#FF0000"><strong>Your passwords do not match, please retype:</strong></font></td>
 	</tr>
 	<?php }?>
-	<tr height="10"><td></td></tr>
+	<tr style="height:10px;"><td></td></tr>
 	<tr>
 		<td colspan="2">
 			<strong><font color="#FF0000">*** Forced Password Change ***</font></strong><br><br>
 			Please enter a new password for cacti:
 		</td>
 	</tr>
-	<tr height="10"><td></td></tr>
+	<tr style="height:10px;"><td></td></tr>
 	<tr>
 		<td>Password:</td>
 		<td><input type="password" name="password" size="40"></td>
@@ -111,14 +125,14 @@ case 'changepassword':
 		<td>Confirm:</td>
 		<td><input type="password" name="confirm" size="40"></td>
 	</tr>
-	<tr height="10"><td></td></tr>
+	<tr style="height:10px;"><td></td></tr>
 	<tr>
 		<td><input type="submit" value="Save"></td>
 	</tr>
 </table>
 
 <input type="hidden" name="action" value="changepassword">
-<input type="hidden" name="ref" value="<?php print $_REQUEST["ref"];?>">
+<input type="hidden" name="ref" value="<?php print (isset($_REQUEST["ref"]) ? sanitize_uri($_REQUEST["ref"]) : '');?>">
 
 </form>
 
