@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,6 +22,37 @@
  +-------------------------------------------------------------------------+
 */
 
+/* tick use required as of PHP 4.3.0 to accomodate signal handling */
+declare(ticks = 1);
+
+function sig_handler($signo) {
+	switch ($signo) {
+		case SIGTERM:
+		case SIGINT:
+			cacti_log("WARNING: Cacti Poller process terminated by user", TRUE);
+
+			/* record the process as having completed */
+			record_cmdphp_done();
+
+			exit;
+			break;
+		default:
+			/* ignore all other signals */
+	}
+}
+
+/* let the poller server know about cmd.php being finished */
+function record_cmdphp_done($pid = "") {
+	if ($pid == "") $pid = getmypid();
+
+	db_execute("UPDATE poller_time SET end_time=NOW() WHERE pid=" . $pid);
+}
+
+/* let cacti processes know that a poller has started */
+function record_cmdphp_started() {
+	db_execute("INSERT INTO poller_time (poller_id, pid, start_time, end_time) VALUES (0, " . getmypid() . ", NOW(), '0000-00-00 00:00:00')");
+}
+
 /* do NOT run this script through a web browser */
 if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
 	die("<br><strong>This script is only meant to run at the command line.</strong>");
@@ -30,7 +61,7 @@ if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($
 $start = date("Y-n-d H:i:s"); // for runtime measurement
 
 ini_set("max_execution_time", "0");
-ini_set("memory_limit", "64M");
+ini_set("memory_limit", "512M");
 
 $no_http_headers = true;
 
@@ -39,6 +70,10 @@ include_once($config["base_path"] . "/lib/snmp.php");
 include_once($config["base_path"] . "/lib/poller.php");
 include_once($config["base_path"] . "/lib/rrd.php");
 include_once($config["base_path"] . "/lib/ping.php");
+include_once($config["library_path"] . "/variables.php");
+
+/* notify cacti processes that a poller is running */
+record_cmdphp_started();
 
 /* correct for a windows PHP bug. fixed in 5.2.0 */
 if ($config["cacti_server_os"] == "win32") {
@@ -56,8 +91,14 @@ if ($config["cacti_server_os"] == "win32") {
 	}
 }
 
+/* install signal handlers for UNIX only */
+if (function_exists("pcntl_signal")) {
+	pcntl_signal(SIGTERM, "sig_handler");
+	pcntl_signal(SIGINT, "sig_handler");
+}
+
 /* record the start time */
-list($micro,$seconds) = split(" ", microtime());
+list($micro,$seconds) = explode(" ", microtime());
 $start = $seconds + $micro;
 
 /* initialize the polling items */
@@ -84,7 +125,7 @@ if ( $_SERVER["argc"] == 1 ) {
 	$hosts = array_rekey($hosts, "id", $host_struc);
 
 	$host_count = sizeof($hosts);
-	$script_server_calls = db_fetch_cell("SELECT count(*) from poller_item WHERE action=2");
+	$script_server_calls = db_fetch_cell("SELECT count(*) from poller_item WHERE action IN (" . POLLER_ACTION_SCRIPT_PHP . "," . POLLER_ACTION_SCRIPT_PHP_COUNT . ")");
 
 	/* setup next polling interval */
 	if (isset($polling_interval)) {
@@ -140,7 +181,7 @@ if ( $_SERVER["argc"] == 1 ) {
 						$_SERVER["argv"][2] . ") ORDER by host_id");
 
 				$script_server_calls = db_fetch_cell("SELECT count(*) from poller_item " .
-						"WHERE (action=2 AND (host_id >= " .
+						"WHERE (action IN (" . POLLER_ACTION_SCRIPT_PHP . "," . POLLER_ACTION_SCRIPT_PHP_COUNT . ") AND (host_id >= " .
 						$_SERVER["argv"][1] .
 						" and host_id <= " .
 						$_SERVER["argv"][2] . "))");
@@ -192,7 +233,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 			$using_proc_function = true;
 		}else {
 			$using_proc_function = false;
-			if (read_config_option("log_verbosity") == POLLER_VERBOSITY_DEBUG) {
+			if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
 				cacti_log("WARNING: PHP version 4.3 or above is recommended for performance considerations.",$print_data_to_stdout);
 			}
 		}
@@ -244,7 +285,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 					where poller_reindex.host_id=" . $item["host_id"]);
 
 				if ((sizeof($reindex) > 0) && (!$host_down)) {
-					if (read_config_option("log_verbosity") == POLLER_VERBOSITY_DEBUG) {
+					if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
 						cacti_log("Host[$host_id] RECACHE: Processing " . sizeof($reindex) . " items in the auto reindex cache for '" . $item["hostname"] . "'.",$print_data_to_stdout);
 					}
 
@@ -253,18 +294,156 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 
 						/* do the check */
 						switch ($index_item["action"]) {
+
 						case POLLER_ACTION_SNMP: /* snmp */
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] OID: " . $index_item["arg1"], $print_data_to_stdout);
+							}
 							$output = cacti_snmp_get($item["hostname"], $item["snmp_community"], $index_item["arg1"],
 								$item["snmp_version"], $item["snmp_username"], $item["snmp_password"],
 								$item["snmp_auth_protocol"], $item["snmp_priv_passphrase"], $item["snmp_priv_protocol"],
 								$item["snmp_context"], $item["snmp_port"], $item["snmp_timeout"], read_config_option("snmp_retries"), SNMP_CMDPHP);
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] OID: " . $index_item["arg1"] . ", output: " . $output, $print_data_to_stdout);
+							}
+
 							break;
+
 						case POLLER_ACTION_SCRIPT: /* script (popen) */
-							$output = exec_poll($index_item["arg1"]);
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Script: " . $index_item["arg1"], $print_data_to_stdout);
+							}
+							$output = trim(exec_poll($index_item["arg1"]));
+
+							/* remove any quotes from string */
+							$output = strip_quotes($output);
+
+							if (!validate_result($output)) {
+								if (strlen($output) > 20) {
+									$strout = 20;
+								} else {
+									$strout = strlen($output);
+								}
+
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Warning: Result from Script not valid. Partial Result: " . substr($output, 0, $strout), $print_data_to_stdout);
+							}
+
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Script: " . $index_item["arg1"] . ", output: $output",$print_data_to_stdout);
+							}
 							break;
+
+						case POLLER_ACTION_SCRIPT_PHP: /* script (php script server) */
+							if ($using_proc_function == true) {
+								if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
+									cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Script Server: " . $index_item["arg1"], $print_data_to_stdout);
+								}
+
+								$output = trim(str_replace("\n", "", exec_poll_php($index_item["arg1"], $using_proc_function, $pipes, $cactiphp)));
+
+								/* remove any quotes from string */
+								$output = strip_quotes($output);
+
+								if (!validate_result($output)) {
+									if (strlen($output) > 20) {
+										$strout = 20;
+									} else {
+										$strout = strlen($output);
+									}
+
+									cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] WARNING: Result from Script Server not valid. Partial Result: " . substr($output, 0, $strout), $print_data_to_stdout);
+								}
+
+								if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
+									cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Script Server: " . $index_item["arg1"] . ", output: $output", $print_data_to_stdout);
+								}
+							}else{
+								if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
+									cacti_log("Host[$host_id] DS[$data_source] *SKIPPING* Script Server: " . $item["arg1"] . " (PHP < 4.3)", $print_data_to_stdout);
+								}
+
+								$output = "U";
+							}
+
+							break;
+						case POLLER_ACTION_SNMP_COUNT: /* snmp; count items */
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] OID Count: " . $index_item["arg1"], $print_data_to_stdout);
+							}
+							$output = sizeof(cacti_snmp_walk($item["hostname"], $item["snmp_community"], $index_item["arg1"],
+								$item["snmp_version"], $item["snmp_username"], $item["snmp_password"],
+								$item["snmp_auth_protocol"], $item["snmp_priv_passphrase"], $item["snmp_priv_protocol"],
+								$item["snmp_context"], $item["snmp_port"], $item["snmp_timeout"], read_config_option("snmp_retries"), SNMP_CMDPHP));
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] OID Count: " . $index_item["arg1"] . ", output: " . $output, $print_data_to_stdout);
+							}
+
+							break;
+						case POLLER_ACTION_SCRIPT_COUNT: /* script (popen); count items */
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Script Count: " . $index_item["arg1"], $print_data_to_stdout);
+							}
+							/* count items found */
+							$script_index_array = exec_into_array($index_item["arg1"]);
+							$output = sizeof($script_index_array);
+
+							if (!validate_result($output)) {
+								if (strlen($output) > 20) {
+									$strout = 20;
+								} else {
+									$strout = strlen($output);
+								}
+
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Warning: Result from Script not valid. Partial Result: " . substr($output, 0, $strout), $print_data_to_stdout);
+							}
+
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
+								cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Script Count: " . $index_item["arg1"] . ", output: $output",$print_data_to_stdout);
+							}
+							break;
+
+						case POLLER_ACTION_SCRIPT_PHP_COUNT: /* script (php script server); count items */
+							if ($using_proc_function == true) {
+								if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
+									cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Script Server Count: " . $index_item["arg1"], $print_data_to_stdout);
+								}
+
+								/* fetch specified index */
+								$output = 'U'; # TODO compatibility until option is correctly implemented
+								cacti_log("Host[$host_id] DS[$data_source] *SKIPPING* Script Server Count: " . $item["arg1"] . " (arg_num_indexes required)", $print_data_to_stdout);
+								# TODO $output = sizeof(exec_poll_php($index_item["arg1"], $using_proc_function, $pipes, $cactiphp));
+								/* remove any quotes from string */
+								#$output = strip_quotes($output);
+
+								#if (!validate_result($output)) {
+								#	if (strlen($output) > 20) {
+								#		$strout = 20;
+								#	} else {
+								#		$strout = strlen($output);
+								#	}
+
+								#	cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] WARNING: Result from Script Server not valid. Partial Result: " . substr($output, 0, $strout), $print_data_to_stdout);
+								#}
+
+								#if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
+								#	cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] Script Server Count: " . $index_item["arg1"] . ", output: $output", $print_data_to_stdout);
+								#}
+							}else{
+								if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
+									cacti_log("Host[$host_id] DS[$data_source] *SKIPPING* Script Server: " . $item["arg1"] . " (PHP < 4.3)", $print_data_to_stdout);
+								}
+
+								$output = "U";
+							}
+
+							break;
+						default: /* invalid reindex option */
+							cacti_log("Host[$host_id] RECACHE DQ[" . $index_item["data_query_id"] . "] ERROR: Invalid reindex option: " . $index_item["action"], $print_data_to_stdout);
 						}
 
+
 						/* assert the result with the expected value in the db; recache if the assert fails */
+						/* TODO: remove magic ":" from poller_command["command"]; this may interfere with scripts */
 						if (($index_item["op"] == "=") && ($index_item["assert_value"] != trim($output))) {
 							cacti_log("ASSERT: '" . $index_item["assert_value"] . "=" . trim($output) . "' failed. Recaching host '" . $item["hostname"] . "', data query #" . $index_item["data_query_id"], $print_data_to_stdout);
 							db_execute("replace into poller_command (poller_id, time, action, command) values (0, NOW(), " . POLLER_COMMAND_REINDEX . ", '" . $item["host_id"] . ":" . $index_item["data_query_id"] . "')");
@@ -293,7 +472,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 								if (!empty($output)) {
 									$set_spike_kill = true;
 
-									if (read_config_option("log_verbosity") == POLLER_VERBOSITY_DEBUG) {
+									if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG) {
 										cacti_log("Host[$host_id] NOTICE: Spike Kill in Effect for '" . $item["hostname"] . "'.", $print_data_to_stdout);
 									}
 								}
@@ -353,7 +532,6 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 					}
 
 					cacti_log("Host[$host_id] DS[$data_source] WARNING: Result from CMD not valid.  Partial Result: " . substr($output, 0, $strout), $print_data_to_stdout);
-					$output = "U";
 				}
 
 				if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
@@ -376,7 +554,6 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 						}
 
 						cacti_log("Host[$host_id] DS[$data_source] WARNING: Result from SERVER not valid.  Partial Result: " . substr($output, 0, $strout), $print_data_to_stdout);
-						$output = "U";
 					}
 
 					if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM) {
@@ -391,6 +568,8 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 				}
 
 				break;
+			default: /* invalid polling option */
+				cacti_log("Host[$host_id] DS[$data_source] ERROR: Invalid polling option: " . $item["action"], $stdout);
 			} /* End Switch */
 
 			if (isset($output)) {
@@ -417,7 +596,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 
 	if (($print_data_to_stdout) || (read_config_option("log_verbosity") >= POLLER_VERBOSITY_MEDIUM)) {
 		/* take time and log performance data */
-		list($micro,$seconds) = split(" ", microtime());
+		list($micro,$seconds) = explode(" ", microtime());
 		$end = $seconds + $micro;
 
 		cacti_log(sprintf("Time: %01.4f s, " .
@@ -433,9 +612,4 @@ if ((sizeof($polling_items) > 0) && (read_config_option("poller_enabled") == "on
 /* record the process as having completed */
 record_cmdphp_done();
 
-function record_cmdphp_done() {
-	/* let the poller server know about cmd.php being finished */
-	db_execute("insert into poller_time (poller_id, start_time, end_time) values (0, NOW(), NOW())");
-}
-
 ?>
