@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -33,7 +33,6 @@ define("MAX_DISPLAY_PAGES", 21);
 
 /* set default action */
 if (!isset($_REQUEST["action"])) { $_REQUEST["action"] = ""; }
-
 switch ($_REQUEST["action"]) {
 	case 'save':
 		form_save();
@@ -112,6 +111,11 @@ function draw_edit_form_row($field_array, $field_name, $previous_value) {
    ------------------- */
 
 function host_reload_query() {
+	/* ================= input validation ================= */
+	input_validate_input_number(get_request_var("id"));
+	input_validate_input_number(get_request_var("host_id"));
+	/* ==================================================== */
+
 	run_data_query($_GET["host_id"], $_GET["id"]);
 }
 
@@ -197,6 +201,15 @@ function host_new_graphs_save() {
 				$return_array = create_complete_graph_from_template($graph_template_id, $_POST["host_id"], "", $values["cg"]);
 
 				debug_log_insert("new_graphs", "Created graph: " . get_graph_title($return_array["local_graph_id"]));
+
+				/* lastly push host-specific information to our data sources */
+				if (sizeof($return_array["local_data_id"])) { # we expect at least one data source associated
+					foreach($return_array["local_data_id"] as $item) {
+						push_out_host($_POST["host_id"], $item);
+					}
+				} else {
+					debug_log_insert("new_graphs", "ERROR: no Data Source associated. Check Template");
+				}
 			}elseif ($current_form_type == "sg") {
 				while (list($snmp_index, $true) = each($snmp_index_array)) {
 					$snmp_query_array["snmp_index"] = decode_data_query_index($snmp_index, $snmp_query_array["snmp_query_id"], $_POST["host_id"]);
@@ -204,13 +217,19 @@ function host_new_graphs_save() {
 					$return_array = create_complete_graph_from_template($graph_template_id, $_POST["host_id"], $snmp_query_array, $values["sg"]{$snmp_query_array["snmp_query_id"]});
 
 					debug_log_insert("new_graphs", "Created graph: " . get_graph_title($return_array["local_graph_id"]));
+
+					/* lastly push host-specific information to our data sources */
+					if (sizeof($return_array["local_data_id"])) { # we expect at least one data source associated
+						foreach($return_array["local_data_id"] as $item) {
+							push_out_host($_POST["host_id"], $item);
+						}
+					} else {
+						debug_log_insert("new_graphs", "ERROR: no Data Source associated. Check Template");
+					}
 				}
 			}
 		}
 	}
-
-	/* lastly push host-specific information to our data sources */
-	push_out_host($_POST["host_id"],0);
 }
 
 function host_new_graphs($host_id, $host_template_id, $selected_graphs_array) {
@@ -332,19 +351,16 @@ function host_new_graphs($host_id, $host_template_id, $selected_graphs_array) {
 	form_hidden_box("save_component_new_graphs", "1", "");
 	print "<input type='hidden' name='selected_graphs_array' value='" . serialize($selected_graphs_array) . "'>\n";
 
-	form_save_button("graphs_new.php?host_id=$host_id");
+	if (!substr_count($_SERVER["HTTP_REFERER"], "graphs_new")) {
+		$_REQUEST["returnto"] = basename($_SERVER["HTTP_REFERER"]);
+	}
+	load_current_session_value("returnto", "sess_graphs_new_returnto", "");
+
+	form_save_button($_REQUEST["returnto"]);
 
 	include_once("./include/bottom_footer.php");
 }
 
-function check_changed($request, $session) {
-	if ((isset($_REQUEST[$request])) && (isset($_SESSION[$session]))) {
-		if ($_REQUEST[$request] != $_SESSION[$session]) {
-			return 1;
-		}
-	}
-}
-
 /* -------------------
     Graph Functions
    ------------------- */
@@ -357,18 +373,19 @@ function graphs() {
 	input_validate_input_number(get_request_var_request("graph_type"));
 	/* ==================================================== */
 
+	/* clean up search string */
+	if (isset($_REQUEST["filter"])) {
+		$_REQUEST["filter"] = sanitize_search_string(get_request_var("filter"));
+	}
+
 	/* if the user pushed the 'clear' button */
 	if (isset($_REQUEST["clear_x"])) {
-		kill_session_var("sess_graphs_new_host_id");
-		kill_session_var("sess_graphs_new_graph_type");
 		kill_session_var("sess_graphs_new_filter");
-
-		unset($_REQUEST["host_id"]);
-		unset($_REQUEST["graph_type"]);
 		unset($_REQUEST["filter"]);
+		$changed = true;
 	}else{
 		/* if any of the settings changed, reset the page number */
-		$changed = 0;
+		$changed = false;
 		$changed += check_changed("host_id",    "sess_graphs_new_host_id");
 		$changed += check_changed("graph_type", "sess_graphs_new_graph_type");
 		$changed += check_changed("filter",     "sess_graphs_new_filter");
@@ -382,9 +399,52 @@ function graphs() {
 	$row_limit = read_config_option("num_rows_data_query");
 	$debug_log = debug_log_return("new_graphs");
 
+	if (!empty($debug_log)) {
+		debug_log_clear("new_graphs");
+		if (read_config_option("cacti_popup_messages") == "on") { ?>
+		<div id='message'>
+			<?php print "<table align='center' style='width:100%;background-color:#" . $colors["header"] . ";'><tr><td style='align:center;padding:3px;font-weight:bold;font-size:10pt;text-align:center;'>Graphs Created</td><td style='width:1px;align:right;'><input type='button' value='Clear' onClick='javascript:document.getElementById(\"message\").style.display=\"none\"' style='align=right;'></td></tr></table>";?>
+			<?php print "<table align='left' style='width:100%;'><tr><td><ul style='text-align:left;white-space:nowrap;color:#000000;padding:2px 10px;margin:10px;'>" . $debug_log . "</ul></td></tr></table>";?>
+		</div>
+		<?php }else{ ?>
+		<table width='100%' style='background-color: #f5f5f5; border: 1px solid #bbbbbb;' align='center'>
+			<tr bgcolor="<?php print $colors["light"];?>">
+				<td style="padding: 3px; font-family: monospace;">
+					<ul style='margin:0px 5px;padding-left:10px'><?php print $debug_log;?></ul>
+				</td>
+			</tr>
+		</table>
+		<br><?php }
+	}
 	?>
 	<script type="text/javascript">
 	<!--
+	<?php if (read_config_option("cacti_popup_messages") == "on") {?>
+	var obj = document.getElementById('message');
+
+	if (obj) {
+		if (window.innerHeight) {
+			height = window.innerHeight;
+			width  = window.innerWidth;
+		}else{
+			height = document.body.clientHeight;
+			width  = document.body.clientWidth;
+		}
+		obj.style.position = "absolute";
+		obj.style.padding = "0px";
+		obj.style.display = "";
+		obj.style.overflow = "auto";
+		obj.style.color = "#FFFFFF";
+		obj.style.backgroundColor = "#<?php print $colors["light"];?>";
+		obj.style.border = "1px solid #<?php print $colors["header"];?>";
+		cw = obj.offsetWidth;
+		// Adjust for IE6
+		if (!cw) cw = 150;
+		ch = obj.offsetHeight;
+		obj.style.top = '65px';
+		obj.style.left = ((width/2) - (cw/2) - 88)+'px';
+	}
+	<?php } ?>
 
 	function applyGraphsNewFilterChange(objForm) {
 		strURL = '?graph_type=' + objForm.graph_type.value;
@@ -395,33 +455,16 @@ function graphs() {
 
 	-->
 	</script>
-	<?php
-
-	if (!empty($debug_log)) {
-		debug_log_clear("new_graphs");
-		?>
-		<table width='100%' style='background-color: #f5f5f5; border: 1px solid #bbbbbb;' align='center'>
-			<tr bgcolor="<?php print $colors["light"];?>">
-				<td style="padding: 3px; font-family: monospace;">
-					<?php print $debug_log;?>
-				</td>
-			</tr>
-		</table>
-		<br>
-		<?php
-	}
-	?>
-
-	<form name="form_graphs_new">
+	<form name="form_graphs_new" action="graphs_new.php">
 	<table width="100%" cellpadding="4" align="center">
 		<tr>
 			<td nowrap style='white-space: nowrap;' width="30%" class="textInfo">
-				<?php print $host["description"];?> (<?php print $host["hostname"];?>)
+				<?php print htmlspecialchars($host["description"]);?> (<?php print htmlspecialchars($host["hostname"]);?>)
 			</td>
 			<td align="left" class="textInfo" colspan="2" style="color: #aaaaaa;">
 				<?php
 				if (!empty($host["host_template_id"])) {
-					print db_fetch_cell("select name from host_template where id=" . $host["host_template_id"]);
+					print htmlspecialchars(db_fetch_cell("select name from host_template where id=" . $host["host_template_id"]));
 				}
 				?>
 			</td>
@@ -438,9 +481,9 @@ function graphs() {
 				$hosts = db_fetch_assoc("select id,CONCAT_WS('',description,' (',hostname,')') as name from host order by description,hostname");
 
 				if (sizeof($hosts) > 0) {
-				foreach ($hosts as $item) {
-					print "<option value='" . $item["id"] . "'"; if ($_REQUEST["host_id"] == $item["id"]) { print " selected"; } print ">" . $item["name"] . "</option>\n";
-				}
+					foreach ($hosts as $item) {
+						print "<option value='" . $item["id"] . "'"; if ($_REQUEST["host_id"] == $item["id"]) { print " selected"; } print ">" . htmlspecialchars($item["name"]) . "</option>\n";
+					}
 				}
 				?>
 				</select>
@@ -472,8 +515,9 @@ function graphs() {
 				</select>
 			</td>
 			<td nowrap style='white-space: nowrap;' class="textInfo" align="center" valign="top">
-				<span style="white-space: nowrap; color: #c16921;">*</span><a href="host.php?action=edit&id=<?php print $_REQUEST["host_id"];?>">Edit this Host</a><br>
-				<span style="white-space: nowrap; color: #c16921;">*</span><a href="host.php?action=edit">Create New Host</a>
+				<span style="white-space: nowrap; color: #c16921;">*</span><a href="<?php print htmlspecialchars("host.php?action=edit&id=" . $_REQUEST["host_id"]);?>">Edit this Host</a><br>
+				<span style="white-space: nowrap; color: #c16921;">*</span><a href="<?php print htmlspecialchars("host.php?action=edit");?>">Create New Host</a><br>
+				<?php api_plugin_hook('graphs_new_top_links'); ?>
 			</td>
 		</tr>
 	</table>
@@ -484,11 +528,11 @@ function graphs() {
 				Search:&nbsp;
 			</td>
 			<td nowrap style='white-space: nowrap;' width="200">
-				<input type="text" name="filter" size="30" width="200" value="<?php print $_REQUEST["filter"];?>">
+				<input type="text" name="filter" size="30" value="<?php print htmlspecialchars(get_request_var_request("filter"));?>">
 			</td>
 			<td align="left" nowrap style='white-space: nowrap;'>
-				&nbsp;<input type="image" src="images/button_go.gif" name="go" alt="Go" border="0" align="absmiddle">
-				<input type="image" src="images/button_clear.gif" name="clear" alt="Clear" border="0" align="absmiddle">
+				&nbsp;<input type="submit" value="Go" title="Set/Refresh Filters">
+				<input type="submit" name="clear_x" value="Clear" title="Clear Filters">
 			</td>
 		</tr>
 	</table>
@@ -503,6 +547,14 @@ function graphs() {
 
 	$i = 0;
 
+	if ($changed) {
+		foreach($snmp_queries as $query) {
+			kill_session_var("sess_graphs_new_page" . $query["id"]);
+			unset($_REQUEST["page" . $query["id"]]);
+			load_current_session_value("page" . $query["id"], "sess_graphs_new_page" . $query["id"], "1");
+		}
+	}
+
 	if ($_REQUEST["graph_type"] > 0) {
 		load_current_session_value("page" . $_REQUEST["graph_type"], "sess_graphs_new_page" . $_REQUEST["graph_type"], "1");
 	}else if ($_REQUEST["graph_type"] == -2) {
@@ -511,6 +563,8 @@ function graphs() {
 		}
 	}
 
+	$script = "<script type='text/javascript'>\nvar gt_created_graphs = new Array();\nvar created_graphs = new Array()\n";
+
 	if ($_REQUEST["graph_type"] < 0) {
 		html_start_box("<strong>Graph Templates</strong>", "100%", $colors["header"], "3", "center", "");
 
@@ -535,21 +589,17 @@ function graphs() {
 			AND graph_local.host_id=" . $host["id"] . "
 			GROUP BY graph_local.graph_template_id");
 
-		print "<script type='text/javascript'>\nvar gt_created_graphs = new Array()\n</script>\n";
-
 		if (sizeof($template_graphs) > 0) {
-			print "<script type='text/javascript'>\n<!--\n";
-			print "var gt_created_graphs = new Array(";
+			$script .= "var gt_created_graphs = new Array(";
 
 			$cg_ctr = 0;
 			foreach ($template_graphs as $template_graph) {
-				print (($cg_ctr > 0) ? "," : "") . "'" . $template_graph["graph_template_id"] . "'";
+				$script .= (($cg_ctr > 0) ? "," : "") . "'" . $template_graph["graph_template_id"] . "'";
 
 				$cg_ctr++;
 			}
 
-			print ")\n";
-			print "//-->\n</script>\n";
+			$script .= ")\n";
 		}
 
 		/* create a row for each graph template associated with the host template */
@@ -559,8 +609,8 @@ function graphs() {
 
 			print "<tr id='gt_line$query_row' bgcolor='#" . (($i % 2 == 0) ? "ffffff" : $colors["light"]) . "'>"; $i++;
 
-			print "		<td onClick='gt_select_line(" . $graph_template["graph_template_id"] . ");'><span id='gt_text$query_row" . "_0'>
-						<span id='gt_text$query_row" . "_0'><strong>Create:</strong> " . $graph_template["graph_template_name"] . "</span>
+			print "		<td onClick='gt_select_line(" . $graph_template["graph_template_id"] . ");'>
+						<span id='gt_text$query_row" . "_0'><strong>Create:</strong> " . htmlspecialchars($graph_template["graph_template_name"]) . "</span>
 					</td>
 					<td align='right'>
 						<input type='checkbox' name='cg_$query_row' id='cg_$query_row' onClick='gt_update_selection_indicators();'>
@@ -569,7 +619,7 @@ function graphs() {
 		}
 		}
 
-		print "<script type='text/javascript'>gt_update_deps(1);</script>\n";
+		$script .= "gt_update_deps(1);\n";
 
 		$available_graph_templates = db_fetch_assoc("SELECT
 			graph_templates.id, graph_templates.name
@@ -599,13 +649,15 @@ function graphs() {
 			($_REQUEST["graph_type"] != -2 ? " AND snmp_query.id=" . $_REQUEST["graph_type"] : '') . "
 			ORDER BY snmp_query.name");
 
-		print "<script type='text/javascript'>\nvar created_graphs = new Array()\n</script>\n";
-
 		if (sizeof($snmp_queries) > 0) {
 		foreach ($snmp_queries as $snmp_query) {
 			unset($total_rows);
 
-			$page = $_REQUEST["page" . $snmp_query["id"]];
+			if (!$changed) {
+				$page = $_REQUEST["page" . $snmp_query["id"]];
+			}else{
+				$page = 1;
+			}
 
 			$xml_array = get_data_query_array($snmp_query["id"]);
 
@@ -633,8 +685,6 @@ function graphs() {
 			$snmp_query_graphs = db_fetch_assoc("SELECT snmp_query_graph.id,snmp_query_graph.name FROM snmp_query_graph WHERE snmp_query_graph.snmp_query_id=" . $snmp_query["id"] . " ORDER BY snmp_query_graph.name");
 
 			if (sizeof($snmp_query_graphs) > 0) {
-				print "<script type='text/javascript'>\n<!--\n";
-
 				foreach ($snmp_query_graphs as $snmp_query_graph) {
 					$created_graphs = db_fetch_assoc("SELECT DISTINCT
 						data_local.snmp_index
@@ -646,21 +696,19 @@ function graphs() {
 						AND data_input_data.value='" . $snmp_query_graph["id"] . "'
 						AND data_local.host_id=" . $host["id"]);
 
-					print "created_graphs[" . $snmp_query_graph["id"] . "] = new Array(";
+					$script .= "created_graphs[" . $snmp_query_graph["id"] . "] = new Array(";
 
 					$cg_ctr = 0;
 					if (sizeof($created_graphs) > 0) {
 					foreach ($created_graphs as $created_graph) {
-						print (($cg_ctr > 0) ? "," : "") . "'" . encode_data_query_index($created_graph["snmp_index"]) . "'";
+						$script .= (($cg_ctr > 0) ? "," : "") . "'" . encode_data_query_index($created_graph["snmp_index"]) . "'";
 
 						$cg_ctr++;
 					}
 					}
 
-					print ")\n";
+					$script .= ")\n";
 				}
-
-				print "//-->\n</script>\n";
 			}
 
 			print "	<table width='100%' style='background-color: #" . $colors["form_alternate2"] . "; border: 1px solid #" . $colors["header"] . ";' align='center' cellpadding='3' cellspacing='0'>\n
@@ -672,7 +720,7 @@ function graphs() {
 										<strong>Data Query</strong> [" . $snmp_query["name"] . "]
 									</td>
 									<td align='right' nowrap>
-										<a href='graphs_new.php?action=query_reload&id=" . $snmp_query["id"] . "&host_id=" . $host["id"] . "'><img src='images/reload_icon_small.gif' alt='Reload Associated Query' border='0' align='absmiddle'></a>
+										<a href='" . htmlspecialchars("graphs_new.php?action=query_reload&id=" . $snmp_query["id"] . "&host_id=" . $host["id"]) . "'><img src='images/reload_icon_small.gif' title='Reload Associated Query' alt='' border='0' align='middle'></a>
 									</td>
 								</tr>
 							</table>
@@ -751,7 +799,8 @@ function graphs() {
 						$sql_order
 						LIMIT " . ($row_limit*($page-1)) . "," . $row_limit;
 
-					$rows_query = "SELECT host_id, snmp_query_id, snmp_index FROM host_snmp_cache
+					$rows_query = "SELECT host_id, snmp_query_id, snmp_index
+						FROM host_snmp_cache
 						WHERE host_id=" . $host["id"] . "
 						AND snmp_query_id=" . $snmp_query["id"] . "
 						$sql_where
@@ -761,7 +810,7 @@ function graphs() {
 
 					$total_rows = sizeof(db_fetch_assoc($rows_query));
 
-					if (($page-1) * $row_limit > $total_rows) {
+					if (($page - 1) * $row_limit > $total_rows) {
 						$page = 1;
 						$_REQUEST["page" . $query["id"]] = $page;
 						load_current_session_value("page" . $query["id"], "sess_graphs_new_page" . $query["id"], "1");
@@ -776,13 +825,13 @@ function graphs() {
 										<table width='100%' cellspacing='0' cellpadding='0' border='0'>
 											<tr>
 												<td align='left' class='textHeaderDark'>
-													<strong>&lt;&lt; "; if ($page > 1) { $nav .= "<a class='linkOverDark' href='graphs_new.php?page" . $snmp_query["id"] . "=" . ($page-1) . "'>"; } $nav .= "Previous"; if ($page > 1) { $nav .= "</a>"; } $nav .= "</strong>
+													<strong>&lt;&lt; "; if ($page > 1) { $nav .= "<a class='linkOverDark' href='" . htmlspecialchars("graphs_new.php?page" . $snmp_query["id"] . "=" . ($page-1)) . "'>"; } $nav .= "Previous"; if ($page > 1) { $nav .= "</a>"; } $nav .= "</strong>
 												</td>\n
 												<td align='center' class='textHeaderDark'>
 													Showing Rows " . (($row_limit*($page-1))+1) . " to " . ((($total_rows < $row_limit) || ($total_rows < ($row_limit*$page))) ? $total_rows : ($row_limit*$page)) . " of $total_rows [$url_page_select]
 												</td>\n
 												<td align='right' class='textHeaderDark'>
-													<strong>"; if (($page * $row_limit) < $total_rows) { $nav .= "<a class='linkOverDark' href='graphs_new.php?page" . $snmp_query["id"] . "=" . ($page+1) . "'>"; } $nav .= "Next"; if (($page * $row_limit) < $total_rows) { $nav .= "</a>"; } $nav .= " &gt;&gt;</strong>
+													<strong>"; if (($page * $row_limit) < $total_rows) { $nav .= "<a class='linkOverDark' href='" . htmlspecialchars("graphs_new.php?page" . $snmp_query["id"] . "=" . ($page+1)) . "'>"; } $nav .= "Next"; if (($page * $row_limit) < $total_rows) { $nav .= "</a>"; } $nav .= " &gt;&gt;</strong>
 												</td>\n
 											</tr>
 										</table>
@@ -793,10 +842,10 @@ function graphs() {
 					}
 
 					while (list($field_name, $field_array) = each($xml_array["fields"])) {
-						if ($field_array["direction"] == "input") {
+						if ($field_array["direction"] == "input" && sizeof($field_names)) {
 							foreach($field_names as $row) {
 								if ($row["field_name"] == $field_name) {
-									$html_dq_header .= "<td height='1'><strong><font color='#" . $colors["header_text"] . "'>" . $field_array["name"] . "</font></strong></td>\n";
+									$html_dq_header .= "<td style='height:1px;'><strong><font color='#" . $colors["header_text"] . "'>" . $field_array["name"] . "</font></strong></td>\n";
 									break;
 								}
 							}
@@ -805,7 +854,7 @@ function graphs() {
 
 					if (!sizeof($snmp_query_indexes)) {
 						print "<tr bgcolor='#" . $colors["form_alternate1"] . "'><td>This data query returned 0 rows, perhaps there was a problem executing this
-							data query. You can <a href='host.php?action=query_verbose&id=" . $snmp_query["id"] . "&host_id=" . $host["id"] . "'>run this data
+							data query. You can <a href='" . htmlspecialchars("host.php?action=query_verbose&id=" . $snmp_query["id"] . "&host_id=" . $host["id"]) . "'>run this data
 							query in debug mode</a> to get more information.</td></tr>\n";
 					}else{
 						print "	<tr bgcolor='#" . $colors["header_panel"] . "'>
@@ -829,7 +878,7 @@ function graphs() {
 							if ($field_array["direction"] == "input") {
 								if (in_array($field_name, $fields)) {
 									if (isset($row[$field_name])) {
-										print "<td onClick='dq_select_line(" . $snmp_query["id"] . ",\"" . encode_data_query_index($row["snmp_index"]) . "\");'><span id='text$query_row" . "_" . $column_counter . "'>" . (strlen($_REQUEST["filter"]) ? eregi_replace("(" . preg_quote($_REQUEST["filter"]) . ")", "<span style='background-color: #F8D93D;'>\\1</span>", $row[$field_name]) : $row[$field_name]) . "</span></td>";
+										print "<td onClick='dq_select_line(" . $snmp_query["id"] . ",\"" . encode_data_query_index($row["snmp_index"]) . "\");'><span id='text$query_row" . "_" . $column_counter . "'>" . (strlen($_REQUEST["filter"]) ? preg_replace("/(" . preg_quote($_REQUEST["filter"]) . ")/i", "<span style='background-color: #F8D93D;'>\\1</span>", $row[$field_name]) : $row[$field_name]) . "</span></td>";
 									}else{
 										print "<td onClick='dq_select_line(" . $snmp_query["id"] . ",\"" . encode_data_query_index($row["snmp_index"]) . "\");'><span id='text$query_row" . "_" . $column_counter . "'></span></td>";
 									}
@@ -864,16 +913,16 @@ function graphs() {
 			$data_query_graphs = db_fetch_assoc("select snmp_query_graph.id,snmp_query_graph.name from snmp_query_graph where snmp_query_graph.snmp_query_id=" . $snmp_query["id"] . " order by snmp_query_graph.name");
 
 			if (sizeof($data_query_graphs) == 1) {
-				form_hidden_box("sgg_" . $snmp_query["id"] . "' id='sgg_" . $snmp_query["id"], $data_query_graphs[0]["id"], "");
+				echo "<input type='hidden' id='sgg_" . $snmp_query["id"] . "' name='sgg_" . $snmp_query["id"] . "' value='" . $data_query_graphs[0]["id"] . "'>\n";
 			}elseif (sizeof($data_query_graphs) > 1) {
 				print "	<table align='center' width='100%'>
 						<tr>
 							<td width='1' valign='top'>
-								<img src='images/arrow.gif' alt='' align='absmiddle'>&nbsp;
+								<img src='images/arrow.gif' alt=''>&nbsp;
 							</td>
 							<td align='right'>
 								<span style='font-size: 12px; font-style: italic;'>Select a graph type:</span>&nbsp;
-								<select name='sgg_" . $snmp_query["id"] . "' id='sgg_" . $snmp_query["id"] . "' onChange='dq_update_deps(" . $snmp_query["id"] . "," . $column_counter . ");'>
+								<select name='sgg_" . $snmp_query["id"] . "' id='sgg_" . $snmp_query["id"] . "' onChange='dq_update_deps(" . $snmp_query["id"] . "," . (isset($column_counter) ? $column_counter:"") . ");'>
 									"; html_create_list($data_query_graphs,"name","id","0"); print "
 								</select>
 							</td>
@@ -882,16 +931,27 @@ function graphs() {
 			}
 
 			print "<br>";
-			print "<script type='text/javascript'>dq_update_deps(" . $snmp_query["id"] . "," . ($num_visible_fields) . ");</script>\n";
+
+			$script .= "dq_update_deps(" . $snmp_query["id"] . "," . $num_visible_fields . ");\n";
 		}
 		}
 	}
 
+	if (strlen($script)) {
+		$script .= "</script>\n";
+		print $script;
+	}
+
 	form_hidden_box("save_component_graph", "1", "");
 	form_hidden_box("host_id", $host["id"], "0");
 	form_hidden_box("host_template_id", $host["host_template_id"], "0");
 
-	form_save_button((isset($_SERVER["HTTP_REFERER"]) ? $_SERVER["HTTP_REFERER"] : "index.php"));
+	if (isset($_SERVER["HTTP_REFERER"]) && !substr_count($_SERVER["HTTP_REFERER"], "graphs_new")) {
+		$_REQUEST["returnto"] = basename($_SERVER["HTTP_REFERER"]);
+	}
+	load_current_session_value("returnto", "sess_graphs_new_returnto", "");
+
+	form_save_button($_REQUEST["returnto"]);
 
 	print "<script type='text/javascript'>dq_update_selection_indicators();</script>\n";
 	print "<script type='text/javascript'>gt_update_selection_indicators();</script>\n";
