@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,6 +22,8 @@
  +-------------------------------------------------------------------------+
 */
 
+define("CACTI_ESCAPE_CHARACTER", "\"");
+
 define("HOST_GROUPING_GRAPH_TEMPLATE", 1);
 define("HOST_GROUPING_DATA_QUERY_INDEX", 2);
 
@@ -34,10 +36,6 @@ define("TREE_ITEM_TYPE_HEADER", 1);
 define("TREE_ITEM_TYPE_GRAPH", 2);
 define("TREE_ITEM_TYPE_HOST", 3);
 
-define("RRDTOOL_PIPE_CHILD_READ", 0);
-define("RRDTOOL_PIPE_CHILD_WRITE", 1);
-define("RRDTOOL_PIPE_STDERR_WRITE", 2);
-
 define("RRDTOOL_OUTPUT_NULL", 0);
 define("RRDTOOL_OUTPUT_STDOUT", 1);
 define("RRDTOOL_OUTPUT_STDERR", 2);
@@ -66,9 +64,18 @@ define("GRAPH_ITEM_TYPE_STACK",   8);
 define("GRAPH_ITEM_TYPE_GPRINT",  9);
 define("GRAPH_ITEM_TYPE_LEGEND", 10);
 
+/* used both for polling and reindexing */
 define("POLLER_ACTION_SNMP", 0);
 define("POLLER_ACTION_SCRIPT", 1);
 define("POLLER_ACTION_SCRIPT_PHP", 2);
+/* used for reindexing only:
+ * in case we do not have OID_NUM_INDEXES|ARG_NUM_INDEXES
+ * we simply use the OID_INDEX|ARG_INDEX and count number of indexes found
+ * so this is more of a REINDEX_ACTION_... thingy
+ */
+define("POLLER_ACTION_SNMP_COUNT", 10);
+define("POLLER_ACTION_SCRIPT_COUNT", 11);
+define("POLLER_ACTION_SCRIPT_PHP_COUNT", 12);
 
 define("POLLER_COMMAND_REINDEX", 1);
 define("POLLER_COMMAND_RRDPURGE", 2);
@@ -78,11 +85,15 @@ define("POLLER_VERBOSITY_LOW", 2);
 define("POLLER_VERBOSITY_MEDIUM", 3);
 define("POLLER_VERBOSITY_HIGH", 4);
 define("POLLER_VERBOSITY_DEBUG", 5);
+define("POLLER_VERBOSITY_DEVDBG", 6);
 
 define("AVAIL_NONE", 0);
 define("AVAIL_SNMP_AND_PING", 1);
 define("AVAIL_SNMP", 2);
 define("AVAIL_PING", 3);
+define("AVAIL_SNMP_OR_PING", 4);
+define("AVAIL_SNMP_GET_SYSDESC", 5);
+define("AVAIL_SNMP_GET_NEXT", 6);
 
 define("PING_ICMP", 1);
 define("PING_UDP", 2);
@@ -173,4 +184,9 @@ define("SNMP_POLLER", 0);
 define("SNMP_CMDPHP", 1);
 define("SNMP_WEBUI", 2);
 
+define('OPER_MODE_NATIVE', 0);
+define('OPER_MODE_RESKIN', 1);
+define('OPER_MODE_IFRAME_NONAV', 2);
+define('OPER_MODE_NOTABS', 3);
+
 ?>
