@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,8 +22,9 @@
  +-------------------------------------------------------------------------+
 */
 
-if (!defined("VALID_HOST_FIELDS")) {
-	define("VALID_HOST_FIELDS", "(hostname|snmp_community|snmp_username|snmp_password|snmp_auth_protocol|snmp_priv_passphrase|snmp_priv_protocol|snmp_context|snmp_version|snmp_port|snmp_timeout)");
+if (!defined('VALID_HOST_FIELDS')) {
+	$string = api_plugin_hook_function('valid_host_fields', '(hostname|host_id|snmp_community|snmp_username|snmp_password|snmp_auth_protocol|snmp_priv_passphrase|snmp_priv_protocol|snmp_context|snmp_version|snmp_port|snmp_timeout)');
+	define('VALID_HOST_FIELDS', $string);
 }
 
 /* file: cdef.php, action: edit */
@@ -77,15 +78,18 @@ $fields_data_input_edit = array(
 	"type_id" => array(
 		"method" => "drop_array",
 		"friendly_name" => "Input Type",
-		"description" => "Choose what type of data input method this is.",
+		"description" => "Choose the method you wish to use to collect data for this Data Input method.",
 		"value" => "|arg1:type_id|",
 		"array" => $input_types,
 		),
 	"input_string" => array(
-		"method" => "textbox",
+		"method" => "textarea",
 		"friendly_name" => "Input String",
 		"description" => "The data that is sent to the script, which includes the complete path to the script and input sources in &lt;&gt; brackets.",
 		"value" => "|arg1:input_string|",
+		"textarea_rows" => "4",
+		"textarea_cols" => "60",
+		"class" => "textAreaNotes",
 		"max_length" => "255",
 		),
 	"id" => array(
@@ -142,7 +146,8 @@ $fields_data_input_field_edit = array(
 		"friendly_name" => "Regular Expression Match",
 		"description" => "If you want to require a certain regular expression to be matched againt input data, enter it here (ereg format).",
 		"value" => "|arg1:regexp_match|",
-		"max_length" => "200"
+		"max_length" => "200",
+		"size" => "70"
 		),
 	"allow_nulls" => array(
 		"method" => "checkbox",
@@ -155,7 +160,7 @@ $fields_data_input_field_edit = array(
 	"type_code" => array(
 		"method" => "textbox",
 		"friendly_name" => "Special Type Code",
-		"description" => "If this field should be treated specially by host templates, indicate so here. Valid keywords for this field are 'hostname', 'snmp_community', 'snmp_username', 'snmp_password', 'snmp_auth_protocol', 'snmp_priv_passphrase', 'snmp_priv_protocol', 'snmp_port', 'snmp_timeout', and 'snmp_version'.",
+		"description" => "If this field should be treated specially by host templates, indicate so here. Valid keywords for this field are " . (str_replace(")", "'", str_replace("(", "'", str_replace("|", "', '", VALID_HOST_FIELDS)))),
 		"value" => "|arg1:type_code|",
 		"max_length" => "40"
 		),
@@ -273,7 +278,7 @@ $struct_data_source_item = array(
 		"description" => "Choose unique name to represent this piece of data inside of the rrd file."
 		),
 	"rrd_minimum" => array(
-		"friendly_name" => "Minimum Value",
+		"friendly_name" => "Minimum Value ('U' for No Minimum)",
 		"method" => "textbox",
 		"max_length" => "20",
 		"size" => "30",
@@ -281,7 +286,7 @@ $struct_data_source_item = array(
 		"description" => "The minimum value of data that is allowed to be collected."
 		),
 	"rrd_maximum" => array(
-		"friendly_name" => "Maximum Value",
+		"friendly_name" => "Maximum Value ('U' for No Maximum)",
 		"method" => "textbox",
 		"max_length" => "20",
 		"size" => "30",
@@ -643,6 +648,10 @@ $fields_graph_template_input_edit = array(
 
 /* file: host.php, action: edit */
 $fields_host_edit = array(
+	"host_header" => array(
+		"method" => "spacer",
+		"friendly_name" => "General Host Options"
+		),
 	"description" => array(
 		"method" => "textbox",
 		"friendly_name" => "Description",
@@ -660,19 +669,18 @@ $fields_host_edit = array(
 	"host_template_id" => array(
 		"method" => "drop_sql",
 		"friendly_name" => "Host Template",
-		"description" => "Choose what type of host, host template this is. The host template will govern what kinds of data should be gathered from this type of host.",
+		"description" => "Choose the Host Template to use to define the default Graph Templates and Data Queries associated with this Host.",
 		"value" => "|arg1:host_template_id|",
 		"none_value" => "None",
 		"sql" => "select id,name from host_template order by name",
 		),
-	"notes" => array(
-		"method" => "textarea",
-		"friendly_name" => "Notes",
-		"description" => "Enter notes to this host.",
-		"class" => "textAreaNotes",
-		"value" => "|arg1:notes|",
-		"textarea_rows" => "5",
-		"textarea_cols" => "40"
+	"device_threads" => array(
+		"method" => "drop_array",
+		"friendly_name" => "Number of Collection Threads",
+		"description" => "The number of concurrent threads to use for polling this device.  This applies to the Spine poller only.",
+		"value" => "|arg1:device_threads|",
+		"default" => "1",
+		"array" => $device_threads
 		),
 	"disabled" => array(
 		"method" => "checkbox",
@@ -682,7 +690,7 @@ $fields_host_edit = array(
 		"default" => "",
 		"form_id" => false
 		),
-	"avalaibility_header" => array(
+	"availability_header" => array(
 		"method" => "spacer",
 		"friendly_name" => "Availability/Reachability Options"
 		),
@@ -724,7 +732,7 @@ $fields_host_edit = array(
 		),
 	"ping_retries" => array(
 		"friendly_name" => "Ping Retry Count",
-		"description" => "The number of times Cacti will attempt to ping a host before failing.",
+		"description" => "After an initial failure, the number of ping retries Cacti will attempt before failing.",
 		"method" => "textbox",
 		"value" => "|arg1:ping_retries|",
 		"default" => read_config_option("ping_retries"),
@@ -827,12 +835,25 @@ $fields_host_edit = array(
 	"max_oids" => array(
 		"method" => "textbox",
 		"friendly_name" => "Maximum OID's Per Get Request",
-		"description" => "Specified the number of OID's that can be obtained in a single SNMP Get request.  <br><i>NOTE: This feature only works when using Spine</i>",
+		"description" => "Specified the number of OID's that can be obtained in a single SNMP Get request.",
 		"value" => "|arg1:max_oids|",
 		"max_length" => "8",
 		"default" => read_config_option("max_get_size"),
 		"size" => "15"
 		),
+	"header4" => array(
+		"method" => "spacer",
+		"friendly_name" => "Additional Options"
+		),
+	"notes" => array(
+		"method" => "textarea",
+		"friendly_name" => "Notes",
+		"description" => "Enter notes to this host.",
+		"class" => "textAreaNotes",
+		"value" => "|arg1:notes|",
+		"textarea_rows" => "5",
+		"textarea_cols" => "50"
+		),
 	"id" => array(
 		"method" => "hidden_zero",
 		"value" => "|arg1:id|"
@@ -934,6 +955,7 @@ $fields_data_query_edit = array(
 		"friendly_name" => "Description",
 		"description" => "A description for this data query.",
 		"value" => "|arg1:description|",
+		"size" => "80",
 		"max_length" => "255",
 		),
 	"xml_path" => array(
@@ -942,12 +964,13 @@ $fields_data_query_edit = array(
 		"description" => "The full path to the XML file containing definitions for this data query.",
 		"value" => "|arg1:xml_path|",
 		"default" => "<path_cacti>/resource/",
+		"size" => "80",
 		"max_length" => "255",
 		),
 	"data_input_id" => array(
 		"method" => "drop_sql",
 		"friendly_name" => "Data Input Method",
-		"description" => "Choose what type of host, host template this is. The host template will govern what kinds of data should be gathered from this type of host.",
+		"description" => "Choose the input method for this Data Query.  This input method defines how data is collected for each Host associated with the Data Query.",
 		"value" => "|arg1:data_input_id|",
 		"sql" => "select id,name from data_input where (type_id=3 or type_id=4 or type_id=5 or type_id=6) order by name",
 		),
@@ -973,7 +996,7 @@ $fields_data_query_item_edit = array(
 	"graph_template_id" => array(
 		"method" => "drop_sql",
 		"friendly_name" => "Graph Template",
-		"description" => "Choose what type of host, host template this is. The host template will govern what kinds of data should be gathered from this type of host.",
+		"description" => "Choose the Graph Template to use for this Data Query Graph Template item.",
 		"value" => "|arg1:graph_template_id|",
 		"sql" => "select id,name from graph_templates order by name",
 		),
@@ -1154,4 +1177,71 @@ $fields_user_user_edit_host = array(
 		)
 	);
 
+$export_types = array(
+	"graph_template" => array(
+		"name" => "Graph Template",
+		"title_sql" => "select name from graph_templates where id=|id|",
+		"dropdown_sql" => "select id,name from graph_templates order by name"
+		),
+	"data_template" => array(
+		"name" => "Data Template",
+		"title_sql" => "select name from data_template where id=|id|",
+		"dropdown_sql" => "select id,name from data_template order by name"
+		),
+	"host_template" => array(
+		"name" => "Host Template",
+		"title_sql" => "select name from host_template where id=|id|",
+		"dropdown_sql" => "select id,name from host_template order by name"
+		),
+	"data_query" => array(
+		"name" => "Data Query",
+		"title_sql" => "select name from snmp_query where id=|id|",
+		"dropdown_sql" => "select id,name from snmp_query order by name"
+		)
+	);
+
+$fields_template_import = array(
+	"import_file" => array(
+		"friendly_name" => "Import Template from Local File",
+		"description" => "If the XML file containing template data is located on your local machine, select it here.",
+		"method" => "file"
+		),
+	"import_text" => array(
+		"method" => "textarea",
+		"friendly_name" => "Import Template from Text",
+		"description" => "If you have the XML file containing template data as text, you can paste it into this box to import it.",
+		"value" => "",
+		"default" => "",
+		"textarea_rows" => "10",
+		"textarea_cols" => "50",
+		"class" => "textAreaNotes"
+		),
+	"import_rra" => array(
+		"friendly_name" => "Import RRA Settings",
+		"description" => "Choose whether to allow Cacti to import custom RRA settings from imported templates or whether to use the defaults for this installation.",
+		"method" => "radio",
+		"value" => "",
+		"default" => "1",
+		"on_change" => "changeRRA()",
+		"items" => array(
+			0 => array(
+				"radio_value" => "1",
+				"radio_caption" => "Select your RRA settings below (Recommended)"
+				),
+			1 => array(
+				"radio_value" => "2",
+				"radio_caption" => "Use custom RRA settings from the template"
+				),
+			)
+		),
+	"rra_id" => array(
+		"method" => "drop_multi_rra",
+		"friendly_name" => "Associated RRA's",
+		"description" => "Which RRA's to use when entering data (It is recommended that you <strong>deselect unwanted values</strong>).",
+		"form_id" => "",
+		"sql_all" => "select rra.id from rra where id in (1,2,3,4) order by id",
+		),
+	);
+
+api_plugin_hook('config_form');
 ?>
