@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -77,9 +77,11 @@ $settings = array(
 			"max_length" => "255"
 			),
 		"path_rrdtool_default_font" => array(
-			"friendly_name" => "RRDTool Default Font Path",
-			"description" => "The path to the rrdtool default true type font for version 1.2 and above.",
-			"method" => "filepath",
+			"friendly_name" => "RRDTool Default Font",
+			"description" => "For RRDtool 1.2, the path to the True Type Font File." . "<br/>" .
+							"For RRDtool 1.3 and above, the font name conforming to the pango naming convention:" . "<br/>" .
+							'You can to use the full Pango syntax when selecting your font: The font name has the form "[FAMILY-LIST] [STYLE-OPTIONS] [SIZE]", where FAMILY-LIST is a comma separated list of families optionally terminated by a comma, STYLE_OPTIONS is a whitespace separated list of words where each WORD describes one of style, variant, weight, stretch, or gravity, and SIZE is a decimal number (size in points) or optionally followed by the unit modifier "px" for absolute size. Any one of the options may be absent.',
+			"method" => "font",
 			"max_length" => "255"
 			),
 		"path_php_binary" => array(
@@ -108,7 +110,16 @@ $settings = array(
 			"description" => "The path to Spine binary.",
 			"method" => "filepath",
 			"max_length" => "255"
-			)
+			),
+		"extendedpaths_header" => array(
+			"friendly_name" => "Structured RRD Path",
+			"method" => "spacer",
+			),
+		"extended_paths" => array(
+			"friendly_name" => "Structured RRA Path (/host_id/local_data_id.rrd)",
+			"description" => "Use a seperate subfolder for each hosts RRD files.",
+			"method" => "checkbox"
+ 			)
 		),
 	"general" => array(
 		"logging_header" => array(
@@ -188,7 +199,7 @@ $settings = array(
 			"friendly_name" => "RRDTool Utility Version",
 			"description" => "The version of RRDTool that you have installed.",
 			"method" => "drop_array",
-			"default" => "rrd-1.0.x",
+			"default" => "rrd-1.2.x",
 			"array" => $rrdtool_versions,
 			),
 		"snmp_header" => array(
@@ -199,7 +210,7 @@ $settings = array(
 			"friendly_name" => "SNMP Version",
 			"description" => "Default SNMP version for all new hosts.",
 			"method" => "drop_array",
-			"default" => "Version 1",
+			"default" => "1",
 			"array" => $snmp_versions,
 			),
 		"snmp_community" => array(
@@ -249,28 +260,38 @@ $settings = array(
 			"description" => "Default SNMP timeout in milli-seconds.",
 			"method" => "textbox",
 			"default" => "500",
-			"max_length" => "100"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"snmp_port" => array(
 			"friendly_name" => "SNMP Port Number",
 			"description" => "Default UDP port to be used for SNMP Calls.  Typically 161.",
 			"method" => "textbox",
 			"default" => "161",
-			"max_length" => "100"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"snmp_retries" => array(
 			"friendly_name" => "SNMP Retries",
 			"description" => "The number times the SNMP poller will attempt to reach the host before failing.",
 			"method" => "textbox",
 			"default" => "3",
-			"max_length" => "100"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"other_header" => array(
 			"friendly_name" => "Other Defaults",
 			"method" => "spacer",
 			),
-		"remove_verification" => array(
-			"friendly_name" => "Remove Verification",
+		"reindex_method" => array(
+			"friendly_name" => "Reindex Method for Data Queries",
+			"description" => "The default reindex method to use for all Data Queries.",
+			"method" => "drop_array",
+			"default" => "1",
+			"array" => $reindex_types,
+			),
+		"deletion_verification" => array(
+			"friendly_name" => "Deletion Verification",
 			"description" => "Prompt user before item deletion.",
 			"default" => "on",
 			"method" => "checkbox"
@@ -344,21 +365,24 @@ $settings = array(
 			"description" => "The height of thumbnail graphs in pixels.",
 			"method" => "textbox",
 			"default" => "100",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"export_default_width" => array(
 			"friendly_name" => "Thumbnail Width",
 			"description" => "The width of thumbnail graphs in pixels.",
 			"method" => "textbox",
 			"default" => "300",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"export_num_columns" => array(
 			"friendly_name" => "Thumbnail Columns",
 			"description" => "The number of columns to use when displaying thumbnail graphs.",
 			"method" => "textbox",
 			"default" => "2",
-			"max_length" => "5"
+			"max_length" => "5",
+			"size" => "5"
 			),
 		"export_hdr_paths" => array(
 			"friendly_name" => "Paths",
@@ -396,19 +420,22 @@ $settings = array(
 			"friendly_name" => "Export Every x Times",
 			"description" => "If you don't want Cacti to export static images every 5 minutes, put another number here. For instance, 3 would equal every 15 minutes.",
 			"method" => "textbox",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"export_hourly" => array(
 			"friendly_name" => "Hourly at specified minutes",
 			"description" => "If you want Cacti to export static images on an hourly basis, put the minutes of the hour when to do that. Cacti assumes that you run the data gathering script every 5 minutes, so it will round your value to the one closest to its runtime. For instance, 43 would equal 40 minutes past the hour.",
 			"method" => "textbox",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"export_daily" => array(
 			"friendly_name" => "Daily at specified time",
 			"description" => "If you want Cacti to export static images on an daily basis, put here the time when to do that. Cacti assumes that you run the data gathering script every 5 minutes, so it will round your value to the one closest to its runtime. For instance, 21:23 would equal 20 minutes after 9 PM.",
 			"method" => "textbox",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"export_hdr_ftp" => array(
 			"friendly_name" => "FTP Options",
@@ -430,7 +457,8 @@ $settings = array(
 			"friendly_name" => "FTP Port",
 			"description" => "Communication port with the ftp server (leave empty for defaults). Default: 21.",
 			"method" => "textbox",
-			"max_length" => "255"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"export_ftp_passive" => array(
 			"friendly_name" => "Use passive mode",
@@ -459,16 +487,17 @@ $settings = array(
 		"num_rows_graph" => array(
 			"friendly_name" => "Rows Per Page",
 			"description" => "The number of rows to display on a single page for graph management.",
-			"method" => "textbox",
+			"method" => "drop_array",
 			"default" => "30",
-			"max_length" => "10"
+			"array" => $item_rows
 			),
 		"max_title_graph" => array(
 			"friendly_name" => "Maximum Title Length",
 			"description" => "The maximum number of characters to display for a graph title.",
 			"method" => "textbox",
 			"default" => "80",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"dataqueries_header" => array(
 			"friendly_name" => "Data Queries",
@@ -479,7 +508,8 @@ $settings = array(
 			"description" => "The maximum number of characters to display for a data query field.",
 			"method" => "textbox",
 			"default" => "15",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"graphs_new_header" => array(
 			"friendly_name" => "Graph Creation",
@@ -495,9 +525,9 @@ $settings = array(
 		"num_rows_data_query" => array(
 			"friendly_name" => "Data Query Graph Rows",
 			"description" => "The maximum number Data Query rows to place on a page per Data Query.  This applies to the 'New Graphs' page.",
-			"method" => "textbox",
-			"default" => "20",
-			"max_length" => "10"
+			"method" => "drop_array",
+			"default" => "30",
+			"array" => $item_rows
 			),
 		"datasources_header" => array(
 			"friendly_name" => "Data Sources",
@@ -506,16 +536,17 @@ $settings = array(
 		"num_rows_data_source" => array(
 			"friendly_name" => "Rows Per Page",
 			"description" => "The number of rows to display on a single page for data sources.",
-			"method" => "textbox",
+			"method" => "drop_array",
 			"default" => "30",
-			"max_length" => "10"
+			"array" => $item_rows
 			),
 		"max_title_data_source" => array(
 			"friendly_name" => "Maximum Title Length",
 			"description" => "The maximum number of characters to display for a data source title.",
 			"method" => "textbox",
 			"default" => "45",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"devices_header" => array(
 			"friendly_name" => "Devices",
@@ -524,9 +555,9 @@ $settings = array(
 		"num_rows_device" => array(
 			"friendly_name" => "Rows Per Page",
 			"description" => "The number of rows to display on a single page for devices.",
-			"method" => "textbox",
+			"method" => "drop_array",
 			"default" => "30",
-			"max_length" => "10"
+			"array" => $item_rows
 			),
 		"logmgmt_header" => array(
 			"friendly_name" => "Log Management",
@@ -534,16 +565,16 @@ $settings = array(
 			),
 		"num_rows_log" => array(
 			"friendly_name" => "Default Log File Tail Lines",
-			"description" => "How many lines of the Cacti log file to you want to tail, by default.",
+			"description" => "Default number of lines of the Cacti log file to tail.",
 			"method" => "drop_array",
-			"default" => 50,
+			"default" => 500,
 			"array" => $log_tail_lines,
 			),
 		"log_refresh_interval" => array(
 			"friendly_name" => "Log File Tail Refresh",
-			"description" => "How many often do you want the Cacti log display to update.",
+			"description" => "How often do you want the Cacti log display to update.",
 			"method" => "drop_array",
-			"default" => 20,
+			"default" => 60,
 			"array" => $page_refresh_interval,
 			),
 		"fonts_header" => array(
@@ -554,52 +585,59 @@ $settings = array(
 			"friendly_name" => "Title Font Size",
 			"description" => "The size of the font used for Graph Titles",
 			"method" => "textbox",
-			"default" => "12",
-			"max_length" => "10"
+			"default" => "10",
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"title_font" => array(
 			"friendly_name" => "Title Font File",
-			"description" => "The font file to use for Graph Titles",
-			"method" => "filepath",
+			"description" => "The font to use for Graph Titles" . "<br/>" .
+							"For RRDtool 1.2, the path to the True Type Font File." . "<br/>" .
+							"For RRDtool 1.3 and above, the font name conforming to the pango naming convention:" . "<br/>" .
+							'You can to use the full Pango syntax when selecting your font: The font name has the form "[FAMILY-LIST] [STYLE-OPTIONS] [SIZE]", where FAMILY-LIST is a comma separated list of families optionally terminated by a comma, STYLE_OPTIONS is a whitespace separated list of words where each WORD describes one of style, variant, weight, stretch, or gravity, and SIZE is a decimal number (size in points) or optionally followed by the unit modifier "px" for absolute size. Any one of the options may be absent.',
+			"method" => "font",
 			"max_length" => "100"
 			),
 		"legend_size" => array(
 			"friendly_name" => "Legend Font Size",
 			"description" => "The size of the font used for Graph Legend items",
 			"method" => "textbox",
-			"default" => "10",
-			"max_length" => "10"
+			"default" => "8",
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"legend_font" => array(
 			"friendly_name" => "Legend Font File",
 			"description" => "The font file to be used for Graph Legend items",
-			"method" => "filepath",
+			"method" => "font",
 			"max_length" => "100"
 			),
 		"axis_size" => array(
 			"friendly_name" => "Axis Font Size",
 			"description" => "The size of the font used for Graph Axis",
 			"method" => "textbox",
-			"default" => "8",
-			"max_length" => "10"
+			"default" => "7",
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"axis_font" => array(
 			"friendly_name" => "Axis Font File",
 			"description" => "The font file to be used for Graph Axis items",
-			"method" => "filepath",
+			"method" => "font",
 			"max_length" => "100"
 			),
 		"unit_size" => array(
 			"friendly_name" => "Unit Font Size",
 			"description" => "The size of the font used for Graph Units",
 			"method" => "textbox",
-			"default" => "8",
-			"max_length" => "10"
+			"default" => "7",
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"unit_font" => array(
 			"friendly_name" => "Unit Font File",
 			"description" => "The font file to be used for Graph Unit items",
-			"method" => "filepath",
+			"method" => "font",
 			"max_length" => "100"
 			)
 		),
@@ -624,7 +662,8 @@ $settings = array(
 			),
 		"poller_interval" => array(
 			"friendly_name" => "Poller Interval",
-			"description" => "The polling interval in use.  This setting will effect how often rrd's are checked and updated.",
+			"description" => "The polling interval in use.  This setting will effect how often rrd's are checked and updated.
+			<strong><u>NOTE: If you change this value, you must re-populate the poller cache.  Failure to do so, may result in lost data.</u></strong>",
 			"method" => "drop_array",
 			"default" => 300,
 			"array" => $poller_intervals,
@@ -641,7 +680,14 @@ $settings = array(
 			"description" => "The number of concurrent processes to execute.  Using a higher number when using cmd.php will improve performance.  Performance improvements in spine are best resolved with the threads parameter",
 			"method" => "textbox",
 			"default" => "1",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
+			),
+		"process_leveling" => array(
+			"friendly_name" => "Balance Process Load",
+			"description" => "If you choose this option, Cacti will attempt to balance the load of each poller process by equally distributing poller items per process.",
+			"method" => "checkbox",
+			"default" => "on"
 			),
 		"spine_header" => array(
 			"friendly_name" => "Spine Specific Execution Parameters",
@@ -652,28 +698,32 @@ $settings = array(
 			"description" => "The maximum threads allowed per process.  Using a higher number when using Spine will improve performance.",
 			"method" => "textbox",
 			"default" => "1",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"php_servers" => array(
 			"friendly_name" => "Number of PHP Script Servers",
 			"description" => "The number of concurrent script server processes to run per Spine process.  Settings between 1 and 10 are accepted.  This parameter will help if you are running several threads and script server scripts.",
 			"method" => "textbox",
 			"default" => "1",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"script_timeout" => array(
 			"friendly_name" => "Script and Script Server Timeout Value",
 			"description" => "The maximum time that Cacti will wait on a script to complete.  This timeout value is in seconds",
 			"method" => "textbox",
 			"default" => "25",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"max_get_size" => array(
 			"friendly_name" => "The Maximum SNMP OID's Per SNMP Get Request",
-			"description" => "The maximum number of snmp get OID's to issue per snmp request.  Increasing this value speeds poller performance over slow links.  The maximum value is 60 OID's.",
+			"description" => "The maximum number of snmp get OID's to issue per snmpbulkwalk request.  Increasing this value speeds poller performance over slow links.  The maximum value is 100 OID's.  Decreasing this value to 0 or 1 will disable snmpbulkwalk",
 			"method" => "textbox",
 			"default" => "10",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"availability_header" => array(
 			"friendly_name" => "Host Availability Settings",
@@ -698,21 +748,24 @@ $settings = array(
 			"description" => "When choosing either TCP or UDP Ping, which port should be checked for availability of the host prior to polling.",
 			"method" => "textbox",
 			"default" => "23",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"ping_timeout" => array(
 			"friendly_name" => "Ping Timeout Value",
 			"description" => "The timeout value to use for host ICMP and UDP pinging.  This host SNMP timeout value applies for SNMP pings.",
 			"method" => "textbox",
 			"default" => "400",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"ping_retries" => array(
 			"friendly_name" => "Ping Retry Count",
 			"description" => "The number of times Cacti will attempt to ping a host before failing.",
 			"method" => "textbox",
 			"default" => "1",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"updown_header" => array(
 			"friendly_name" => "Host Up/Down Settings",
@@ -723,14 +776,16 @@ $settings = array(
 			"description" => "The number of polling intervals a host must be down before logging an error and reporting host as down.",
 			"method" => "textbox",
 			"default" => "2",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			),
 		"ping_recovery_count" => array(
 			"friendly_name" => "Recovery Count",
 			"description" => "The number of polling intervals a host must remain up before returning host to an up status and issuing a notice.",
 			"method" => "textbox",
 			"default" => "3",
-			"max_length" => "10"
+			"max_length" => "10",
+			"size" => "5"
 			)
 		),
 	"authentication" => array(
@@ -745,6 +800,10 @@ $settings = array(
 			"default" => 1,
 			"array" => $auth_methods
 			),
+		"special_users_header" => array(
+			"friendly_name" => "Special Users",
+			"method" => "spacer",
+			),
 		"guest_user" => array(
 			"friendly_name" => "Guest User",
 			"description" => "The name of the guest user for viewing graphs; is \"No User\" by default.",
@@ -761,8 +820,8 @@ $settings = array(
 			"sql" => "select username as id, username as name from user_auth where realm = 0 order by username",
 			"default" => "0"
 			),
-		"ldap_header" => array(
-			"friendly_name" => "LDAP Settings",
+		"ldap_general_header" => array(
+			"friendly_name" => "LDAP General Settings",
 			"method" => "spacer"
 			),
 		"ldap_server" => array(
@@ -773,17 +832,19 @@ $settings = array(
 			),
 		"ldap_port" => array(
 			"friendly_name" => "Port Standard",
-			"description" => "TCP/UDP port for Non SSL comminications.",
+			"description" => "TCP/UDP port for Non SSL communications.",
 			"method" => "textbox",
 			"max_length" => "5",
-			"default" => "389"
+			"default" => "389",
+			"size" => "5"
 			),
 		"ldap_port_ssl" => array(
 			"friendly_name" => "Port SSL",
-			"description" => "TCP/UDP port for SSL comminications.",
+			"description" => "TCP/UDP port for SSL communications.",
 			"method" => "textbox",
 			"max_length" => "5",
-			"default" => "636"
+			"default" => "636",
+			"size" => "5"
 			),
 		"ldap_version" => array(
 			"friendly_name" => "Protocol Version",
@@ -819,6 +880,39 @@ $settings = array(
 			"method" => "textbox",
 			"max_length" => "255"
 			),
+		"ldap_group_require" => array(
+			"friendly_name" => "Require Group Membership",
+			"description" => "Require user to be member of group to authenicate. Group settings must be set for this to work, enabling without proper group settings will cause authenication failure.",
+			"default" => "",
+			"method" => "checkbox"
+			),
+		"ldap_group_header" => array(
+			"friendly_name" => "LDAP Group Settings",
+			"method" => "spacer"
+			),
+		"ldap_group_dn" => array(
+			"friendly_name" => "Group Distingished Name (DN)",
+			"description" => "Distingished Name of the group that user must have membership.",
+			"method" => "textbox",
+			"max_length" => "255"
+			),
+		"ldap_group_attrib" => array(
+			"friendly_name" => "Group Member Attribute",
+			"description" => "Name of the attribute that contains the usernames of the members.",
+			"method" => "textbox",
+			"max_length" => "255"
+			),
+		"ldap_group_member_type" => array(
+			"friendly_name" => "Group Member Type",
+			"description" => "Defines if users use full Distingished Name or just Username in the defined Group Member Attribute.",
+			"method" => "drop_array",
+			"default" => 1,
+			"array" => array( 1 => "Distingished Name", 2 => "Username" )
+			),
+		"ldap_search_base_header" => array(
+			"friendly_name" => "LDAP Specific Search Settings",
+			"method" => "spacer"
+			),
 		"ldap_search_base" => array(
 			"friendly_name" => "Search Base",
 			"description" => "Search base for searching the LDAP directory, such as <i>\"dc=win2kdomain,dc=local\"</i> or <i>\"ou=people,dc=domain,dc=local\"</i>.",
@@ -988,6 +1082,13 @@ $settings_graphs = array(
 			"array" => $graph_tree_views,
 			"default" => "2"
 			),
+		"treeview_graphs_per_page" => array(
+			"friendly_name" => "Graphs Per-Page",
+			"description" => "The number of graphs to display on one page in preview mode.",
+			"method" => "drop_array",
+			"default" => "10",
+			"array" => $graphs_per_page
+			),
 		"default_dual_pane_width" => array(
 			"friendly_name" => "Dual Pane Tree Width",
 			"description" => "When choosing dual pane Tree View, what width should the tree occupy in pixels.",
@@ -1000,24 +1101,30 @@ $settings_graphs = array(
 			"description" => "Choose whether to expand the graph templates used for a host on the dual pane tree.",
 			"method" => "checkbox",
 			"default" => ""
+			),
+		"show_graph_title" => array(
+			"friendly_name" => "Show Graph Title",
+			"description" => "Display the graph title on the page so that it may be searched using the browser.",
+			"method" => "checkbox",
+			"default" => ""
 			)
 		),
 	"preview" => array(
 		"preview_graphs_per_page" => array(
 			"friendly_name" => "Graphs Per-Page",
 			"description" => "The number of graphs to display on one page in preview mode.",
-			"method" => "textbox",
+			"method" => "drop_array",
 			"default" => "10",
-			"max_length" => "5"
+			"array" => $graphs_per_page
 			)
 		),
 	"list" => array(
 		"list_graphs_per_page" => array(
 			"friendly_name" => "Graphs Per-Page",
 			"description" => "The number of graphs to display on one page in list view mode.",
-			"method" => "textbox",
+			"method" => "drop_array",
 			"default" => "30",
-			"max_length" => "5"
+			"array" => $graphs_per_page
 			)
 		),
 	"fonts" => array(
@@ -1038,7 +1145,7 @@ $settings_graphs = array(
 		"title_font" => array(
 			"friendly_name" => "Title Font File",
 			"description" => "The font file to use for Graph Titles",
-			"method" => "filepath",
+			"method" => "font",
 			"max_length" => "100"
 			),
 		"legend_size" => array(
@@ -1051,7 +1158,7 @@ $settings_graphs = array(
 		"legend_font" => array(
 			"friendly_name" => "Legend Font File",
 			"description" => "The font file to be used for Graph Legend items",
-			"method" => "filepath",
+			"method" => "font",
 			"max_length" => "100"
 			),
 		"axis_size" => array(
@@ -1064,7 +1171,7 @@ $settings_graphs = array(
 		"axis_font" => array(
 			"friendly_name" => "Axis Font File",
 			"description" => "The font file to be used for Graph Axis items",
-			"method" => "filepath",
+			"method" => "font",
 			"max_length" => "100"
 			),
 		"unit_size" => array(
@@ -1077,10 +1184,12 @@ $settings_graphs = array(
 		"unit_font" => array(
 			"friendly_name" => "Unit Font File",
 			"description" => "The font file to be used for Graph Unit items",
-			"method" => "filepath",
+			"method" => "font",
 			"max_length" => "100"
 			)
 		)
 	);
 
+api_plugin_hook('config_settings');
+
 ?>
