@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -25,6 +25,8 @@
 include("./include/auth.php");
 include("./include/top_header.php");
 
+api_plugin_hook('console_before');
+
 ?>
 <table width="100%" align="center">
 	<tr>
@@ -46,6 +48,8 @@ include("./include/top_header.php");
 
 <?php
 
+api_plugin_hook('console_after');
+
 include("./include/bottom_footer.php");
 
 ?>
