@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -27,7 +27,13 @@ include("../include/global.php");
 /* allow the upgrade script to run for as long as it needs to */
 ini_set("max_execution_time", "0");
 
-$cacti_versions = array("0.8", "0.8.1", "0.8.2", "0.8.2a", "0.8.3", "0.8.3a", "0.8.4", "0.8.5", "0.8.5a", "0.8.6", "0.8.6a", "0.8.6b", "0.8.6c", "0.8.6d", "0.8.6e", "0.8.6f", "0.8.6g", "0.8.6h", "0.8.6i", "0.8.6j", "0.8.7", "0.8.7a");
+/* verify all required php extensions */
+if (!verify_php_extensions()) {exit;}
+
+$cacti_versions = array("0.8", "0.8.1", "0.8.2", "0.8.2a", "0.8.3", "0.8.3a", "0.8.4", "0.8.5", "0.8.5a",
+	"0.8.6", "0.8.6a", "0.8.6b", "0.8.6c", "0.8.6d", "0.8.6e", "0.8.6f", "0.8.6g", "0.8.6h", "0.8.6i", "0.8.6j", "0.8.6k",
+	"0.8.7", "0.8.7a", "0.8.7b", "0.8.7c", "0.8.7d", "0.8.7e", "0.8.7f", "0.8.7g", "0.8.7h", "0.8.7i",
+	"0.8.8", "0.8.8a");
 
 $old_cacti_version = db_fetch_cell("select cacti from version");
 
@@ -37,9 +43,9 @@ $old_version_index = array_search($old_cacti_version, $cacti_versions);
 /* do a version check */
 if ($old_cacti_version == $config["cacti_version"]) {
 	print "	<p style='font-family: Verdana, Arial; font-size: 16px; font-weight: bold; color: red;'>Error</p>
-		This installation is already up-to-date. Click <a href='../index.php'>here</a> to use cacti.</p>";
+		<p style='font-family: Verdana, Arial; font-size: 12px;'>This installation is already up-to-date. Click <a href='../index.php'>here</a> to use cacti.</p>";
 	exit;
-}elseif (ereg("^0\.6", $old_cacti_version)) {
+}elseif (preg_match("/^0\.6/", $old_cacti_version)) {
 	print "	<p style='font-family: Verdana, Arial; font-size: 16px; font-weight: bold; color: red;'>Error</p>
 		<p style='font-family: Verdana, Arial; font-size: 12px;'>You are attempting to install cacti " . $config["cacti_version"] . "
 		onto a 0.6.x database. To continue, you must create a new database, import 'cacti.sql' into it, and
@@ -56,6 +62,23 @@ if ($old_cacti_version == $config["cacti_version"]) {
 	exit;
 }
 
+function verify_php_extensions() {
+	$extensions = array("session", "sockets", "mysql", "xml");
+	$ok = true;
+	$missing_extension = "	<p style='font-family: Verdana, Arial; font-size: 16px; font-weight: bold; color: red;'>Error</p>
+							<p style='font-family: Verdana, Arial; font-size: 12px;'>The following PHP extensions are missing:</p><ul>";
+	foreach ($extensions as $extension) {
+		if (!extension_loaded($extension)){
+			$ok = false;
+			$missing_extension .= "<li style='font-family: Verdana, Arial; font-size: 12px;'>$extension</li>";
+		}
+	}
+	if (!$ok) {
+		print $missing_extension . "</ul><p style='font-family: Verdana, Arial; font-size: 12px;'>Please install those PHP extensions and retry</p>";
+	}
+	return $ok;
+}
+
 function db_install_execute($cacti_version, $sql) {
 	$sql_install_cache = (isset($_SESSION["sess_sql_install_cache"]) ? $_SESSION["sess_sql_install_cache"] : array());
 
@@ -102,7 +125,7 @@ if ($config["cacti_server_os"] == "unix") {
 		$input["path_rrdtool"]["default"] = "/usr/local/bin/rrdtool";
 	}
 }elseif ($config["cacti_server_os"] == "win32") {
-	$which_php = find_best_path("rrdtool.exe");
+	$which_rrdtool = find_best_path("rrdtool.exe");
 
 	if (config_value_exists("path_rrdtool")) {
 		$input["path_rrdtool"]["default"] = read_config_option("path_rrdtool");
@@ -259,12 +282,16 @@ if ((file_exists($input["path_rrdtool"]["default"])) && (($config["cacti_server_
 
 	$out_array = array();
 
-	exec($input["path_rrdtool"]["default"], $out_array);
+	exec("\"" . $input["path_rrdtool"]["default"] . "\"", $out_array);
 
 	if (sizeof($out_array) > 0) {
-		if (ereg("^RRDtool 1\.2", $out_array[0])) {
+		if (preg_match("/^RRDtool 1\.4/", $out_array[0])) {
+			$input["rrdtool_version"]["default"] = "rrd-1.4.x";
+		}else if (preg_match("/^RRDtool 1\.3\./", $out_array[0])) {
+			$input["rrdtool_version"]["default"] = "rrd-1.3.x";
+		}else if (preg_match("/^RRDtool 1\.2\./", $out_array[0])) {
 			$input["rrdtool_version"]["default"] = "rrd-1.2.x";
-		}else if (ereg("^RRDtool 1\.0\.", $out_array[0])) {
+		}else if (preg_match("/^RRDtool 1\.0\./", $out_array[0])) {
 			$input["rrdtool_version"]["default"] = "rrd-1.0.x";
 		}
 	}
@@ -328,10 +355,6 @@ if ($_REQUEST["step"] == "4") {
 		run_data_query($host_id, 6);
 	}
 
-	/* it's always a good idea to re-populate the poller cache to make sure everything is refreshed and
-	up-to-date */
-	repopulate_poller_cache();
-
 	db_execute("delete from version");
 	db_execute("insert into version (cacti) values ('" . $config["cacti_version"] . "')");
 
@@ -395,14 +418,46 @@ if ($_REQUEST["step"] == "4") {
 		}elseif ($cacti_versions[$i] == "0.8.7a") {
 			include ("0_8_7_to_0_8_7a.php");
 			upgrade_to_0_8_7a();
+		}elseif ($cacti_versions[$i] == "0.8.7b") {
+			include ("0_8_7a_to_0_8_7b.php");
+			upgrade_to_0_8_7b();
+		}elseif ($cacti_versions[$i] == "0.8.7c") {
+			include ("0_8_7b_to_0_8_7c.php");
+			upgrade_to_0_8_7c();
+		}elseif ($cacti_versions[$i] == "0.8.7d") {
+			include ("0_8_7c_to_0_8_7d.php");
+			upgrade_to_0_8_7d();
+		}elseif ($cacti_versions[$i] == "0.8.7e") {
+			include ("0_8_7d_to_0_8_7e.php");
+			upgrade_to_0_8_7e();
+		}elseif ($cacti_versions[$i] == "0.8.7f") {
+			include ("0_8_7e_to_0_8_7f.php");
+			upgrade_to_0_8_7f();
+		}elseif ($cacti_versions[$i] == "0.8.7g") {
+			include ("0_8_7f_to_0_8_7g.php");
+			upgrade_to_0_8_7g();
+		}elseif ($cacti_versions[$i] == "0.8.7h") {
+			include ("0_8_7g_to_0_8_7h.php");
+			upgrade_to_0_8_7h();
+		}elseif ($cacti_versions[$i] == "0.8.7i") {
+			include ("0_8_7h_to_0_8_7i.php");
+			upgrade_to_0_8_7i();
+		}elseif ($cacti_versions[$i] == "0.8.8") {
+			include ("0_8_7i_to_0_8_8.php");
+			upgrade_to_0_8_8();
+		}elseif ($cacti_versions[$i] == "0.8.8a") {
+			include ("0_8_8_to_0_8_8a.php");
+			upgrade_to_0_8_8a();
 		}
 	}
 }
 
 ?>
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <head>
 	<title>cacti</title>
+	<meta http-equiv="Content-Type" content="text/html;charset=utf-8">
 	<style>
 	<!--
 		BODY,TABLE,TR,TD
@@ -430,7 +485,7 @@ if ($_REQUEST["step"] == "4") {
 <form method="post" action="index.php">
 
 <table width="500" align="center" cellpadding="1" cellspacing="0" border="0" bgcolor="#104075">
-	<tr bgcolor="#FFFFFF" height="10">
+	<tr bgcolor="#FFFFFF" style="height:10px;">
 		<td>&nbsp;</td>
 	</tr>
 	<tr>
