@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -25,15 +25,16 @@
 /* api_device_remove - removes a device
    @arg $device_id - the id of the device to remove */
 function api_device_remove($device_id) {
-	db_execute("delete from host where id=$device_id");
-	db_execute("delete from host_graph where host_id=$device_id");
-	db_execute("delete from host_snmp_query where host_id=$device_id");
-	db_execute("delete from host_snmp_cache where host_id=$device_id");
-	db_execute("delete from poller_item where host_id=$device_id");
-	db_execute("delete from poller_reindex where host_id=$device_id");
+	db_execute("delete from host             where id=$device_id");
+	db_execute("delete from host_graph       where host_id=$device_id");
+	db_execute("delete from host_snmp_query  where host_id=$device_id");
+	db_execute("delete from host_snmp_cache  where host_id=$device_id");
+	db_execute("delete from poller_item      where host_id=$device_id");
+	db_execute("delete from poller_reindex   where host_id=$device_id");
+	db_execute("delete from poller_command   where command like '$device_id:%'");
 	db_execute("delete from graph_tree_items where host_id=$device_id");
 
-	db_execute("update data_local set host_id=0 where host_id=$device_id");
+	db_execute("update data_local  set host_id=0 where host_id=$device_id");
 	db_execute("update graph_local set host_id=0 where host_id=$device_id");
 }
 
@@ -52,19 +53,23 @@ function api_device_remove_multi($device_ids) {
 				$devices_to_delete .= ", " . $device_id;
 			}
 
+			/* poller commands go one at a time due to trashy logic */
+			db_execute("DELETE FROM poller_item      WHERE host_id=$device_id");
+			db_execute("DELETE FROM poller_reindex   WHERE host_id=$device_id");
+			db_execute("DELETE FROM poller_command   WHERE command like '$device_id:%'");
+
 			$i++;
 		}
 
-		db_execute("DELETE FROM host WHERE id IN ($devices_to_delete)");
-		db_execute("DELETE FROM host_graph WHERE host_id IN ($devices_to_delete)");
-		db_execute("DELETE FROM host_snmp_query WHERE host_id IN ($devices_to_delete)");
-		db_execute("DELETE FROM host_snmp_cache WHERE host_id IN ($devices_to_delete)");
-		db_execute("DELETE FROM poller_item WHERE host_id IN ($devices_to_delete)");
-		db_execute("DELETE FROM poller_reindex WHERE host_id IN ($devices_to_delete)");
+		db_execute("DELETE FROM host             WHERE id IN ($devices_to_delete)");
+		db_execute("DELETE FROM host_graph       WHERE host_id IN ($devices_to_delete)");
+		db_execute("DELETE FROM host_snmp_query  WHERE host_id IN ($devices_to_delete)");
+		db_execute("DELETE FROM host_snmp_cache  WHERE host_id IN ($devices_to_delete)");
+
 		db_execute("DELETE FROM graph_tree_items WHERE host_id IN ($devices_to_delete)");
 
 		/* for people who choose to leave data sources around */
-		db_execute("UPDATE data_local SET host_id=0 WHERE host_id IN ($devices_to_delete)");
+		db_execute("UPDATE data_local  SET host_id=0 WHERE host_id IN ($devices_to_delete)");
 		db_execute("UPDATE graph_local SET host_id=0 WHERE host_id IN ($devices_to_delete)");
 
 	}
@@ -89,7 +94,11 @@ function api_device_gt_remove($device_id, $graph_template_id) {
 function api_device_save($id, $host_template_id, $description, $hostname, $snmp_community, $snmp_version,
 	$snmp_username, $snmp_password, $snmp_port, $snmp_timeout, $disabled,
 	$availability_method, $ping_method, $ping_port, $ping_timeout, $ping_retries,
-	$notes, $snmp_auth_protocol, $snmp_priv_passphrase, $snmp_priv_protocol, $snmp_context, $max_oids) {
+	$notes, $snmp_auth_protocol, $snmp_priv_passphrase, $snmp_priv_protocol, $snmp_context, $max_oids, $device_threads) {
+	global $config;
+	include_once($config["base_path"]."/lib/utility.php");
+	include_once($config["base_path"]."/lib/variables.php");
+	include_once($config["base_path"]."/lib/data_query.php");
 
 	/* fetch some cache variables */
 	if (empty($id)) {
@@ -101,23 +110,30 @@ function api_device_save($id, $host_template_id, $description, $hostname, $snmp_
 	$save["id"] = $id;
 	$save["host_template_id"]     = form_input_validate($host_template_id, "host_template_id", "^[0-9]+$", false, 3);
 	$save["description"]          = form_input_validate($description, "description", "", false, 3);
-	$save["hostname"]             = form_input_validate($hostname, "hostname", "", false, 3);
+	$save["hostname"]             = form_input_validate(trim($hostname), "hostname", "", false, 3);
 	$save["notes"]                = form_input_validate($notes, "notes", "", true, 3);
 
 	$save["snmp_version"]         = form_input_validate($snmp_version, "snmp_version", "", true, 3);
 	$save["snmp_community"]       = form_input_validate($snmp_community, "snmp_community", "", true, 3);
 
-	$save["snmp_username"]        = form_input_validate($snmp_username, "snmp_username", "", true, 3);
-	$save["snmp_password"]        = form_input_validate($snmp_password, "snmp_password", "", true, 3);
-	$save["snmp_auth_protocol"]   = form_input_validate($snmp_auth_protocol, "snmp_auth_protocol", "", true, 3);
-	$save["snmp_priv_passphrase"] = form_input_validate($snmp_priv_passphrase, "snmp_priv_passphrase", "", true, 3);
-	$save["snmp_priv_protocol"]   = form_input_validate($snmp_priv_protocol, "snmp_priv_protocol", "", true, 3);
-	$save["snmp_context"]         = form_input_validate($snmp_context, "snmp_context", "", true, 3);
+	if ($save["snmp_version"] == 3) {
+		$save["snmp_username"]        = form_input_validate($snmp_username, "snmp_username", "", true, 3);
+		$save["snmp_password"]        = form_input_validate($snmp_password, "snmp_password", "", true, 3);
+		$save["snmp_auth_protocol"]   = form_input_validate($snmp_auth_protocol, "snmp_auth_protocol", "^MD5|SHA$", true, 3);
+		$save["snmp_priv_passphrase"] = form_input_validate($snmp_priv_passphrase, "snmp_priv_passphrase", "", true, 3);
+		$save["snmp_priv_protocol"]   = form_input_validate($snmp_priv_protocol, "snmp_priv_protocol", "^DES|AES128$", true, 3);
+		$save["snmp_context"]         = form_input_validate($snmp_context, "snmp_context", "", true, 3);
+	} else {
+		$save["snmp_username"]        = "";
+		$save["snmp_password"]        = "";
+	}
 
 	$save["snmp_port"]            = form_input_validate($snmp_port, "snmp_port", "^[0-9]+$", false, 3);
 	$save["snmp_timeout"]         = form_input_validate($snmp_timeout, "snmp_timeout", "^[0-9]+$", false, 3);
 
-	$save["disabled"]             = form_input_validate($disabled, "disabled", "", true, 3);
+	/* disabled = "on"   => regexp "^on$"
+	 * not disabled = "" => no regexp, but allow nulls */
+	$save["disabled"]             = form_input_validate($disabled, "disabled", "^on$", true, 3);
 
 	$save["availability_method"]  = form_input_validate($availability_method, "availability_method", "^[0-9]+$", false, 3);
 	$save["ping_method"]          = form_input_validate($ping_method, "ping_method", "^[0-9]+$", false, 3);
@@ -125,6 +141,9 @@ function api_device_save($id, $host_template_id, $description, $hostname, $snmp_
 	$save["ping_timeout"]         = form_input_validate($ping_timeout, "ping_timeout", "^[0-9]+$", true, 3);
 	$save["ping_retries"]         = form_input_validate($ping_retries, "ping_retries", "^[0-9]+$", true, 3);
 	$save["max_oids"]             = form_input_validate($max_oids, "max_oids", "^[0-9]+$", true, 3);
+	$save["device_threads"]       = form_input_validate($device_threads, "device_threads", "^[0-9]+$", true, 3);
+
+	$save = api_plugin_hook_function('api_device_save', $save);
 
 	$host_id = 0;
 
@@ -153,7 +172,7 @@ function api_device_save($id, $host_template_id, $description, $hostname, $snmp_
 
 			if (sizeof($snmp_queries) > 0) {
 			foreach ($snmp_queries as $snmp_query) {
-				db_execute("replace into host_snmp_query (host_id,snmp_query_id,reindex_method) values ($host_id," . $snmp_query["snmp_query_id"] . "," . DATA_QUERY_AUTOINDEX_BACKWARDS_UPTIME . ")");
+				db_execute("replace into host_snmp_query (host_id,snmp_query_id,reindex_method) values ($host_id," . $snmp_query["snmp_query_id"] . "," . read_config_option("reindex_method") . ")");
 
 				/* recache snmp data */
 				run_data_query($host_id, $snmp_query["snmp_query_id"]);
@@ -165,11 +184,16 @@ function api_device_save($id, $host_template_id, $description, $hostname, $snmp_
 			if (sizeof($graph_templates) > 0) {
 			foreach ($graph_templates as $graph_template) {
 				db_execute("replace into host_graph (host_id,graph_template_id) values ($host_id," . $graph_template["graph_template_id"] . ")");
+				api_plugin_hook_function('add_graph_template_to_host', array("host_id" => $host_id, "graph_template_id" => $graph_template["graph_template_id"]));
 			}
 			}
 		}
 	}
 
+	# now that we have the id of the new host, we may plugin postprocessing code
+	$save["id"] = $host_id;
+	api_plugin_hook_function('api_device_new', $save);
+
 	return $host_id;
 }
 
