@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -26,9 +26,7 @@
    @arg $cdef_item_id - the id of the individual cdef item
    @returns - a text-based representation of the cdef item */
 function get_cdef_item_name($cdef_item_id) 	{
-	global $config;
-
-	include($config["include_path"] . "/global_arrays.php");
+	global $config, $cdef_functions, $cdef_operators;
 
 	$cdef_item = db_fetch_row("select type,value from cdef_items where id=$cdef_item_id");
 	$current_cdef_value = $cdef_item["value"];
