@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,22 +23,20 @@
 */
 
 function run_data_query($host_id, $snmp_query_id) {
-	global $config;
+	global $config, $input_types;
 
 	include_once($config["library_path"] . "/poller.php");
 	include_once($config["library_path"] . "/utility.php");
 
 	debug_log_insert("data_query", "Running data query [$snmp_query_id].");
 	$type_id = db_fetch_cell("select data_input.type_id from (snmp_query,data_input) where snmp_query.data_input_id=data_input.id and snmp_query.id=$snmp_query_id");
+	if (isset($input_types[$type_id])) debug_log_insert("data_query", "Found type = '" . $type_id . "' [" . $input_types[$type_id] . "].");
 
 	if ($type_id == DATA_INPUT_TYPE_SNMP_QUERY) {
-		debug_log_insert("data_query", "Found type = '3' [snmp query].");
 		$result = query_snmp_host($host_id, $snmp_query_id);
 	}elseif ($type_id == DATA_INPUT_TYPE_SCRIPT_QUERY) {
-		debug_log_insert("data_query", "Found type = '4 '[script query].");
 		$result = query_script_host($host_id, $snmp_query_id);
 	}elseif ($type_id == DATA_INPUT_TYPE_QUERY_SCRIPT_SERVER) {
-		debug_log_insert("data_query", "Found type = '6 '[script query].");
 		$result = query_script_host($host_id, $snmp_query_id);
 	}else{
 		debug_log_insert("data_query", "Unknown type = '$type_id'");
@@ -56,26 +54,37 @@ function run_data_query($host_id, $snmp_query_id) {
 	/* update the poller cache */
 	update_poller_cache_from_query($host_id, $snmp_query_id);
 
+	api_plugin_hook_function('run_data_query', array("host_id" => $host_id, "snmp_query_id" => $snmp_query_id));
+
 	return (isset($result) ? $result : true);
 }
 
 function get_data_query_array($snmp_query_id) {
-	global $config;
+	global $config, $data_query_xml_arrays;
 
 	include_once($config["library_path"] . "/xml.php");
 
-	$xml_file_path = db_fetch_cell("select xml_path from snmp_query where id=$snmp_query_id");
-	$xml_file_path = str_replace("<path_cacti>", $config["base_path"], $xml_file_path);
+	/* load the array into memory if it hasn't been done yet */
+	if (!isset($data_query_xml_arrays[$snmp_query_id])) {
+		$xml_file_path = db_fetch_cell("select xml_path from snmp_query where id=$snmp_query_id");
+		$xml_file_path = str_replace("<path_cacti>", $config["base_path"], $xml_file_path);
 
-	if (!file_exists($xml_file_path)) {
-		debug_log_insert("data_query", "Could not find data query XML file at '$xml_file_path'");
-		return false;
+		if (!file_exists($xml_file_path)) {
+			debug_log_insert("data_query", "Could not find data query XML file at '$xml_file_path'");
+			return false;
+		}
+
+		debug_log_insert("data_query", "Found data query XML file at '$xml_file_path'");
+
+		$data = implode("",file($xml_file_path));
+
+		$xml_data = xml2array($data);
+
+		/* store the array value to the global array for future reference */
+		$data_query_xml_arrays[$snmp_query_id] = $xml_data;
 	}
 
-	debug_log_insert("data_query", "Found data query XML file at '$xml_file_path'");
-
-	$data = implode("",file($xml_file_path));
-	return xml2array($data);
+	return $data_query_xml_arrays[$snmp_query_id];
 }
 
 function query_script_host($host_id, $snmp_query_id) {
@@ -89,18 +98,49 @@ function query_script_host($host_id, $snmp_query_id) {
 
 	debug_log_insert("data_query", "XML file parsed ok.");
 
+	/* are we talking to script server? */
 	if (isset($script_queries["script_server"])) {
-		$script_queries["script_path"] = "|path_php_binary| -q " . $script_queries["script_path"];
+		$script_queries["script_path"] = "\"|path_php_binary|\" -q " . $script_queries["script_path"];
 	}
 
+	if (!verify_index_order($script_queries)) {
+		debug_log_insert("data_query", "Invalid field &lt;index_order&gt;" . $script_queries["index_order"] . "&lt;/index_order&gt;");
+		debug_log_insert("data_query", "Must contain &lt;direction&gt;input&lt;/direction&gt; fields only");
+		return false;
+	}
+
+	/* provide data for arg_num_indexes, if given */
+	if (isset($script_queries["arg_num_indexes"])) {
+		$script_path = get_script_query_path((isset($script_queries["arg_prepend"]) ? $script_queries["arg_prepend"] . " ": "") . $script_queries["arg_num_indexes"], $script_queries["script_path"], $host_id);
+
+		/* fetch specified index at specified OID */
+		$script_num_index_array = exec_into_array($script_path);
+
+		debug_log_insert("data_query", "Executing script for num of indexes" . " '$script_path'");
+		for ($i=0;($i<sizeof($script_num_index_array));$i++) {
+			debug_log_insert("data_query", "Found number of indexes: " . $script_num_index_array[$i]);
+		}
+	} else {
+		if (isset($script_queries["script_server"])) {
+			debug_log_insert("data_query", "&lt;arg_num_indexes&gt; missing in XML file, 'Index Count Changed' not supported");
+		} else {
+			debug_log_insert("data_query", "&lt;arg_num_indexes&gt; missing in XML file, 'Index Count Changed' emulated by counting arg_index entries");
+		}
+	}
+
+	/* provide data for index, mandatory */
 	$script_path = get_script_query_path((isset($script_queries["arg_prepend"]) ? $script_queries["arg_prepend"] . " ": "") . $script_queries["arg_index"], $script_queries["script_path"], $host_id);
 
-	/* fetch specified index at specified OID */
+	/* fetch specified index */
 	$script_index_array = exec_into_array($script_path);
 
-	debug_log_insert("data_query", "Executing script for list of indexes '$script_path'");
+	debug_log_insert("data_query", "Executing script for list of indexes" . " '$script_path' " . "Index Count: " . sizeof($script_index_array));
+	for ($i=0;($i<sizeof($script_index_array));$i++) {
+		debug_log_insert("data_query", "Found index: " . $script_index_array[$i]);
+	}
 
-	db_execute("delete from host_snmp_cache where host_id=$host_id and snmp_query_id=$snmp_query_id");
+	/* set an array to host all updates */
+	$output_array = array();
 
 	while (list($field_name, $field_array) = each($script_queries["fields"])) {
 		if ($field_array["direction"] == "input") {
@@ -115,9 +155,7 @@ function query_script_host($host_id, $snmp_query_id) {
 					$script_index = $matches[1];
 					$field_value = $matches[2];
 
-					db_execute("replace into host_snmp_cache
-						(host_id,snmp_query_id,field_name,field_value,snmp_index,oid)
-						values ($host_id,$snmp_query_id,'$field_name','$field_value','$script_index','')");
+					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $field_value, $script_index, '');
 
 					debug_log_insert("data_query", "Found item [$field_name='$field_value'] index: $script_index");
 				}
@@ -125,6 +163,10 @@ function query_script_host($host_id, $snmp_query_id) {
 		}
 	}
 
+	if (sizeof($output_array)) {
+		data_query_update_host_cache_from_buffer($host_id, $snmp_query_id, $output_array);
+	}
+
 	return true;
 }
 
@@ -144,7 +186,9 @@ function query_snmp_host($host_id, $snmp_query_id) {
 		snmp_priv_protocol,
 		snmp_context,
 		snmp_port,
-		snmp_timeout
+		snmp_timeout,
+		ping_retries,
+		max_oids
 		FROM host
 		WHERE id='$host_id'");
 
@@ -163,18 +207,42 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 	debug_log_insert("data_query", "XML file parsed ok.");
 
+	if (!verify_index_order($snmp_queries)) {
+		debug_log_insert("data_query", "Invalid field &lt;index_order&gt;" . $snmp_queries["index_order"] . "&lt;/index_order&gt;");
+		debug_log_insert("data_query", "Must contain &lt;direction&gt;input&lt;/direction&gt; fields only");
+		return false;
+	}
+
+	/* provide data for oid_num_indexes, if given */
+	if (isset($snmp_queries["oid_num_indexes"])) {
+		$snmp_num_indexes = cacti_snmp_get($host["hostname"], $host["snmp_community"], $snmp_queries["oid_num_indexes"],
+										$host["snmp_version"], $host["snmp_username"], $host["snmp_password"],
+										$host["snmp_auth_protocol"], $host["snmp_priv_passphrase"], $host["snmp_priv_protocol"],
+										$host["snmp_context"], $host["snmp_port"], $host["snmp_timeout"],
+										$host["ping_retries"], $host["max_oids"], SNMP_WEBUI);
+
+		debug_log_insert("data_query", "Executing SNMP get for num of indexes @ '" . $snmp_queries["oid_num_indexes"] . "' Index Count: " . $snmp_num_indexes);
+	} else {
+		debug_log_insert("data_query", "&lt;oid_num_indexes&gt; missing in XML file, 'Index Count Changed' emulated by counting oid_index entries");
+	}
+
 	/* fetch specified index at specified OID */
-	$snmp_index = cacti_snmp_walk($host["hostname"], $host["snmp_community"], $snmp_queries["oid_index"],
+	$snmp_indexes = cacti_snmp_walk($host["hostname"], $host["snmp_community"], $snmp_queries["oid_index"],
 		$host["snmp_version"], $host["snmp_username"], $host["snmp_password"],
 		$host["snmp_auth_protocol"], $host["snmp_priv_passphrase"], $host["snmp_priv_protocol"],
-		$host["snmp_context"], $host["snmp_port"], $host["snmp_timeout"], read_config_option("snmp_retries"), SNMP_WEBUI);
+		$host["snmp_context"], $host["snmp_port"], $host["snmp_timeout"], $host["ping_retries"], $host["max_oids"], SNMP_WEBUI);
 
-	debug_log_insert("data_query", "Executing SNMP walk for list of indexes @ '" . $snmp_queries["oid_index"] . "'");
+	debug_log_insert("data_query", "Executing SNMP walk for list of indexes @ '" . $snmp_queries["oid_index"] . "' Index Count: " . sizeof($snmp_indexes));
 
 	/* no data found; get out */
-	if (!$snmp_index) {
+	if (!sizeof($snmp_indexes)) {
 		debug_log_insert("data_query", "No SNMP data returned");
 		return false;
+	} else {
+		/* show list of indices found */
+		for ($i=0; $i<sizeof($snmp_indexes); $i++) {
+			debug_log_insert("data_query", "Index found at OID: '" . $snmp_indexes[$i]["oid"] . "' value: '" . $snmp_indexes[$i]["value"] . "'");
+		}
 	}
 
 	/* the last octet of the oid is the index by default */
@@ -184,28 +252,29 @@ function query_snmp_host($host_id, $snmp_query_id) {
 	if (isset($snmp_queries["oid_index_parse"])) {
 		$index_parse_regexp = str_replace("OID/REGEXP:", "", $snmp_queries["oid_index_parse"]);
 
-		for ($i=0; $i<sizeof($snmp_index); $i++) {
-			$snmp_index[$i]["value"] = ereg_replace($index_parse_regexp, "\\1", $snmp_index[$i]["oid"]);
+		for ($i=0; $i<sizeof($snmp_indexes); $i++) {
+			$snmp_indexes[$i]["value"] = preg_replace('/' . $index_parse_regexp . '/', "\\1", $snmp_indexes[$i]["oid"]);
+			debug_log_insert("data_query", "index_parse at OID: '" . $snmp_indexes[$i]["oid"] . "' results: '" . $snmp_indexes[$i]["value"] . "'");
 		}
 	}
 
-	db_execute("delete from host_snmp_cache where host_id='$host_id' and snmp_query_id='$snmp_query_id'");
+	/* set an array to host all updates */
+	$output_array = array();
 
 	while (list($field_name, $field_array) = each($snmp_queries["fields"])) {
 		if ((!isset($field_array["oid"])) && ($field_array["source"] == "index")) {
-			for ($i=0; $i<sizeof($snmp_index); $i++) {
-				debug_log_insert("data_query", "Inserting index data [value='" . $snmp_index[$i]["value"] . "']");
+			for ($i=0; $i<sizeof($snmp_indexes); $i++) {
+				debug_log_insert("data_query", "Inserting index data for field '" . $field_name . "' [value='" . $snmp_indexes[$i]["value"] . "']");
 
-				db_execute("replace into host_snmp_cache
-					(host_id, snmp_query_id, field_name, field_value, snmp_index, oid)
-					values ('$host_id','$snmp_query_id','$field_name','" . $snmp_index[$i]["value"] . "','" . $snmp_index[$i]["value"] . "','')");
+				$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $snmp_indexes[$i]["value"], $snmp_indexes[$i]["value"], '');
 			}
 		}else if (($field_array["method"] == "get") && ($field_array["direction"] == "input")) {
 			debug_log_insert("data_query", "Located input field '$field_name' [get]");
 
 			if ($field_array["source"] == "value") {
-				for ($i=0; $i<sizeof($snmp_index); $i++) {
-					$oid = $field_array["oid"] .  "." . $snmp_index[$i]["value"];
+				for ($i=0; $i<sizeof($snmp_indexes); $i++) {
+					$oid = $field_array["oid"] .  "." . $snmp_indexes[$i]["value"];
+					$oid .= isset($field_array["oid_suffix"]) ? ("." . $field_array["oid_suffix"]) : "";
 
 					$value = cacti_snmp_get($host["hostname"], $host["snmp_community"], $oid,
 						$host["snmp_version"], $host["snmp_username"], $host["snmp_password"],
@@ -214,9 +283,7 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 					debug_log_insert("data_query", "Executing SNMP get for data @ '$oid' [value='$value']");
 
-					db_execute("replace into host_snmp_cache
-						(host_id,snmp_query_id,field_name,field_value,snmp_index,oid)
-						values ('$host_id','$snmp_query_id','$field_name','$value','" . $snmp_index[$i]["value"] . "','$oid')");
+					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $value, $snmp_indexes[$i]["value"],$oid);
 				}
 			}
 		}else if (($field_array["method"] == "walk") && ($field_array["direction"] == "input")) {
@@ -226,13 +293,13 @@ function query_snmp_host($host_id, $snmp_query_id) {
 			$snmp_data = cacti_snmp_walk($host["hostname"], $host["snmp_community"], $field_array["oid"],
 				$host["snmp_version"], $host["snmp_username"], $host["snmp_password"],
 				$host["snmp_auth_protocol"], $host["snmp_priv_passphrase"], $host["snmp_priv_protocol"],
-				$host["snmp_context"], $host["snmp_port"], $host["snmp_timeout"], read_config_option("snmp_retries"), SNMP_WEBUI);
+				$host["snmp_context"], $host["snmp_port"], $host["snmp_timeout"], $host["ping_retries"], $host["max_oids"], SNMP_WEBUI);
 
 			debug_log_insert("data_query", "Executing SNMP walk for data @ '" . $field_array["oid"] . "'");
 
 			if ($field_array["source"] == "value") {
 				for ($i=0; $i<sizeof($snmp_data); $i++) {
-					$snmp_index = ereg_replace($index_parse_regexp, "\\1", $snmp_data[$i]["oid"]);
+					$snmp_index = preg_replace('/' . (isset($field_array["oid_index_parse"]) ? $field_array["oid_index_parse"] : $index_parse_regexp) . '/', "\\1", $snmp_data[$i]["oid"]);
 
 					$oid = $field_array["oid"] . ".$snmp_index";
 
@@ -243,6 +310,9 @@ function query_snmp_host($host_id, $snmp_query_id) {
 						}else if ((substr_count(strtolower($snmp_data[$i]["value"]), "up")) ||
 							($snmp_data[$i]["value"] == "1")) {
 							$snmp_data[$i]["value"] = "Up";
+						}else if ((substr_count(strtolower($snmp_data[$i]["value"]), "notpresent")) ||
+							($snmp_data[$i]["value"] == "6")) {
+							$snmp_data[$i]["value"] = "notPresent";
 						}else{
 							$snmp_data[$i]["value"] = "Testing";
 						}
@@ -250,16 +320,14 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 					debug_log_insert("data_query", "Found item [$field_name='" . $snmp_data[$i]["value"] . "'] index: $snmp_index [from value]");
 
-					db_execute("replace into host_snmp_cache
-						(host_id,snmp_query_id,field_name,field_value,snmp_index,oid)
-						values ('$host_id','$snmp_query_id','$field_name','" . $snmp_data[$i]["value"] . "','$snmp_index','$oid')");
+					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $snmp_data[$i]["value"] , $snmp_index, $oid);
 				}
 			}elseif (substr($field_array["source"], 0, 11) == "OID/REGEXP:") {
 				for ($i=0; $i<sizeof($snmp_data); $i++) {
-					$value = ereg_replace(str_replace("OID/REGEXP:", "", $field_array["source"]), "\\1", $snmp_data[$i]["oid"]);
+					$value = preg_replace('/' . str_replace("OID/REGEXP:", "", $field_array["source"]) . '/', "\\1", $snmp_data[$i]["oid"]);
 
 					if (isset($snmp_queries["oid_index_parse"])) {
-						$snmp_index = ereg_replace($index_parse_regexp, "\\1", $snmp_data[$i]["oid"]);
+						$snmp_index = preg_replace('/' . $index_parse_regexp . '/', "\\1", $snmp_data[$i]["oid"]);
 					}else if ((isset($snmp_data[$i]["value"])) && ($snmp_data[$i]["value"] != "")) {
 						$snmp_index = $snmp_data[$i]["value"];
 					}
@@ -274,29 +342,82 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 					debug_log_insert("data_query", "Found item [$field_name='$value'] index: $snmp_index [from regexp oid parse]");
 
-					db_execute("replace into host_snmp_cache
-						(host_id,snmp_query_id,field_name,field_value,snmp_index,oid)
-						values ('$host_id','$snmp_query_id','$field_name','$value','$snmp_index','$oid')");
+					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $value, $snmp_index, $oid);
 				}
 			}elseif (substr($field_array["source"], 0, 13) == "VALUE/REGEXP:") {
 				for ($i=0; $i<sizeof($snmp_data); $i++) {
-					$value = ereg_replace(str_replace("VALUE/REGEXP:", "", $field_array["source"]), "\\1", $snmp_data[$i]["value"]);
-					$snmp_index = ereg_replace($index_parse_regexp, "\\1", $snmp_data[$i]["oid"]);
-					$oid = $field_array["oid"] .  "." . $value;
+					$value = preg_replace('/' . str_replace("VALUE/REGEXP:", "", $field_array["source"]) . '/', "\\1", $snmp_data[$i]["value"]);
+					$snmp_index = preg_replace('/' . (isset($field_array["oid_index_parse"]) ? $field_array["oid_index_parse"] : $index_parse_regexp) . '/', "\\1", $snmp_data[$i]["oid"]);
+					$oid = $field_array["oid"] . "." . $snmp_index;
 
 					debug_log_insert("data_query", "Found item [$field_name='$value'] index: $snmp_index [from regexp value parse]");
 
-					db_execute("replace into host_snmp_cache
-						(host_id,snmp_query_id,field_name,field_value,snmp_index,oid)
-						values ('$host_id','$snmp_query_id','$field_name','$value','$snmp_index','$oid')");
+					$output_array[] = "('$host_id', '$snmp_query_id', '$field_name', '$value', '$snmp_index', '$oid', '1')";
 				}
 			}
 		}
 	}
 
+	if (sizeof($output_array)) {
+		data_query_update_host_cache_from_buffer($host_id, $snmp_query_id, $output_array);
+	}
+
 	return true;
 }
 
+function data_query_format_record($host_id, $snmp_query_id, $field_name, $value, $snmp_index, $oid) {
+	global $cnn_id;
+
+	return "($host_id, $snmp_query_id, " . $cnn_id->qstr($field_name) . ", " . $cnn_id->qstr($value) . ", " . $cnn_id->qstr($snmp_index) . ", " . $cnn_id->qstr($oid) . ", 1)";
+}
+
+function data_query_update_host_cache_from_buffer($host_id, $snmp_query_id, &$output_array) {
+	/* set all fields present value to 0, to mark the outliers when we are all done */
+	db_execute("UPDATE host_snmp_cache SET present=0 WHERE host_id='$host_id' AND snmp_query_id='$snmp_query_id'");
+
+	/* setup the database call */
+	$sql_prefix   = "INSERT INTO host_snmp_cache (host_id, snmp_query_id, field_name, field_value, snmp_index, oid, present) VALUES";
+	$sql_suffix   = " ON DUPLICATE KEY UPDATE field_value=VALUES(field_value), oid=VALUES(oid), present=VALUES(present)";
+
+	/* use a reasonable insert buffer, the default is 1MByte */
+	$max_packet   = 256000;
+
+	/* setup somme defaults */
+	$overhead     = strlen($sql_prefix) + strlen($sql_suffix);
+	$buf_len      = 0;
+	$buf_count    = 0;
+	$buffer       = "";
+
+	foreach($output_array as $record) {
+		if ($buf_count == 0) {
+			$delim = " ";
+		} else {
+			$delim = ", ";
+		}
+
+		$buffer .= $delim . $record;
+
+		$buf_len += strlen($record);
+
+		if (($overhead + $buf_len) > ($max_packet - 1024)) {
+			db_execute($sql_prefix . $buffer . $sql_suffix);
+
+			$buffer    = "";
+			$buf_len   = 0;
+			$buf_count = 0;
+		} else {
+			$buf_count++;
+		}
+	}
+
+	if ($buf_count > 0) {
+		db_execute($sql_prefix . $buffer . $sql_suffix);
+	}
+
+	/* remove stale records from the host cache */
+	db_execute("DELETE FROM host_snmp_cache WHERE host_id='$host_id' AND snmp_query_id='$snmp_query_id' AND present='0'");
+}
+
 /* data_query_index - returns an array containing the data query ID and index value given
 	a data query index type/value combination and a host ID
    @arg $index_type - the name of the index to match
@@ -324,6 +445,10 @@ function data_query_index($index_type, $index_value, $host_id, $data_query_id) {
 	   [output_type] => 13
 	) */
 function data_query_field_list($data_template_data_id) {
+	if (!is_numeric($data_template_data_id)) {
+		return 0;
+	}
+
 	$field = db_fetch_assoc("select
 		data_input_fields.type_code,
 		data_input_data.value
@@ -461,6 +586,16 @@ function get_formatted_data_query_indexes($host_id, $data_query_id) {
 
 	/* from the xml; cached in 'host_snmp_query' */
 	$sort_cache = db_fetch_row("select sort_field,title_format from host_snmp_query where host_id='$host_id' and snmp_query_id='$data_query_id'");
+	/* in case no unique index is available, fallback to first field in XML */
+	if (strlen($sort_cache["sort_field"]) == 0){
+		$snmp_queries = get_data_query_array($data_query_id);
+		if (isset($snmp_queries["index_order"])){
+			$i = explode(":", $snmp_queries["index_order"]);
+			if (sizeof($i) > 0){
+				$sort_cache["sort_field"] = array_shift($i);
+			}
+		}
+	}
 
 	/* get a list of data query indexes and the field value that we are supposed
 	to sort */
@@ -604,6 +739,7 @@ function update_data_query_sort_cache($host_id, $data_query_id) {
 	}
 
 	/* update the cache */
+	/* TODO: if both $sort field and $title_format are empty, this yields funny results */
 	db_execute("update host_snmp_query set sort_field = '$sort_field', title_format = '$title_format' where host_id = '$host_id' and snmp_query_id = '$data_query_id'");
 }
 
@@ -652,4 +788,43 @@ function get_script_query_path($args, $script_path, $host_id) {
 	return substitute_script_query_path($script_path) . " $extra_arguments";
 }
 
+
+/**
+ * verify a given index_order
+ * @param array $raw_xml 	- parsed XML array
+ * @return bool 			- index_order field valid
+ */
+function verify_index_order($raw_xml) {
+
+	/* invalid xml check */
+	if ((!is_array($raw_xml)) || (sizeof($raw_xml) == 0)) {
+		debug_log_insert("data_query", "Error parsing XML file into an array.");
+		return false;
+	}
+
+	$xml_inputs = array();
+
+	/* list each of the input fields for this snmp query */
+	while (list($field_name, $field_array) = each($raw_xml["fields"])) {
+		if ($field_array["direction"] == "input") {
+			/* create a list of all values for this index */
+			array_push($xml_inputs, $field_name);
+		}
+	}
+
+	$all_index_order_fields_found = true;
+	/* the xml file contains an ordered list of "indexable" fields */
+	if (isset($raw_xml["index_order"])) {
+		$index_order_array = explode(":", $raw_xml["index_order"]);
+
+		for ($i=0; $i<count($index_order_array); $i++) {
+			$all_index_order_fields_found = $all_index_order_fields_found && (in_array($index_order_array[$i], $xml_inputs));
+		}
+	} else {
+		/* the xml file does not contain an index order */
+	}
+
+	return $all_index_order_fields_found;
+}
+
 ?>
