@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -47,7 +47,7 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 		$i = 0;
 		/* do a fetch for each data source */
 		while (list($ldi, $ldi_value) = each($local_data_id)) {
-			$fetch_array[$i] = rrdtool_function_fetch($ldi, $start_seconds, $end_seconds, $resolution);
+			$fetch_array[$i] = @rrdtool_function_fetch($ldi, $start_seconds, $end_seconds, $resolution);
 			/* clean up unwanted data source items */
 			if (! empty($fetch_array[$i])) {
 				while (list($id, $name) = each($fetch_array[$i]["data_source_names"])) {
@@ -84,7 +84,7 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 				/* Go through data souce names */
 				reset($fetch_array[$i]["data_source_names"]);
 				foreach ( $fetch_array[$i]["data_source_names"] as $ds_name ) {
-					$dsi_name_to_id[$ds_name][] = $i; 
+					$dsi_name_to_id[$ds_name][] = $i;
 				}
 			}
 
@@ -95,7 +95,7 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 				$sum_array["data_source_names"][$i] = $ds_name;
 				foreach ($id_array as $id) {
 					$fetch_id = array_search($ds_name,$fetch_array[$id]["data_source_names"]);
-						/* Sum up like ds names */	
+						/* Sum up like ds names */
 						for ($j=0; $j<count($fetch_array[$id]["values"][$fetch_id]); $j++) {
 							if (isset($fetch_array[$id]["values"][$fetch_id][$j])) {
 								$value = $fetch_array[$id]["values"][$fetch_id][$j];
@@ -109,7 +109,7 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 							}
 						}
 				}
-				$i++;	
+				$i++;
 			}
 		}
 
@@ -152,7 +152,7 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 		$fetch_array = $sum_array;
 	}else{
 		/* No array, just calculate the 95th for the data source */
-		$fetch_array = rrdtool_function_fetch($local_data_id, $start_seconds, $end_seconds, $resolution);
+		$fetch_array = @rrdtool_function_fetch($local_data_id, $start_seconds, $end_seconds, $resolution);
 	}
 
 	/* loop through each data source */
@@ -162,25 +162,25 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 		for ($i=0; $i<count($fetch_array["data_source_names"]); $i++) {
 			if (isset($fetch_array["values"][$i])) {
 				$values_array = $fetch_array["values"][$i];
-	
+
 				/* sort the array in descending order */
 				rsort($values_array, SORT_NUMERIC);
 			}
-	
+
 			/* grab the N% row (or 1 - N% in reverse) and use that as our Nth percentile
 			value */
 			$inverse_percentile = 1 - ($percentile / 100);
 			$target = ((count($values_array) + 1) * $inverse_percentile);
 			$target = sprintf("%d", $target);
-	
+
 			if (empty($values_array[$target])) { $values_array[$target] = 0; }
-	
+
 			/* collect Nth percentile values in this array so we can return them */
 			$return_array{$fetch_array["data_source_names"][$i]} = $values_array[$target];
 
 			/* get max Nth calculation for aggregate */
-			if (($fetch_array["data_source_names"][$i] != "nth_percentile_aggregate_max") && 
-				($fetch_array["data_source_names"][$i] != "nth_percentile_aggregate_sum") && 
+			if (($fetch_array["data_source_names"][$i] != "nth_percentile_aggregate_max") &&
+				($fetch_array["data_source_names"][$i] != "nth_percentile_aggregate_sum") &&
 				($fetch_array["data_source_names"][$i] != "nth_percentile_maximum")) {
 				if (isset($return_array{"nth_percentile_aggregate_total"})) {
 					if (($return_array{"nth_percentile_aggregate_total"} < $values_array[$target])) {
@@ -214,7 +214,7 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
    @arg $ds_steps - how many seconds each period represents
    @returns - (array) an array containing each data source item, and its sum */
 function bandwidth_summation($local_data_id, $start_time, $end_time, $rra_steps, $ds_steps) {
-	$fetch_array = rrdtool_function_fetch($local_data_id, $start_time, $end_time, $rra_steps * $ds_steps);
+	$fetch_array = @rrdtool_function_fetch($local_data_id, $start_time, $end_time, $rra_steps * $ds_steps);
 
 	if ((!isset($fetch_array["data_source_names"])) || (count($fetch_array["data_source_names"]) == 0)) {
 		return;
@@ -229,8 +229,8 @@ function bandwidth_summation($local_data_id, $start_time, $end_time, $rra_steps,
 		if (isset($fetch_array["values"][$i])) {
 			$values_array = $fetch_array["values"][$i];
 
-			for ($j=0;$j<count($fetch_array["values"][$i]);$j++) {
-				$sum += $fetch_array["values"][$i][$j];
+			foreach ($fetch_array["values"][$i] as $value) {
+				$sum += $value;
 			}
 
 			if (count($fetch_array["values"][$i]) != 0) {
@@ -239,8 +239,8 @@ function bandwidth_summation($local_data_id, $start_time, $end_time, $rra_steps,
 				$sum = 0;
 			}
 
-			/* collect 95th percentile values in this array so we can return them */
-			$return_array{$fetch_array["data_source_names"][$i]} = $sum;
+			/* collect summation alues in this array so we can return them */
+			$return_array[ $fetch_array["data_source_names"][$i] ] = $sum;
 		}
 	}
 
@@ -290,7 +290,7 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 	}elseif (($regexp_match_array[4] == "aggregate") || ($regexp_match_array[4] == "aggregate_sum") || ($regexp_match_array[4] == "aggregate_max")) {
 		$local_data_array = array();
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((ereg("(AREA|STACK|LINE[123])", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
+			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
 				$local_data_array[$graph_items[$t]["local_data_id"]][] = $graph_items[$t]["data_source_name"];
 			}
 		}
@@ -299,8 +299,8 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 		$local_data_array = array();
 		if (!empty($graph_item["data_source_name"])) {
 			for ($t=0;($t<count($graph_items));$t++) {
-				if ((ereg("(AREA|STACK|LINE[123])", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && 
-					(!empty($graph_items[$t]["data_template_rrd_id"])) && 
+				if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) &&
+					(!empty($graph_items[$t]["data_template_rrd_id"])) &&
 					($graph_item["data_source_name"] == $graph_items[$t]["data_source_name"])) {
 					$local_data_array[$graph_items[$t]["local_data_id"]][] = $graph_items[$t]["data_source_name"];
 				}
@@ -320,12 +320,12 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 		}
 	}elseif ($regexp_match_array[4] == "total") {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((ereg("(AREA|STACK|LINE[123])", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
+			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
 				if (! empty($nth_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]})) {
 					$local_nth = $nth_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]};
 					$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
 					$local_nth /= pow(10,intval($regexp_match_array[3]));
-	
+
 					$nth += $local_nth;
 				}
 
@@ -339,7 +339,7 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 		}
 	}elseif ($regexp_match_array[4] == "total_peak") {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((ereg("(AREA|STACK|LINE[123])", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
+			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
 				if (! empty($nth_cache{$graph_items[$t]["local_data_id"]}["nth_percentile_maximum"])) {
 					$local_nth = $nth_cache{$graph_items[$t]["local_data_id"]}["nth_percentile_maximum"];
 					$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
@@ -351,7 +351,7 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 		}
 	}elseif ($regexp_match_array[4] == "all_max_current") {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((ereg("(AREA|STACK|LINE[123])", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
+			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
 				if (! empty($ninety_fifth_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]})) {
 					$local_nth = $ninety_fifth_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]};
 					$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
@@ -365,7 +365,7 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 		}
 	}elseif ($regexp_match_array[4] == "all_max_peak") {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((ereg("(AREA|STACK|LINE[123])", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
+			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
 				if (! empty($nth_cache{$graph_items[$t]["local_data_id"]}["nth_percentile_maximum"])) {
 					$local_nth = $nth_cache{$graph_items[$t]["local_data_id"]}["nth_percentile_maximum"];
 					$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
@@ -464,10 +464,10 @@ function variable_bandwidth_summation(&$regexp_match_array, &$graph_item, &$grap
 		$summation = $summation_cache{$graph_item["local_data_id"]}{$graph_item["data_source_name"]};
 	}elseif ($regexp_match_array[2] == "total") {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((ereg("(AREA|STACK|LINE[123])", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
-				$local_summation = $summation_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]};
-
-				$summation += $local_summation;
+			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
+				if (isset($summation_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]})) {
+					$summation += $summation_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]};
+				}
 			}
 		}
 	}
