@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2007 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -33,7 +33,7 @@
      corner of the box ("" for no 'Add' link) */
 function html_start_box($title, $width, $background_color, $cell_padding, $align, $add_text) {
 	global $colors; ?>
-	<table align="<?php print $align;?>" width="<?php print $width;?>" cellpadding=1 cellspacing=0 border=0 bgcolor="#<?php print $background_color;?>">
+	<table align="<?php print $align;?>" width="<?php print $width;?>" cellpadding=0 cellspacing=0 border=0 class="cactiTable" bgcolor="#<?php print $background_color;?>">
 		<tr>
 			<td>
 				<table cellpadding=<?php print $cell_padding;?> cellspacing=0 border=0 bgcolor="#<?php print $colors["form_background_dark"];?>" width="100%">
@@ -42,7 +42,7 @@ function html_start_box($title, $width, $background_color, $cell_padding, $align
 							<table width="100%" cellpadding="0" cellspacing="0">
 								<tr>
 									<td bgcolor="#<?php print $background_color;?>" class="textHeaderDark"><?php print $title;?></td>
-										<?php if ($add_text != "") {?><td class="textHeaderDark" align="right" bgcolor="#<?php print $colors["header"];?>"><strong><a class="linkOverDark" href="<?php print $add_text;?>">Add</a>&nbsp;</strong></td><?php }?>
+										<?php if ($add_text != "") {?><td class="textHeaderDark" align="right" bgcolor="#<?php print $colors["header"];?>"><strong><a class="linkOverDark" href="<?php print htmlspecialchars($add_text);?>">Add</a>&nbsp;</strong></td><?php }?>
 								</tr>
 							</table>
 						</td>
@@ -86,6 +86,8 @@ function html_graph_end_box() {
    @arg $extra_url_args - extra arguments to append to the url
    @arg $header - html to use as a header */
 function html_graph_area(&$graph_array, $no_graphs_message = "", $extra_url_args = "", $header = "") {
+	global $config;
+
 	$i = 0;
 	if (sizeof($graph_array) > 0) {
 		if ($header != "") {
@@ -93,18 +95,64 @@ function html_graph_area(&$graph_array, $no_graphs_message = "", $extra_url_args
 		}
 
 		foreach ($graph_array as $graph) {
+			if (isset($graph["graph_template_name"])) {
+				if (isset($prev_graph_template_name)) {
+					if ($prev_graph_template_name != $graph["graph_template_name"]) {
+						$print  = true;
+						$prev_graph_template_name = $graph["graph_template_name"];
+					}else{
+						$print = false;
+					}
+				}else{
+					$print  = true;
+					$prev_graph_template_name = $graph["graph_template_name"];
+				}
+
+				if ($print) {
+					print "<tr bgcolor='#a9b7cb'>
+						<td colspan='3' class='textHeaderDark'>
+							<strong>Graph Template:</strong> " . htmlspecialchars($graph["graph_template_name"]) . "
+						</td>
+					</tr>";
+				}
+			}elseif (isset($graph["data_query_name"])) {
+				if (isset($prev_data_query_name)) {
+					if ($prev_data_query_name != $graph["data_query_name"]) {
+						$print  = true;
+						$prev_data_query_name = $graph["data_query_name"];
+					}else{
+						$print = false;
+					}
+				}else{
+					$print  = true;
+					$prev_data_query_name = $graph["data_query_name"];
+				}
+
+				if ($print) {
+					print "<tr bgcolor='#a9b7cb'><td colspan='3' class='textHeaderDark'><strong>Data Query:</strong> " . htmlspecialchars($graph["data_query_name"]) . "</td></tr>";
+				}
+				print "<tr bgcolor='#a9b7cb'>
+					<td colspan='3' class='textHeaderDark'>
+						" . $graph["sort_field_value"]. "
+					</td>
+				</tr>";
+			}
+
 			?>
-			<tr bgcolor='#<?php print ($i % 2 == 0 ? "f9f9f9" : "ffffff");?>'>
+			<tr align='center' style='background-color: #<?php print ($i % 2 == 0 ? "f9f9f9" : "ffffff");?>;'>
 				<td align='center'>
-					<table width='1' cellpadding='0'>
+					<table align='center' cellpadding='0'>
 						<tr>
-							<td>
-								<a href='graph.php?action=view&local_graph_id=<?php print $graph["local_graph_id"];?>&rra_id=all'><img class='graphimage' id='graph_<?php print $graph["local_graph_id"] ?>' src='graph_image.php?local_graph_id=<?php print $graph["local_graph_id"];?>&rra_id=0<?php print (($extra_url_args == "") ? "" : "&$extra_url_args");?>' border='0' alt='<?php print $graph["title_cache"];?>'></a>
+							<td align='center'>
+								<div style="min-height: <?php echo (1.6 * $graph["height"]) . "px"?>;"><a href='<?php print htmlspecialchars($config['url_path'] . "graph.php?action=view&local_graph_id=" . $graph["local_graph_id"] . "&rra_id=all");?>'><img class='graphimage' id='graph_<?php print $graph["local_graph_id"] ?>' src='<?php print htmlspecialchars($config['url_path'] . "graph_image.php?local_graph_id=" . $graph["local_graph_id"] . "&rra_id=0" . (($extra_url_args == "") ? "" : "&$extra_url_args"));?>' border='0' alt='<?php print htmlspecialchars($graph["title_cache"]);?>'></a></div>
+								<?php print (read_graph_config_option("show_graph_title") == "on" ? "<p style='font-size: 10;' align='center'><strong>" . htmlspecialchars($graph["title_cache"]) . "</strong></p>" : "");?>
 							</td>
-							<td valign='top' style='padding: 3px;' class='noprint'>
-								<a href='graph.php?action=zoom&local_graph_id=<?php print $graph["local_graph_id"];?>&rra_id=0&<?php print $extra_url_args;?>'><img src='images/graph_zoom.gif' border='0' alt='Zoom Graph' title='Zoom Graph' style='padding: 3px;'></a><br>
-								<a href='graph_xport.php?local_graph_id=<?php print $graph["local_graph_id"];?>&rra_id=0&<?php print $extra_url_args;?>'><img src='images/graph_query.png' border='0' alt='CSV Export' title='CSV Export' style='padding: 3px;'></a><br>
-								<a href='#page_top'><img src='images/graph_page_top.gif' border='0' alt='Page Top' title='Page Top' style='padding: 3px;'></a><br>
+							<td valign='top' style='align: left; padding: 3px;' class='noprint'>
+								<a href='<?php print htmlspecialchars($config['url_path'] . "graph.php?action=zoom&local_graph_id=" . $graph["local_graph_id"] . "&rra_id=0&". $extra_url_args);?>'><img src='<?php print $config['url_path'];?>images/graph_zoom.gif' border='0' alt='Zoom Graph' title='Zoom Graph' style='padding: 3px;'></a><br>
+								<a href='<?php print htmlspecialchars($config['url_path'] . "graph_xport.php?local_graph_id=" . $graph["local_graph_id"] . "&rra_id=0&" . $extra_url_args);?>'><img src='<?php print $config['url_path'];?>images/graph_query.png' border='0' alt='CSV Export' title='CSV Export' style='padding: 3px;'></a><br>
+								<a href='<?php print htmlspecialchars($config['url_path'] . "graph.php?action=properties&local_graph_id=" . $graph["local_graph_id"] . "&rra_id=0&" . $extra_url_args);?>'><img src='<?php print $config['url_path'];?>images/graph_properties.gif' border='0' alt='Graph Source/Properties' title='Graph Source/Properties' style='padding: 3px;'></a><br>
+								<?php api_plugin_hook('graph_buttons', array('hook' => 'graphs_thumbnails', 'local_graph_id' => $graph['local_graph_id'], 'rra' =>  0, 'view_type' => 'view')); ?>
+								<a href='#page_top'><img src='<?php print $config['url_path']; ?>images/graph_page_top.gif' border='0' alt='Page Top' title='Page Top' style='padding: 3px;'></a><br>
 							</td>
 						</tr>
 					</table>
@@ -130,26 +178,107 @@ function html_graph_area(&$graph_array, $no_graphs_message = "", $extra_url_args
    @arg $extra_url_args - extra arguments to append to the url
    @arg $header - html to use as a header */
 function html_graph_thumbnail_area(&$graph_array, $no_graphs_message = "", $extra_url_args = "", $header = "") {
-	$i = 0; $k = 0;
-	if (sizeof($graph_array) > 0) {
+	global $config;
+	$i = 0; $k = 0; $j = 0;
+
+	$num_graphs = sizeof($graph_array);
+
+	if ($num_graphs > 0) {
 		if ($header != "") {
 			print $header;
 		}
 
-		print "<tr>";
-
+		$start = true;
 		foreach ($graph_array as $graph) {
-			?>
-			<td align='center' width='<?php print (98 / read_graph_config_option("num_columns"));?>%'>
-				<table width='1' cellpadding='0'>
-					<tr>
-						<td>
-							<a href='graph.php?action=view&rra_id=all&local_graph_id=<?php print $graph["local_graph_id"];?>'><img class='graphimage' id='graph_<?php print $graph["local_graph_id"] ?>' src='graph_image.php?local_graph_id=<?php print $graph["local_graph_id"];?>&rra_id=0&graph_height=<?php print read_graph_config_option("default_height");?>&graph_width=<?php print read_graph_config_option("default_width");?>&graph_nolegend=true<?php print (($extra_url_args == "") ? "" : "&$extra_url_args");?>' border='0' alt='<?php print $graph["title_cache"];?>'></a>
+			if (isset($graph["graph_template_name"])) {
+				if (isset($prev_graph_template_name)) {
+					if ($prev_graph_template_name != $graph["graph_template_name"]) {
+						$print  = true;
+						$prev_graph_template_name = $graph["graph_template_name"];
+					}else{
+						$print = false;
+					}
+				}else{
+					$print  = true;
+					$prev_graph_template_name = $graph["graph_template_name"];
+				}
+
+				if ($print) {
+					if (!$start) {
+						while($i % read_graph_config_option("num_columns") != 0) {
+							print "<td align='center' width='" . ceil(100 / read_graph_config_option("num_columns")) . "%'></td>";
+							$i++;
+						}
+						print "</tr>";
+					}
+
+					print "<tr style='background-color:#a9b7cb;'>
+						<td style='background-color:#a9b7cb;' colspan='" . read_graph_config_option("num_columns") . "' class='textHeaderDark'>
+							<strong>Graph Template:</strong> " . $graph["graph_template_name"] . "
 						</td>
-						<td valign='top' style='padding: 3px;'>
-							<a href='graph.php?action=zoom&local_graph_id=<?php print $graph["local_graph_id"];?>&rra_id=0&<?php print $extra_url_args;?>'><img src='images/graph_zoom.gif' border='0' alt='Zoom Graph' title='Zoom Graph' style='padding: 3px;'></a><br>
-							<a href='graph_xport.php?local_graph_id=<?php print $graph["local_graph_id"];?>&rra_id=0&<?php print $extra_url_args;?>'><img src='images/graph_query.png' border='0' alt='CSV Export' title='CSV Export' style='padding: 3px;'></a><br>
-							<a href='#page_top'><img src='images/graph_page_top.gif' border='0' alt='Page Top' title='Page Top' style='padding: 3px;'></a><br>
+					</tr>";
+					$i = 0;
+				}
+			}elseif (isset($graph["data_query_name"])) {
+				if (isset($prev_data_query_name)) {
+					if ($prev_data_query_name != $graph["data_query_name"]) {
+						$print  = true;
+						$prev_data_query_name = $graph["data_query_name"];
+					}else{
+						$print = false;
+					}
+				}else{
+					$print  = true;
+					$prev_data_query_name = $graph["data_query_name"];
+				}
+
+				if ($print) {
+					if (!$start) {
+						while($i % read_graph_config_option("num_columns") != 0) {
+							print "<td align='center' width='" . ceil(100 / read_graph_config_option("num_columns")) . "%'></td>";
+							$i++;
+						}
+
+						print "</tr>";
+					}
+
+					print "<tr style='background-color:#a9b7cb;'>
+							<td style='background-color:#a9b7cb;' colspan='" . read_graph_config_option("num_columns") . "' class='textHeaderDark'><strong>Data Query:</strong> " . $graph["data_query_name"] . "</td>
+						</tr>";
+					$i = 0;
+				}
+
+				if (!isset($prev_sort_field_value) || $prev_sort_field_value != $graph["sort_field_value"]){
+					$prev_sort_field_value = $graph["sort_field_value"];
+					print "<tr style='background-color:#a9b7cb;'>
+						<td style='background-color:#a9b7cb;' colspan='" . read_graph_config_option("num_columns") . "' class='textHeaderDark'>
+							" . $graph["sort_field_value"] . "
+						</td>
+					</tr>";
+					$i = 0;
+					$j = 0;
+				}
+			}
+
+			if ($i == 0) {
+				print "<tr style='background-color: #" . ($j % 2 == 0 ? "F2F2F2" : "FFFFFF") . ";'>";
+				$start = false;
+			}
+
+			?>
+			<td align='center' width='<?php print ceil(100 / read_graph_config_option("num_columns"));?>%'>
+				<table align='center' cellpadding='0'>
+					<tr>
+						<td align='center'>
+							<div style="min-height: <?php echo (1.6 * read_graph_config_option("default_height")) . "px"?>;"><a href='<?php print htmlspecialchars($config['url_path'] . "graph.php?action=view&rra_id=all&local_graph_id=" . $graph["local_graph_id"]);?>'><img class='graphimage' id='graph_<?php print $graph["local_graph_id"] ?>' src='<?php print htmlspecialchars($config["url_path"] . "graph_image.php?local_graph_id=" . $graph["local_graph_id"] . "&rra_id=0&graph_height=" . read_graph_config_option("default_height") . "&graph_width=" . read_graph_config_option("default_width") . "&graph_nolegend=true" . (($extra_url_args == "") ? "" : "&$extra_url_args"));?>' border='0' alt='<?php print htmlspecialchars($graph["title_cache"]);?>'></a></div>
+							<?php print (read_graph_config_option("show_graph_title") == "on" ? "<p style='font-size: 10;' align='center'><strong>" . htmlspecialchars($graph["title_cache"]) . "</strong></p>" : "");?>
+						</td>
+						<td valign='top' style='align: left; padding: 3px;'>
+							<a href='<?php print htmlspecialchars($config['url_path'] . "graph.php?action=zoom&local_graph_id=" . $graph["local_graph_id"] . "&rra_id=0&" . $extra_url_args);?>'><img src='<?php print $config['url_path'];?>images/graph_zoom.gif' border='0' alt='Zoom Graph' title='Zoom Graph' style='padding: 3px;'></a><br>
+							<a href='<?php print htmlspecialchars($config['url_path'] . "graph_xport.php?local_graph_id=" . $graph["local_graph_id"] . "&rra_id=0&" . $extra_url_args);?>'><img src='<?php print $config['url_path'];?>images/graph_query.png' border='0' alt='CSV Export' title='CSV Export' style='padding: 3px;'></a><br>
+							<a href='<?php print htmlspecialchars($config['url_path'] . "graph.php?action=properties&local_graph_id=" . $graph["local_graph_id"] . "&rra_id=0&" . $extra_url_args);?>'><img src='<?php print $config['url_path'];?>images/graph_properties.gif' border='0' alt='Graph Source/Properties' title='Graph Source/Properties' style='padding: 3px;'></a><br>
+							<?php api_plugin_hook('graph_buttons_thumbnails', array('hook' => 'graphs_thumbnails', 'local_graph_id' => $graph['local_graph_id'], 'rra' =>  0, 'view_type' => '')); ?>
+							<a href='#page_top'><img src='<?php print $config['url_path'] . "images/graph_page_top.gif";?>' border='0' alt='Page Top' title='Page Top' style='padding: 3px;'></a><br>
 						</td>
 					</tr>
 				</table>
@@ -159,13 +288,22 @@ function html_graph_thumbnail_area(&$graph_array, $no_graphs_message = "", $extr
 			$i++;
 			$k++;
 
-			if (($i == read_graph_config_option("num_columns")) && ($k < count($graph_array))) {
-				$i = 0;
-				print "</tr><tr>";
+			if (($i % read_graph_config_option("num_columns") == 0) && ($k < $num_graphs)) {
+				$i=0;
+				$j++;
+				print "</tr>";
+				$start = true;
 			}
 		}
 
-		print "</tr>";
+		if (!$start) {
+			while($i % read_graph_config_option("num_columns") != 0) {
+				print "<td align='center' width='" . ceil(100 / read_graph_config_option("num_columns")) . "%'></td>";
+				$i++;
+			}
+
+			print "</tr>";
+		}
 	}else{
 		if ($no_graphs_message != "") {
 			print "<td><em>$no_graphs_message</em></td>";
@@ -188,14 +326,18 @@ function html_nav_bar($background_color, $colspan, $current_page, $rows_per_page
 		<td colspan='<?php print $colspan;?>'>
 			<table width='100%' cellspacing='0' cellpadding='3' border='0'>
 				<tr>
-					<td align='left' class='textHeaderDark'>
-						<strong>&lt;&lt; <?php if ($current_page > 1) { print "<a class='linkOverDark' href='" . str_replace("<PAGE>", ($current_page-1), $nav_url) . "'>"; } print "Previous"; if ($current_page > 1) { print "</a>"; } ?></strong>
+					<td align='left' class='textHeaderDark' width='15%'>
+						<?php if ($current_page > 1) {
+							print "<strong><a class='linkOverDark' href='" . htmlspecialchars(str_replace("<PAGE>", ($current_page-1), $nav_url)) . "'> &lt;&lt; Previous</a></strong>";
+						} ?>
 					</td>
-					<td align='center' class='textHeaderDark'>
+					<td align='center' class='textHeaderDark' width='70%'>
 						Showing Rows <?php print (($rows_per_page*($current_page-1))+1);?> to <?php print ((($total_rows < $rows_per_page) || ($total_rows < ($rows_per_page*$current_page))) ? $total_rows : ($rows_per_page*$current_page));?> of <?php print $total_rows;?>
 					</td>
-					<td align='right' class='textHeaderDark'>
-						<strong><?php if (($current_page * $rows_per_page) < $total_rows) { print "<a class='linkOverDark' href='" . str_replace("<PAGE>", ($current_page+1), $nav_url) . "'>"; } print "Next"; if (($current_page * $rows_per_page) < $total_rows) { print "</a>"; } ?> &gt;&gt;</strong>
+					<td align='right' class='textHeaderDark' width='15%'>
+						<?php if (($current_page * $rows_per_page) < $total_rows) {
+							print "<strong><a class='linkOverDark' href='" . htmlspecialchars(str_replace("<PAGE>", ($current_page+1), $nav_url)) . "'> Next &gt;&gt; </a></strong>";
+						} ?>
 					</td>
 				</tr>
 			</table>
@@ -238,10 +380,10 @@ function html_header_sort($header_items, $sort_column, $sort_direction, $last_it
 		}
 
 		if (($db_column == "") || (substr_count($db_column, "nosort"))) {
-			print "<td " . ((($i+1) == count($header_items)) ? "colspan='$last_item_colspan' " : "") . "class='textSubHeaderDark'>" . $display_text . "</td>\n";
+			print "<td " . ((($i+1) == count($header_items)) ? "colspan='$last_item_colspan' " : "") . "class='tableSubHeaderColumn'><span class='textSubHeaderDark'>" . $display_text . "</span></td>\n";
 		}else{
-			print "<td " . ((($i) == count($header_items)) ? "colspan='$last_item_colspan'>" : ">");
-			print "<a class='textSubHeaderDark' href=" . $_SERVER["PHP_SELF"] . "?sort_column=" . $db_column . "&sort_direction=" . $direction . ">" . $display_text . "</a>";
+			print "<td class='tableSubHeaderColumn' " . ((($i) == count($header_items)) ? "colspan='$last_item_colspan'>" : ">");
+			print "<a class='textSubHeaderDark' href='" . htmlspecialchars(basename($_SERVER["PHP_SELF"]) . "?sort_column=" . $db_column . "&sort_direction=" . $direction) . "'>" . $display_text . "</a>";
 			print "</td>\n";
 		}
 
@@ -262,7 +404,7 @@ function html_header_sort($header_items, $sort_column, $sort_direction, $last_it
    @arg $sort_direction - the value the current sort direction.  The actual sort direction
         will be opposite this direction if the user selects the same named column.
    @arg $form_action - the url to post the 'select all' form to */
-function html_header_sort_checkbox($header_items, $sort_column, $sort_direction, $form_action = "") {
+function html_header_sort_checkbox($header_items, $sort_column, $sort_direction, $include_form = true, $form_action = "") {
 	global $colors;
 
 	/* reverse the sort direction */
@@ -288,15 +430,15 @@ function html_header_sort_checkbox($header_items, $sort_column, $sort_direction,
 		}
 
 		if (($db_column == "") || (substr_count($db_column, "nosort"))) {
-			print "<td class='textSubHeaderDark'>" . $display_text . "</td>\n";
+			print "<td class='tableSubHeaderColumn'>" . $display_text . "</td>\n";
 		}else{
-			print "<td>";
-			print "<a class='textSubHeaderDark' href=" . $_SERVER["PHP_SELF"] . "?sort_column=" . $db_column . "&sort_direction=" . $direction . ">" . $display_text . "</a>";
+			print "<td class='tableSubHeaderColumn'>";
+			print "<a class='textSubHeaderDark' href='" . htmlspecialchars(basename($_SERVER["PHP_SELF"]) . "?sort_column=" . $db_column . "&sort_direction=" . $direction) . "'>" . $display_text . "</a>";
 			print "</td>\n";
 		}
 	}
 
-	print "<td width='1%' align='right' bgcolor='#819bc0' style='" . get_checkbox_style() . "'><input type='checkbox' style='margin: 0px;' name='all' title='Select All' onClick='SelectAll(\"chk_\",this.checked)'></td>\n<form name='chk' method='post' action='$form_action'>\n";
+	print "<td width='1%' class='tableSubHeaderColumn tdSelectAll' align='right' bgcolor='#819bc0' style='" . get_checkbox_style() . "'><input type='checkbox' style='margin: 0px;' name='all' title='Select All' onClick='SelectAll(\"chk_\",this.checked)'></td>\n" . ($include_form ? "<td style='display:none;'><form name='chk' method='post' action='$form_action'></td>\n":"");
 	print "</tr>\n";
 }
 
@@ -309,7 +451,7 @@ function html_header($header_items, $last_item_colspan = 1) {
 	print "<tr bgcolor='#" . $colors["header_panel"] . "'>\n";
 
 	for ($i=0; $i<count($header_items); $i++) {
-		print "<td " . ((($i+1) == count($header_items)) ? "colspan='$last_item_colspan' " : "") . "class='textSubHeaderDark'>" . $header_items[$i] . "</td>\n";
+		print "<td " . ((($i+1) == count($header_items)) ? "colspan='$last_item_colspan' " : "") . "class='tableSubHeaderColumn'>" . $header_items[$i] . "</td>\n";
 	}
 
 	print "</tr>\n";
@@ -319,7 +461,7 @@ function html_header($header_items, $last_item_colspan = 1) {
      suitable for display inside of a box element
    @arg $header_items - an array containing a list of items to be included in the header
    @arg $form_action - the url to post the 'select all' form to */
-function html_header_checkbox($header_items, $form_action = "") {
+function html_header_checkbox($header_items, $include_form = true, $form_action = "") {
 	global $colors;
 
 	/* default to the 'current' file */
@@ -328,14 +470,14 @@ function html_header_checkbox($header_items, $form_action = "") {
 	print "<tr bgcolor='#" . $colors["header_panel"] . "'>\n";
 
 	for ($i=0; $i<count($header_items); $i++) {
-		print "<td class='textSubHeaderDark'>" . $header_items[$i] . "</td>\n";
+		print "<td class='tableSubHeaderColumn'>" . $header_items[$i] . "</td>\n";
 	}
 
-	print "<td width='1%' align='right' bgcolor='#819bc0' style='" . get_checkbox_style() . "'><input type='checkbox' style='margin: 0px;' name='all' title='Select All' onClick='SelectAll(\"chk_\",this.checked)'></td>\n<form name='chk' method='post' action='$form_action'>\n";
+	print "<td width='1%' class='tableSubHeaderColumn tdSelectAll' align='right' bgcolor='#819bc0' style='" . get_checkbox_style() . "'><input type='checkbox' style='margin: 0px;' name='all' title='Select All' onClick='SelectAll(\"chk_\",this.checked)'></td>\n" . ($include_form ? "<td style='display:none;'><form name='chk' method='post' action='$form_action'></td>\n":"");
 	print "</tr>\n";
 }
 
-/* create_list - draws the items for an html dropdown given an array of data
+/* html_create_list - draws the items for an html dropdown given an array of data
    @arg $form_data - an array containing data for this dropdown. it can be formatted
      in one of two ways:
      $array["id"] = "value";
@@ -350,33 +492,67 @@ function html_header_checkbox($header_items, $form_action = "") {
 function html_create_list($form_data, $column_display, $column_id, $form_previous_value) {
 	if (empty($column_display)) {
 		foreach (array_keys($form_data) as $id) {
-			print '<option value="' . $id . '"';
+			print '<option value="' . htmlspecialchars($id) . '"';
 
 			if ($form_previous_value == $id) {
 			print " selected";
 			}
 
-			print ">" . title_trim(null_out_substitutions($form_data[$id]), 75) . "</option>\n";
+			print ">" . title_trim(null_out_substitutions(htmlspecialchars($form_data[$id])), 75) . "</option>\n";
 		}
 	}else{
 		if (sizeof($form_data) > 0) {
 			foreach ($form_data as $row) {
-				print "<option value='$row[$column_id]'";
+				print "<option value='" . htmlspecialchars($row[$column_id]) . "'";
 
 				if ($form_previous_value == $row[$column_id]) {
 					print " selected";
 				}
 
 				if (isset($row["host_id"])) {
-					print ">" . title_trim($row[$column_display], 75) . "</option>\n";
+					print ">" . title_trim(htmlspecialchars($row[$column_display]), 75) . "</option>\n";
 				}else{
-					print ">" . title_trim(null_out_substitutions($row[$column_display]), 75) . "</option>\n";
+					print ">" . title_trim(null_out_substitutions(htmlspecialchars($row[$column_display])), 75) . "</option>\n";
 				}
 			}
 		}
 	}
 }
 
+/* html_split_string - takes a string and breaks it into a number of <br> separated segments
+   @arg $string - string to be modified and returned
+   @arg $length - the maximal string length to split to
+   @arg $forgiveness - the maximum number of characters to walk back from to determine
+         the correct break location.
+   @returns $new_string - the modified string to be returned. */
+function html_split_string($string, $length = 70, $forgiveness = 10) {
+	$new_string = "";
+	$j    = 0;
+	$done = false;
+
+	while (!$done) {
+		if (strlen($string) > $length) {
+			for($i = 0; $i < $forgiveness; $i++) {
+				if (substr($string, $length-$i, 1) == " ") {
+					$new_string .= substr($string, 0, $length-$i) . "<br>";
+
+					break;
+				}
+			}
+
+			$string = substr($string, $length-$i);
+		}else{
+			$new_string .= $string;
+			$done        = true;
+		}
+
+		$j++;
+		if ($j > 4) break;
+	}
+
+	return $new_string;
+}
+
 /* draw_graph_items_list - draws a nicely formatted list of graph items for display
      on an edit form
    @arg $item_list - an array representing the list of graph items. this array should
@@ -432,7 +608,7 @@ function draw_graph_items_list($item_list, $filename, $url_data, $disable_contro
 		}
 
 		print "<td>";
-		if ($disable_controls == false) { print "<a href='$filename?action=item_edit&id=" . $item["id"] . "&$url_data'>"; }
+		if ($disable_controls == false) { print "<a href='" . htmlspecialchars("$filename?action=item_edit&id=" . $item["id"] . "&$url_data") . "'>"; }
 		print "<strong>Item # " . ($i+1) . "</strong>";
 		if ($disable_controls == false) { print "</a>"; }
 		print "</td>\n";
@@ -440,13 +616,16 @@ function draw_graph_items_list($item_list, $filename, $url_data, $disable_contro
 		if (empty($item["data_source_name"])) { $item["data_source_name"] = "No Task"; }
 
 		switch (true) {
-		case ereg("(AREA|STACK|GPRINT|LINE[123])", $_graph_type_name):
+		case preg_match("/(AREA|STACK|GPRINT|LINE[123])/", $_graph_type_name):
 			$matrix_title = "(" . $item["data_source_name"] . "): " . $item["text_format"];
 			break;
-		case ereg("(HRULE|VRULE)", $_graph_type_name):
+		case preg_match("/(HRULE)/", $_graph_type_name):
 			$matrix_title = "HRULE: " . $item["value"];
 			break;
-		case ereg("(COMMENT)", $_graph_type_name):
+		case preg_match("/(VRULE)/", $_graph_type_name):
+			$matrix_title = "VRULE: " . $item["value"];
+			break;
+		case preg_match("/(COMMENT)/", $_graph_type_name):
 			$matrix_title = "COMMENT: " . $item["text_format"];
 			break;
 		}
@@ -462,9 +641,9 @@ function draw_graph_items_list($item_list, $filename, $url_data, $disable_contro
 		print "<td style='$this_row_style'>" . $item["hex"] . "</td>\n";
 
 		if ($disable_controls == false) {
-			print "<td><a href='$filename?action=item_movedown&id=" . $item["id"] . "&$url_data'><img src='images/move_down.gif' border='0' alt='Move Down'></a>
-					<a href='$filename?action=item_moveup&id=" . $item["id"] . "&$url_data'><img src='images/move_up.gif' border='0' alt='Move Up'></a></td>\n";
-			print "<td align='right'><a href='$filename?action=item_remove&id=" . $item["id"] . "&$url_data'><img src='images/delete_icon.gif' width='10' height='10' border='0' alt='Delete'></a></td>\n";
+			print "<td><a href='" . htmlspecialchars("$filename?action=item_movedown&id=" . $item["id"] . "&$url_data") . "'><img src='" . $config['url_path'] . "images/move_down.gif' border='0' alt='Move Down'></a>
+					<a href='" . htmlspecialchars("$filename?action=item_moveup&id=" . $item["id"] . "&$url_data") . "'><img src='" . $config['url_path'] . "images/move_up.gif' border='0' alt='Move Up'></a></td>\n";
+			print "<td align='right'><a href='" . htmlspecialchars("$filename?action=item_remove&id=" . $item["id"] . "&$url_data") . "'><img src='" . $config['url_path'] . "images/delete_icon.gif' style='height:10px;width:10px;' border='0' alt='Delete'></a></td>\n";
 		}
 
 		print "</tr>";
@@ -478,9 +657,7 @@ function draw_graph_items_list($item_list, $filename, $url_data, $disable_contro
 
 /* draw_menu - draws the cacti menu for display in the console */
 function draw_menu($user_menu = "") {
-	global $colors, $config, $user_auth_realms, $user_auth_realm_filenames;
-
-	include($config["include_path"] . "/global_arrays.php");
+	global $colors, $config, $user_auth_realms, $user_auth_realm_filenames, $menu;
 
 	if (strlen($user_menu == 0)) {
 		$user_menu = $menu;
@@ -523,7 +700,7 @@ function draw_menu($user_menu = "") {
 			if (is_array($item_title)) {
 				$i = 0;
 
-				if ((isset($user_realms[$current_realm_id])) || (!isset($user_auth_realm_filenames{basename($item_url)}))) {
+				if ($current_realm_id == -1 || (isset($user_realms[$current_realm_id])) || (!isset($user_auth_realm_filenames{basename($item_url)}))) {
 					/* if the current page exists in the sub-items array, draw each sub-item */
 					if (array_key_exists(basename($_SERVER["PHP_SELF"]), $item_title) == true) {
 						$draw_sub_items = true;
@@ -532,6 +709,8 @@ function draw_menu($user_menu = "") {
 					}
 
 					while (list($item_sub_url, $item_sub_title) = each($item_title)) {
+						$item_sub_url = $config['url_path'] . $item_sub_url;
+
 						/* indent sub-items */
 						if ($i > 0) {
 							$prepend_string = "---&nbsp;";
@@ -541,7 +720,7 @@ function draw_menu($user_menu = "") {
 
 						/* do not put a line between each sub-item */
 						if (($i == 0) || ($draw_sub_items == false)) {
-							$background = "images/menu_line.gif";
+							$background = $config['url_path'] . "images/menu_line.gif";
 						}else{
 							$background = "";
 						}
@@ -558,9 +737,9 @@ function draw_menu($user_menu = "") {
 						that is contained in the sub-items array */
 						if (($i == 0) || ($draw_sub_items)) {
 							if (basename($_SERVER["PHP_SELF"]) == basename($item_sub_url)) {
-								print "<tr><td class='$td_class' background='$background'>$prepend_string<strong><a href='$item_sub_url'>$item_sub_title</a></strong></td></tr>\n";
+								print "<tr><td class='$td_class' style='background-image:url(\"$background\");'>$prepend_string<strong><a href='" . htmlspecialchars($item_sub_url) . "'>$item_sub_title</a></strong></td></tr>\n";
 							}else{
-								print "<tr><td class='$td_class' background='$background'>$prepend_string<a href='$item_sub_url'>$item_sub_title</a></td></tr>\n";
+								print "<tr><td class='$td_class' style='background-image:url(\"$background\");'>$prepend_string<a href='" . htmlspecialchars($item_sub_url) . "'>$item_sub_title</a></td></tr>\n";
 							}
 						}
 
@@ -568,19 +747,20 @@ function draw_menu($user_menu = "") {
 					}
 				}
 			}else{
-				if ((isset($user_realms[$current_realm_id])) || (!isset($user_auth_realm_filenames{basename($item_url)}))) {
+				if ($current_realm_id == -1 || (isset($user_realms[$current_realm_id])) || (!isset($user_auth_realm_filenames{basename($item_url)}))) {
 					/* draw normal (non sub-item) menu item */
+					$item_url = $config['url_path'] . $item_url;
 					if (basename($_SERVER["PHP_SELF"]) == basename($item_url)) {
-						print "<tr><td class='textMenuItemSelected' background='images/menu_line.gif'><strong><a href='$item_url'>$item_title</a></strong></td></tr>\n";
+						print "<tr><td class='textMenuItemSelected' style='background-image:url(\"" . $config['url_path'] . "images/menu_line.gif\");'><strong><a href='" . htmlspecialchars($item_url) . "'>$item_title</a></strong></td></tr>\n";
 					}else{
-						print "<tr><td class='textMenuItem' background='images/menu_line.gif'><a href='$item_url'>$item_title</a></td></tr>\n";
+						print "<tr><td class='textMenuItem' style='background-image:url(\"" . $config['url_path'] . "images/menu_line.gif\");'><a href='" . htmlspecialchars($item_url) . "'>$item_title</a></td></tr>\n";
 					}
 				}
 			}
 		}
 	}
 
-	print "<tr><td class='textMenuItem' background='images/menu_line.gif'></td></tr>\n";
+	print "<tr><td class='textMenuItem' style='background-image:url(\"" . $config['url_path'] . "images/menu_line.gif\");'></td></tr>\n";
 
 	print "</table></td></tr>";
 }
@@ -590,18 +770,19 @@ function draw_menu($user_menu = "") {
    @arg $actions_array - an array that contains a list of possible actions. this array should
      be compatible with the form_dropdown() function */
 function draw_actions_dropdown($actions_array) {
+	global $config;
 	?>
 	<table align='center' width='100%'>
 		<tr>
 			<td width='1' valign='top'>
-				<img src='images/arrow.gif' alt='' align='absmiddle'>&nbsp;
+				<img src='<?php echo $config['url_path']; ?>images/arrow.gif' alt='' align='middle'>&nbsp;
 			</td>
 			<td align='right'>
 				Choose an action:
 				<?php form_dropdown("drp_action",$actions_array,"","","1","","");?>
 			</td>
 			<td width='1' align='right'>
-				<input type='image' src='images/button_go.gif' alt='Go'>
+				<input type='submit' value='Go' title='Execute Action'>
 			</td>
 		</tr>
 	</table>
@@ -615,7 +796,7 @@ function draw_actions_dropdown($actions_array) {
  */
 
 function DrawMatrixHeaderItem($matrix_name, $matrix_text_color, $column_span = 1) { ?>
-		<td height="1" colspan="<?php print $column_span;?>">
+		<td class="tableSubHeaderColumn" style="height:1px;" colspan="<?php print $column_span;?>">
 			<strong><font color="#<?php print $matrix_text_color;?>"><?php print $matrix_name;?></font></strong>
 		</td>
 <?php }
