@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,7 +22,7 @@
  +-------------------------------------------------------------------------+
 */
 
-function &import_xml_data(&$xml_data, $import_custom_rra_settings) {
+function &import_xml_data(&$xml_data, $import_custom_rra_settings, $rra_array = array()) {
 	global $config, $hash_type_codes, $hash_version_codes;
 
 	include_once($config["library_path"] . "/xml.php");
@@ -53,7 +53,7 @@ function &import_xml_data(&$xml_data, $import_custom_rra_settings) {
 	$hash_cache = array();
 
 	/* the order of the $hash_type_codes array is ordered such that the items
-	with the most dependencies are last and the items with no dependenecies are first.
+	with the most dependencies are last and the items with no dependencies are first.
 	this means dependencies will just magically work themselves out :) */
 	reset($hash_type_codes);
 	while (list($type, $code) = each($hash_type_codes)) {
@@ -65,10 +65,10 @@ function &import_xml_data(&$xml_data, $import_custom_rra_settings) {
 
 				switch($type) {
 				case 'graph_template':
-					$hash_cache += xml_to_graph_template($dep_hash_cache[$type][$i]["hash"], $hash_array, $hash_cache);
+					$hash_cache += xml_to_graph_template($dep_hash_cache[$type][$i]["hash"], $hash_array, $hash_cache, $dep_hash_cache[$type][$i]["version"]);
 					break;
 				case 'data_template':
-					$hash_cache += xml_to_data_template($dep_hash_cache[$type][$i]["hash"], $hash_array, $hash_cache, $import_custom_rra_settings);
+					$hash_cache += xml_to_data_template($dep_hash_cache[$type][$i]["hash"], $hash_array, $hash_cache, $import_custom_rra_settings, $rra_array);
 					break;
 				case 'host_template':
 					$hash_cache += xml_to_host_template($dep_hash_cache[$type][$i]["hash"], $hash_array, $hash_cache);
@@ -104,7 +104,7 @@ function &import_xml_data(&$xml_data, $import_custom_rra_settings) {
 	return $info_array;
 }
 
-function &xml_to_graph_template($hash, &$xml_array, &$hash_cache) {
+function &xml_to_graph_template($hash, &$xml_array, &$hash_cache, $hash_version) {
 	global $struct_graph, $struct_graph_item, $fields_graph_template_input_edit, $hash_version_codes;
 
 	/* import into: graph_templates */
@@ -121,9 +121,6 @@ function &xml_to_graph_template($hash, &$xml_array, &$hash_cache) {
 	$save["id"] = (empty($_graph_template_id) ? "0" : db_fetch_cell("select graph_templates_graph.id from (graph_templates,graph_templates_graph) where graph_templates.id=graph_templates_graph.graph_template_id and graph_templates.id=$graph_template_id and graph_templates_graph.local_graph_id=0"));
 	$save["graph_template_id"] = $graph_template_id;
 
-	/* parse information from the hash */
-	$parsed_hash = parse_xml_hash($hash);
-
 	reset($struct_graph);
 	while (list($field_name, $field_array) = each($struct_graph)) {
 		/* make sure this field exists in the xml array first */
@@ -133,7 +130,9 @@ function &xml_to_graph_template($hash, &$xml_array, &$hash_cache) {
 
 		/* make sure this field exists in the xml array first */
 		if (isset($xml_array["graph"][$field_name])) {
-			if (($field_name == "unit_exponent_value") && (get_version_index($parsed_hash["version"]) < get_version_index("0.8.5")) && ($xml_array["graph"][$field_name] == "0")) { /* backwards compatability */
+			/* Cacti pre 0.8.5 did handle a unit_exponent=0 differently
+			 * so we need to know the version of the current hash code we're just working on */
+			if (($field_name == "unit_exponent_value") && (get_version_index($hash_version) < get_version_index("0.8.5")) && ($xml_array["graph"][$field_name] == "0")) { /* backwards compatability */
 				$save[$field_name] = "";
 			}else{
 				$save[$field_name] = addslashes(xml_character_decode($xml_array["graph"][$field_name]));
@@ -163,9 +162,9 @@ function &xml_to_graph_template($hash, &$xml_array, &$hash_cache) {
 				/* make sure this field exists in the xml array first */
 				if (isset($item_array[$field_name])) {
 					/* is the value of this field a hash or not? */
-					if (ereg("hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})", $item_array[$field_name])) {
+					if (preg_match("/hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})/", $item_array[$field_name])) {
 						$save[$field_name] = resolve_hash_to_id($item_array[$field_name], $hash_cache);
-					}elseif (($field_name == "color_id") && (ereg("^[a-fA-F0-9]{6}$", $item_array[$field_name])) && (get_version_index($parsed_hash["version"]) >= get_version_index("0.8.5"))) { /* treat the 'color' field differently */
+					}elseif (($field_name == "color_id") && (preg_match("/^[a-fA-F0-9]{6}$/", $item_array[$field_name])) && (get_version_index($parsed_hash["version"]) >= get_version_index("0.8.5"))) { /* treat the 'color' field differently */
 						$color_id = db_fetch_cell("select id from colors where hex='" . $item_array[$field_name] . "'");
 
 						if (empty($color_id)) {
@@ -240,7 +239,7 @@ function &xml_to_graph_template($hash, &$xml_array, &$hash_cache) {
 	return $hash_cache;
 }
 
-function &xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_custom_rra_settings) {
+function &xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_custom_rra_settings, $rra_array) {
 	global $struct_data_source, $struct_data_source_item;
 
 	/* import into: data_template */
@@ -268,7 +267,7 @@ function &xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_custom_
 		/* make sure this field exists in the xml array first */
 		if (isset($xml_array["ds"][$field_name])) {
 			/* is the value of this field a hash or not? */
-			if (ereg("hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})", $xml_array["ds"][$field_name])) {
+			if (preg_match("/hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})/", $xml_array["ds"][$field_name])) {
 				$save[$field_name] = resolve_hash_to_id($xml_array["ds"][$field_name], $hash_cache);
 			}else{
 				$save[$field_name] = addslashes(xml_character_decode($xml_array["ds"][$field_name]));
@@ -301,13 +300,13 @@ function &xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_custom_
 				}
 			}
 		}
-	/* use all rras by default */
-	}else{
-		$rras = db_fetch_assoc("select id from rra");
-
-		if (is_array($rras)) {
-			foreach ($rras as $rra) {
-				db_execute("replace into data_template_data_rra (data_template_data_id,rra_id) values ($data_template_data_id," . $rra["id"] . ")");
+	}else{ /* use all rras selected by the user */
+		if (is_array($rra_array)) {
+			/* when overriding an existing data template, make sure that specifying fewer (or different) rra's is honoured */
+			db_execute("DELETE FROM data_template_data_rra  WHERE data_template_data_id = $data_template_data_id");
+			foreach ($rra_array as $rra) {
+				/* as it was user supplied input, make sure it's an integer */
+				db_execute("replace into data_template_data_rra (data_template_data_id,rra_id) values ($data_template_data_id," . intval($rra) . ")");
 			}
 		}
 	}
@@ -337,7 +336,7 @@ function &xml_to_data_template($hash, &$xml_array, &$hash_cache, $import_custom_
 				/* make sure this field exists in the xml array first */
 				if (isset($item_array[$field_name])) {
 					/* is the value of this field a hash or not? */
-					if (ereg("hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})", $item_array[$field_name])) {
+					if (preg_match("/hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})/", $item_array[$field_name])) {
 						$save[$field_name] = resolve_hash_to_id($item_array[$field_name], $hash_cache);
 					}else{
 						$save[$field_name] = addslashes(xml_character_decode($item_array[$field_name]));
@@ -390,7 +389,7 @@ function &xml_to_data_query($hash, &$xml_array, &$hash_cache) {
 		/* make sure this field exists in the xml array first */
 		if (isset($xml_array[$field_name])) {
 			/* is the value of this field a hash or not? */
-			if (ereg("hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})", $xml_array[$field_name])) {
+			if (preg_match("/hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})/", $xml_array[$field_name])) {
 				$save[$field_name] = resolve_hash_to_id($xml_array[$field_name], $hash_cache);
 			}else{
 				$save[$field_name] = addslashes(xml_character_decode($xml_array[$field_name]));
@@ -422,7 +421,7 @@ function &xml_to_data_query($hash, &$xml_array, &$hash_cache) {
 				/* make sure this field exists in the xml array first */
 				if (isset($item_array[$field_name])) {
 					/* is the value of this field a hash or not? */
-					if (ereg("hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})", $item_array[$field_name])) {
+					if (preg_match("/hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})/", $item_array[$field_name])) {
 						$save[$field_name] = resolve_hash_to_id($item_array[$field_name], $hash_cache);
 					}else{
 						$save[$field_name] = addslashes(xml_character_decode($item_array[$field_name]));
@@ -678,7 +677,21 @@ function &xml_to_cdef($hash, &$xml_array, &$hash_cache) {
 			while (list($field_name, $field_array) = each($fields_cdef_item_edit)) {
 				/* make sure this field exists in the xml array first */
 				if (isset($item_array[$field_name])) {
-					$save[$field_name] = addslashes(xml_character_decode($item_array[$field_name]));
+					/* check, if an inherited cdef as to be decoded (value == 5)
+					 * this whole procedure relies on the sequence during template export
+					 * inherited cdef's must come first, this has to be taken care of during export
+					 * so we do not have any specific dependency checks here */
+					if (($field_name == "value") && ($item_array["type"] == '5')) {
+						/* parse information from the hash, which in this case
+						 * is stored as a value of the current item being processed */
+						$parsed_item_hash = parse_xml_hash($item_array["value"]);
+						/* invalid/wrong hash */
+						if ($parsed_item_hash == false) { return false; }
+						$_cdef_id = db_fetch_cell("select id from cdef where hash='" . $parsed_item_hash["hash"] . "'");
+						$save[$field_name] = $_cdef_id;
+					} else {
+						$save[$field_name] = addslashes(xml_character_decode($item_array[$field_name]));
+					}
 				}
 			}
 
@@ -822,16 +835,17 @@ function resolve_hash_to_id($hash, &$hash_cache_array) {
 }
 
 function parse_xml_hash($hash) {
-	if (ereg("hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})", $hash, $matches)) {
+	if (preg_match("/hash_([a-f0-9]{2})([a-f0-9]{4})([a-f0-9]{32})/", $hash, $matches)) {
 		$parsed_hash["type"] = check_hash_type($matches[1]);
 		$parsed_hash["version"] = strval(check_hash_version($matches[2]));
 		$parsed_hash["hash"] = $matches[3];
 
 		/* an error has occured */
-		if (($parsed_hash["type"] == false) || ($parsed_hash["version"] == false)) {
+		if (($parsed_hash["type"] === false) || ($parsed_hash["version"] === false)) {
 			return false;
 		}
 	}else{
+		cacti_log(__FUNCTION__ . " ERROR wrong hash format", false);
 		return false;
 	}
 
@@ -906,13 +920,18 @@ function get_version_index($string_version) {
 		$i++;
 	}
 
+	/* version index not found */
 	return -1;
 }
 
 function xml_character_decode($text) {
-	$trans_tbl = get_html_translation_table(HTML_ENTITIES);
-	$trans_tbl = array_flip($trans_tbl);
-	return strtr($text, $trans_tbl);
+	if (function_exists("html_entity_decode")) {
+		return html_entity_decode($text, ENT_QUOTES, "UTF-8");
+	} else {
+		$trans_tbl = get_html_translation_table(HTML_ENTITIES);
+		$trans_tbl = array_flip($trans_tbl);
+		return strtr($text, $trans_tbl);
+	}
 }
 
 ?>
