@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -36,12 +36,12 @@ function exec_poll($command) {
 		}
 
 		/* return if the popen command was not successfull */
-		if ($fp == 0) {
+		if (!is_resource($fp)) {
 			cacti_log("WARNING; Problem with POPEN command.");
 			return "U";
 		}
 
-		$output = fgets($fp, 4096);
+		$output = fgets($fp, 8192);
 
 		pclose($fp);
 	}else{
@@ -61,6 +61,7 @@ function exec_poll($command) {
    @returns - the output of $command after execution against the php script
      server */
 function exec_poll_php($command, $using_proc_function, $pipes, $proc_fd) {
+	global $config;
 	/* execute using php process */
 	if ($using_proc_function == 1) {
 		if (is_resource($proc_fd)) {
@@ -72,7 +73,7 @@ function exec_poll_php($command, $using_proc_function, $pipes, $proc_fd) {
 			/* send command to the php server */
 			fwrite($pipes[0], $command . "\r\n");
 
-			$output = fgets($pipes[1], 4096);
+			$output = fgets($pipes[1], 8192);
 
 			if (substr_count($output, "ERROR") > 0) {
 				$output = "U";
@@ -80,7 +81,7 @@ function exec_poll_php($command, $using_proc_function, $pipes, $proc_fd) {
 		}
 	/* execute the old fashion way */
 	}else{
-   		/* formulate command */
+		/* formulate command */
 		$command = read_config_option("path_php_binary") . " " . $command;
 
 		if (function_exists("popen")) {
@@ -91,12 +92,12 @@ function exec_poll_php($command, $using_proc_function, $pipes, $proc_fd) {
 			}
 
 			/* return if the popen command was not successfull */
-			if ($fp == 0) {
+			if (!is_resource($fp)) {
 				cacti_log("WARNING; Problem with POPEN command.");
 				return "U";
 			}
 
-			$output = fgets($fp, 4096);
+			$output = fgets($fp, 8192);
 
 			pclose($fp);
 		}else{
@@ -112,9 +113,9 @@ function exec_poll_php($command, $using_proc_function, $pipes, $proc_fd) {
    @arg $filename - the full pathname to the script to execute
    @arg $args - any additional arguments that must be passed onto the executable */
 function exec_background($filename, $args = "") {
-	global $config;
+	global $config, $debug;
 
-	if (read_config_option("log_verbosity") == POLLER_VERBOSITY_DEBUG) {
+	if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG || $debug) {
 		cacti_log("DEBUG: About to Spawn a Remote Process [CMD: $filename, ARGS: $args]", true, "POLLER");
 	}
 
@@ -135,6 +136,7 @@ function exec_background($filename, $args = "") {
 function file_exists_2gb($filename) {
 	global $config;
 
+	$rval = 0;
 	if ($config["cacti_server_os"] != "win32") {
 		system("test -f $filename", $rval);
 		return ($rval == 0);
@@ -167,8 +169,10 @@ function update_reindex_cache($host_id, $data_query_id) {
 		case DATA_QUERY_AUTOINDEX_BACKWARDS_UPTIME:
 			/* the uptime backwards method requires snmp, so make sure snmp is actually enabled
 			 * on this device first */
-			if ($host["snmp_community"] != "") {
+			if ($host["snmp_version"] > 0) {
 				if (isset($data_query_xml["oid_uptime"])) {
+					$oid_uptime = $data_query_xml["oid_uptime"];
+				}elseif (isset($data_query_xml["uptime_oid"])) {
 					$oid_uptime = $data_query_xml["uptime_oid"];
 				}else{
 					$oid_uptime = ".1.3.6.1.2.1.1.3.0";
@@ -188,23 +192,54 @@ function update_reindex_cache($host_id, $data_query_id) {
 					$host["snmp_timeout"],
 					SNMP_POLLER);
 
-				array_push($recache_stack, "insert into poller_reindex (host_id,data_query_id,action,op,assert_value,arg1) values ($host_id,$data_query_id,0,'<','$assert_value','$oid_uptime')");
+				$recache_stack[] = "('$host_id', '$data_query_id'," .  POLLER_ACTION_SNMP . ", '<', '$assert_value', '$oid_uptime', '1')";
 			}
 
 			break;
 		case DATA_QUERY_AUTOINDEX_INDEX_NUM_CHANGE:
 			/* this method requires that some command/oid can be used to determine the
-			 * current number of indexes in the data query */
+			 * current number of indexes in the data query
+			 * pay ATTENTION to quoting!
+			 * the script parameters are usually enclosed in single tics: '
+			 * so we have to enclose the whole list of parameters in double tics: "
+			 * */
+
+			/* the assert_value counts the number of distinct indexes currently available in host_snmp_cache
+			 * we do NOT make use of <oid_num_indexes> or the like!
+			 * this works, even if no <oid_num_indexes> was given
+			 */
 			$assert_value = sizeof(db_fetch_assoc("select snmp_index from host_snmp_cache where host_id=$host_id and snmp_query_id=$data_query_id group by snmp_index"));
 
-			if ($data_query_type == DATA_INPUT_TYPE_SNMP_QUERY) {
-				if (isset($data_query_xml["oid_num_indexes"])) {
-					array_push($recache_stack, "insert into poller_reindex (host_id, data_query_id, action, op, assert_value, arg1) values ($host_id, $data_query_id, 0, '=', '$assert_value', '" . $data_query_xml["oid_num_indexes"] . "')");
-				}
-			}else if ($data_query_type == DATA_INPUT_TYPE_SCRIPT_QUERY) {
-				if (isset($data_query_xml["arg_num_indexes"])) {
-					array_push($recache_stack, "insert into poller_reindex (host_id, data_query_id, action, op, assert_value, arg1) values ($host_id, $data_query_id, 1, '=', '$assert_value', '" . get_script_query_path((isset($data_query_xml["arg_prepend"]) ? $data_query_xml["arg_prepend"] . " ": "") . $data_query_xml["arg_num_indexes"], $data_query_xml["script_path"], $host_id) . "')");
-				}
+			/* now, we have to build the (list of) commands that are later used on a recache event
+			 * the result of those commands will be compared to the assert_value we have just computed
+			 * on a comparison failure, a reindex event will be generated
+			 */
+			switch ($data_query_type) {
+				case DATA_INPUT_TYPE_SNMP_QUERY:
+					if (isset($data_query_xml["oid_num_indexes"])) { /* we have a specific OID for counting indexes */
+						$recache_stack[] = "($host_id, $data_query_id," .  POLLER_ACTION_SNMP . ", '=', '$assert_value', '" . $data_query_xml["oid_num_indexes"] . "', '1')";
+					} else { /* count all indexes found */
+						$recache_stack[] = "($host_id, $data_query_id," .  POLLER_ACTION_SNMP_COUNT . ", '=', '$assert_value', '" . $data_query_xml["oid_index"] . "', '1')";
+					}
+					break;
+				case DATA_INPUT_TYPE_SCRIPT_QUERY:
+					if (isset($data_query_xml["arg_num_indexes"])) { /* we have a specific request for counting indexes */
+						$recache_stack[] = "($host_id, $data_query_id," . POLLER_ACTION_SCRIPT . ", '=', '$assert_value', '" . get_script_query_path((isset($data_query_xml["arg_prepend"]) ? $data_query_xml["arg_prepend"] . " ": "") . $data_query_xml["arg_num_indexes"], $data_query_xml["script_path"], $host_id) . "', '1')";
+					} else { /* count all indexes found */
+						$recache_stack[] = "($host_id, $data_query_id," . POLLER_ACTION_SCRIPT_COUNT . ", '=', '$assert_value', '" . get_script_query_path((isset($data_query_xml["arg_prepend"]) ? $data_query_xml["arg_prepend"] . " ": "") . $data_query_xml["arg_index"], $data_query_xml["script_path"], $host_id) . "', '1')";
+					}
+					break;
+				case DATA_INPUT_TYPE_QUERY_SCRIPT_SERVER:
+					if (isset($data_query_xml["arg_num_indexes"])) { /* we have a specific request for counting indexes */
+						/* escape path (windows!) and parameters for use with database sql; TODO: replace by db specific escape function like mysql_real_escape_string? */
+						$recache_stack[] = "($host_id, $data_query_id," . POLLER_ACTION_SCRIPT_PHP . ", '=', '$assert_value', '" . addslashes(get_script_query_path($data_query_xml["script_function"] . " " . (isset($data_query_xml["arg_prepend"]) ? $data_query_xml["arg_prepend"] . " ": "") . $data_query_xml["arg_num_indexes"], $data_query_xml["script_path"], $host_id)) . "', '1')";
+					} else { /* count all indexes found */
+						# TODO: push the correct assert value
+						/* escape path (windows!) and parameters for use with database sql; TODO: replace by db specific escape function like mysql_real_escape_string? */
+						#$recache_stack[] = "($host_id, $data_query_id," . POLLER_ACTION_SCRIPT_PHP_COUNT . ", '=', '$assert_value', '" . addslashes(get_script_query_path($data_query_xml["script_function"] . " " . (isset($data_query_xml["arg_prepend"]) ? $data_query_xml["arg_prepend"] . " ": "") . $data_query_xml["arg_index"], $data_query_xml["script_path"], $host_id)) . "', '1')";
+						# omit the assert value until we are able to run an 'index' command through script server
+					}
+					break;
 			}
 
 			break;
@@ -216,9 +251,9 @@ function update_reindex_cache($host_id, $data_query_id) {
 					$assert_value = $index["field_value"];
 
 					if ($data_query_type == DATA_INPUT_TYPE_SNMP_QUERY) {
-						array_push($recache_stack, "insert into poller_reindex (host_id, data_query_id, action, op, assert_value, arg1) values ($host_id, $data_query_id, 0, '=', '$assert_value', '" . $data_query_xml["fields"]{$data_query["sort_field"]}["oid"] . "." . $index["snmp_index"] . "')");
+						$recache_stack[] = "($host_id, $data_query_id," .  POLLER_ACTION_SNMP . ", '=', '$assert_value', '" . $data_query_xml["fields"]{$data_query["sort_field"]}["oid"] . "." . $index["snmp_index"] . "', '1')";
 					}else if ($data_query_type == DATA_INPUT_TYPE_SCRIPT_QUERY) {
-						array_push($recache_stack, "insert into poller_reindex (host_id, data_query_id, action, op, assert_value, arg1) values ($host_id, $data_query_id, 1, '=', '$assert_value', '" . get_script_query_path((isset($data_query_xml["arg_prepend"]) ? $data_query_xml["arg_prepend"] . " ": "") . $data_query_xml["arg_get"] . " " . $data_query_xml["fields"]{$data_query["sort_field"]}["query_name"] . " " . $index["snmp_index"], $data_query_xml["script_path"], $host_id) . "')");
+						$recache_stack[] = "('$host_id', '$data_query_id'," . POLLER_ACTION_SCRIPT . ", '=', '$assert_value', '" . get_script_query_path((isset($data_query_xml["arg_prepend"]) ? $data_query_xml["arg_prepend"] . " ": "") . $data_query_xml["arg_get"] . " " . $data_query_xml["fields"]{$data_query["sort_field"]}["query_name"] . " " . $index["snmp_index"], $data_query_xml["script_path"], $host_id) . "', '1')";
 					}
 				}
 			}
@@ -226,20 +261,64 @@ function update_reindex_cache($host_id, $data_query_id) {
 			break;
 	}
 
-	/* save the delete for last since we need to reference this table in the code above */
-	db_execute("delete from poller_reindex where host_id=$host_id and data_query_id=$data_query_id");
-
-	for ($i=0; $i<count($recache_stack); $i++) {
-		db_execute($recache_stack[$i]);
+	if (sizeof($recache_stack)) {
+		poller_update_poller_reindex_from_buffer($host_id, $data_query_id, $recache_stack);
 	}
 }
 
+function poller_update_poller_reindex_from_buffer($host_id, $data_query_id, &$recache_stack) {
+	/* set all fields present value to 0, to mark the outliers when we are all done */
+	db_execute("UPDATE poller_reindex SET present=0 WHERE host_id='$host_id' AND data_query_id='$data_query_id'");
+
+	/* setup the database call */
+	$sql_prefix   = "INSERT INTO poller_reindex (host_id, data_query_id, action, op, assert_value, arg1, present) VALUES";
+	$sql_suffix   = " ON DUPLICATE KEY UPDATE action=VALUES(action), op=VALUES(op), assert_value=VALUES(assert_value), present=VALUES(present)";
+
+	/* use a reasonable insert buffer, the default is 1MByte */
+	$max_packet   = 256000;
+
+	/* setup somme defaults */
+	$overhead     = strlen($sql_prefix) + strlen($sql_suffix);
+	$buf_len      = 0;
+	$buf_count    = 0;
+	$buffer       = "";
+
+	foreach($recache_stack AS $record) {
+		if ($buf_count == 0) {
+			$delim = " ";
+		} else {
+			$delim = ", ";
+		}
+
+		$buffer .= $delim . $record;
+
+		$buf_len += strlen($record);
+
+		if (($overhead + $buf_len) > ($max_packet - 1024)) {
+			db_execute($sql_prefix . $buffer . $sql_suffix);
+
+			$buffer    = "";
+			$buf_len   = 0;
+			$buf_count = 0;
+		} else {
+			$buf_count++;
+		}
+	}
+
+	if ($buf_count > 0) {
+		db_execute($sql_prefix . $buffer . $sql_suffix);
+	}
+
+	/* remove stale records from the poller reindex */
+	db_execute("DELETE FROM poller_reindex WHERE host_id='$host_id' AND data_query_id='$data_query_id' AND present='0'");
+}
+
 /* process_poller_output - grabs data from the 'poller_output' table and feeds the *completed*
      results to RRDTool for processing
   @arg $rrdtool_pipe - the array of pipes containing the file descriptor for rrdtool
   @arg $remainder - don't use LIMIT if TRUE */
-function process_poller_output($rrdtool_pipe, $remainder = FALSE) {
-	global $config;
+function process_poller_output(&$rrdtool_pipe, $remainder = FALSE) {
+	global $config, $debug;
 
 	include_once($config["library_path"] . "/rrd.php");
 
@@ -256,6 +335,7 @@ function process_poller_output($rrdtool_pipe, $remainder = FALSE) {
 	$results = db_fetch_assoc("select
 		poller_output.output,
 		poller_output.time,
+		UNIX_TIMESTAMP(poller_output.time) as unix_time,
 		poller_output.local_data_id,
 		poller_item.rrd_path,
 		poller_item.rrd_name,
@@ -267,14 +347,31 @@ function process_poller_output($rrdtool_pipe, $remainder = FALSE) {
 	if (sizeof($results) > 0) {
 		/* create an array keyed off of each .rrd file */
 		foreach ($results as $item) {
-			$value = trim($item["output"]);
-			$unix_time = strtotime($item["time"]);
+			/* trim the default characters, but add single and double quotes */
+			$value = trim($item["output"], " \r\n\t\x0B\0\"'");
+			$unix_time = $item["unix_time"];
 
 			$rrd_update_array{$item["rrd_path"]}["local_data_id"] = $item["local_data_id"];
 
 			/* single one value output */
 			if ((is_numeric($value)) || ($value == "U")) {
 				$rrd_update_array{$item["rrd_path"]}["times"][$unix_time]{$item["rrd_name"]} = $value;
+			/* special case of one value output: hexadecimal to decimal conversion */
+			}elseif (is_hexadecimal($value)) {
+				/* attempt to accomodate 32bit and 64bit systems */
+				$value = str_replace(' ', '', $value);
+				if (strlen($value) <= 8 || ((2147483647+1) == intval(2147483647+1))) {
+					$rrd_update_array{$item["rrd_path"]}["times"][$unix_time]{$item["rrd_name"]} = hexdec($value);
+				}elseif (function_exists("bcpow")) {
+					$dec = 0;
+					$vallen = strlen($value);
+					for ($i = 1; $i <= $vallen; $i++) {
+						$dec = bcadd($dec, bcmul(strval(hexdec($value[$i - 1])), bcpow('16', strval($vallen - $i))));
+					}
+					$rrd_update_array{$item["rrd_path"]}["times"][$unix_time]{$item["rrd_name"]} = $dec;
+				}else{
+					$rrd_update_array{$item["rrd_path"]}["times"][$unix_time]{$item["rrd_name"]} = "U";
+				}
 			/* multiple value output */
 			}else{
 				$values = explode(" ", $value);
@@ -286,17 +383,21 @@ function process_poller_output($rrdtool_pipe, $remainder = FALSE) {
 					where data_template_rrd.data_input_field_id=data_input_fields.id
 					and data_template_rrd.local_data_id=" . $item["local_data_id"]), "data_name", "data_source_name");
 
-				for ($i=0; $i<count($values); $i++) {
-					if (preg_match("/^([a-zA-Z0-9_\.-]+):([eE0-9\+\.-]+)$/", $values[$i], $matches)) {
-						if (isset($rrd_field_names{$matches[1]})) {
-							if (read_config_option("log_verbosity") == POLLER_VERBOSITY_DEBUG) {
-								cacti_log("Parsed MULTI output field '" . $matches[0] . "' [map " . $matches[1] . "->" . $rrd_field_names{$matches[1]} . "]" , true, "POLLER");
+				if (sizeof($values)) {
+				foreach($values as $value) {
+					$matches = explode(":", $value);
+
+					if (sizeof($matches) == 2) {
+						if (isset($rrd_field_names{$matches[0]})) {
+							if (read_config_option("log_verbosity") >= POLLER_VERBOSITY_DEBUG || $debug) {
+								cacti_log("Parsed MULTI output field '" . $matches[0] . ":" . $matches[1] . "' [map " . $matches[0] . "->" . $rrd_field_names{$matches[0]} . "]" , true, "POLLER");
 							}
 
-							$rrd_update_array{$item["rrd_path"]}["times"][$unix_time]{$rrd_field_names{$matches[1]}} = $matches[2];
+							$rrd_update_array{$item["rrd_path"]}["times"][$unix_time]{$rrd_field_names{$matches[0]}} = $matches[1];
 						}
 					}
 				}
+				}
 			}
 
 			/* fallback values */
@@ -309,19 +410,35 @@ function process_poller_output($rrdtool_pipe, $remainder = FALSE) {
 
 		/* make sure each .rrd file has complete data */
 		reset($results);
+		$k = 0;
+		$data_ids = array();
 		foreach ($results as $item) {
-			$unix_time = strtotime($item["time"]);
+			$unix_time = $item["unix_time"];
 
 			if (isset($rrd_update_array{$item["rrd_path"]}["times"][$unix_time])) {
 				if ($item["rrd_num"] <= sizeof($rrd_update_array{$item["rrd_path"]}["times"][$unix_time])) {
-					db_execute("delete from poller_output where local_data_id='" . $item["local_data_id"] . "' and rrd_name='" . $item["rrd_name"] . "' and time='" . $item["time"] . "'");
+					$data_ids[] = $item["local_data_id"];
+					$k++;
+					if ($k % 10000 == 0) {
+						db_execute("DELETE FROM poller_output WHERE local_data_id IN (" . implode(",", $data_ids) . ")");
+						$k = 0;
+						$data_ids = array();
+					}
 				}else{
 					unset($rrd_update_array{$item["rrd_path"]}["times"][$unix_time]);
 				}
 			}
 		}
 
-		$rrds_processed = rrdtool_function_update($rrd_update_array, $rrdtool_pipe);
+		if ($k > 0) {
+			db_execute("DELETE FROM poller_output WHERE local_data_id IN (" . implode(",", $data_ids) . ")");
+		}
+
+		api_plugin_hook_function('poller_output', $rrd_update_array);
+
+		if (api_plugin_hook_function('poller_on_demand', $results)) {
+			$rrds_processed = rrdtool_function_update($rrd_update_array, $rrdtool_pipe);
+		}
 	}
 
 	return $rrds_processed;
