@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,20 +22,11 @@
  +-------------------------------------------------------------------------+
 */
 
-define("REGEXP_SNMP_TRIM", "(hex|counter(32|64)|gauge|gauge(32|64)|float|ipaddress|string|integer):");
+define("REGEXP_SNMP_TRIM", "/(hex|counter(32|64)|gauge|gauge(32|64)|float|ipaddress|string|integer):/i");
 
 define("SNMP_METHOD_PHP", 1);
 define("SNMP_METHOD_BINARY", 2);
 
-/* we must use an apostrophe to escape community names under Unix in case the user uses
-characters that the shell might interpret. the ucd-snmp binaries on Windows flip out when
-you do this, but are perfectly happy with a quotation mark. */
-if ($config["cacti_server_os"] == "unix") {
-	define("SNMP_ESCAPE_CHARACTER", "'");
-}else{
-	define("SNMP_ESCAPE_CHARACTER", "\"");
-}
-
 function cacti_snmp_get($hostname, $community, $oid, $version, $username, $password, $auth_proto, $priv_pass, $priv_proto, $context, $port = 161, $timeout = 500, $retries = 0, $environ = SNMP_POLLER) {
 	global $config;
 
@@ -46,11 +37,17 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 	}
 
 	/* do not attempt to poll invalid combinations */
-	if (($version == 0) || (($community == "") && ($version != 3))) {
+	if (($version == 0) || (!is_numeric($version)) ||
+		(!is_numeric($port)) ||
+		(!is_numeric($retries)) ||
+		(!is_numeric($timeout)) ||
+		(($community == "") && ($version != 3))
+		) {
 		return "U";
 	}
 
-	if (snmp_get_method($version) == SNMP_METHOD_PHP) {
+	if ((snmp_get_method($version) == SNMP_METHOD_PHP) &&
+		(!strlen($context) || ($version != 3))) {
 		/* make sure snmp* is verbose so we can see what types of data
 		we are getting back */
 		snmp_set_quick_print(0);
@@ -60,7 +57,7 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 		}elseif ($version == "2") {
 			$snmp_value = @snmp2_get("$hostname:$port", "$community", "$oid", ($timeout * 1000), $retries);
 		}else{
-			if ($priv_proto == "[None]") {
+			if ($priv_proto == "[None]" || $priv_pass == '') {
 				$proto = "authNoPriv";
 				$priv_proto = "";
 			}else{
@@ -69,7 +66,12 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 
 			$snmp_value = @snmp3_get("$hostname:$port", "$username", $proto, $auth_proto, "$password", $priv_proto, "$priv_pass", "$oid", ($timeout * 1000), $retries);
 		}
+
+		if ($snmp_value === false) {
+			cacti_log("WARNING: SNMP Get Timeout for Host:'$hostname', and OID:'$oid'", false);
+		}
 	}else {
+		$snmp_value = '';
 		/* ucd/net snmp want the timeout in seconds */
 		$timeout = ceil($timeout / 1000);
 
@@ -79,7 +81,7 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 			$snmp_auth = (read_config_option("snmp_version") == "ucd-snmp") ? snmp_escape_string($community) : "-c " . snmp_escape_string($community); /* v1/v2 - community string */
 			$version = "2c"; /* ucd/net snmp prefers this over '2' */
 		}elseif ($version == "3") {
-			if ($priv_proto == "[None]") {
+			if ($priv_proto == "[None]" || $priv_pass == '') {
 				$proto = "authNoPriv";
 				$priv_proto = "";
 			}else{
@@ -110,21 +112,33 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 		if (empty($snmp_auth)) { return; }
 
 		if (read_config_option("snmp_version") == "ucd-snmp") {
-			exec(read_config_option("path_snmpget") . " -O vt -v$version -t $timeout -r $retries $hostname:$port $snmp_auth $oid", $snmp_value);
+			/* escape the command to be executed and vulnerable parameters
+			 * numeric parameters are not subject to command injection
+			 * snmp_auth is treated seperately, see above */
+			exec(cacti_escapeshellcmd(read_config_option("path_snmpget")) . " -O vt -v$version -t $timeout -r $retries " . cacti_escapeshellarg($hostname) . ":$port $snmp_auth " . cacti_escapeshellarg($oid), $snmp_value);
 		}else {
-			exec(read_config_option("path_snmpget") . " -O fntev $snmp_auth -v $version -t $timeout -r $retries $hostname:$port $oid", $snmp_value);
+			exec(cacti_escapeshellcmd(read_config_option("path_snmpget")) . " -O fntev " . $snmp_auth . " -v $version -t $timeout -r $retries " . cacti_escapeshellarg($hostname) . ":$port " . cacti_escapeshellarg($oid), $snmp_value);
 		}
-	}
 
-	if (isset($snmp_value)) {
 		/* fix for multi-line snmp output */
 		if (is_array($snmp_value)) {
 			$snmp_value = implode(" ", $snmp_value);
 		}
 	}
 
+	/* fix for multi-line snmp output */
+	if (isset($snmp_value)) {
+		if (is_array($snmp_value)) {
+			$snmp_value = implode(" ", $snmp_value);
+		}
+	}
+
+	if (substr_count($snmp_value, "Timeout:")) {
+		cacti_log("WARNING: SNMP Get Timeout for Host:'$hostname', and OID:'$oid'", false);
+	}
+
 	/* strip out non-snmp data */
-	$snmp_value = format_snmp_string($snmp_value);
+	$snmp_value = format_snmp_string($snmp_value, false);
 
 	return $snmp_value;
 }
@@ -139,11 +153,17 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 	}
 
 	/* do not attempt to poll invalid combinations */
-	if (($version == 0) || (($community == "") && ($version != 3))) {
+	if (($version == 0) || (!is_numeric($version)) ||
+		(!is_numeric($port)) ||
+		(!is_numeric($retries)) ||
+		(!is_numeric($timeout)) ||
+		(($community == "") && ($version != 3))
+		) {
 		return "U";
 	}
 
-	if (snmp_get_method($version) == SNMP_METHOD_PHP) {
+	if ((snmp_get_method($version) == SNMP_METHOD_PHP) &&
+		(!strlen($context) || ($version != 3))) {
 		/* make sure snmp* is verbose so we can see what types of data
 		we are getting back */
 		snmp_set_quick_print(0);
@@ -153,7 +173,7 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 		}elseif ($version == "2") {
 			$snmp_value = @snmp2_getnext("$hostname:$port", "$community", "$oid", ($timeout * 1000), $retries);
 		}else{
-			if ($priv_proto == "[None]") {
+			if ($priv_proto == "[None]" || $priv_pass == '') {
 				$proto = "authNoPriv";
 				$priv_proto = "";
 			}else{
@@ -162,7 +182,12 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 
 			$snmp_value = @snmp3_getnext("$hostname:$port", "$username", $proto, $auth_proto, "$password", $priv_proto, "$priv_pass", "$oid", ($timeout * 1000), $retries);
 		}
+
+		if ($snmp_value === false) {
+			cacti_log("WARNING: SNMP GetNext Timeout for Host:'$hostname', and OID:'$oid'", false);
+		}
 	}else {
+		$snmp_value = '';
 		/* ucd/net snmp want the timeout in seconds */
 		$timeout = ceil($timeout / 1000);
 
@@ -172,7 +197,7 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 			$snmp_auth = (read_config_option("snmp_version") == "ucd-snmp") ? snmp_escape_string($community): "-c " . snmp_escape_string($community); /* v1/v2 - community string */
 			$version = "2c"; /* ucd/net snmp prefers this over '2' */
 		}elseif ($version == "3") {
-			if ($priv_proto == "[None]") {
+			if ($priv_proto == "[None]" || $priv_pass == '') {
 				$proto = "authNoPriv";
 				$priv_proto = "";
 			}else{
@@ -203,9 +228,12 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 		if (empty($snmp_auth)) { return; }
 
 		if (read_config_option("snmp_version") == "ucd-snmp") {
-			exec(read_config_option("path_snmpgetnext") . " -O vt -v$version -t $timeout -r $retries $hostname:$port $snmp_auth $oid", $snmp_value);
+			/* escape the command to be executed and vulnerable parameters
+			 * numeric parameters are not subject to command injection
+			 * snmp_auth is treated seperately, see above */
+			exec(cacti_escapeshellcmd(read_config_option("path_snmpgetnext")) . " -O vt -v$version -t $timeout -r $retries " . cacti_escapeshellarg($hostname) . ":$port $snmp_auth " . cacti_escapeshellarg($oid), $snmp_value);
 		}else {
-			exec(read_config_option("path_snmpgetnext") . " -O fntev $snmp_auth -v $version -t $timeout -r $retries $hostname:$port $oid", $snmp_value);
+			exec(cacti_escapeshellcmd(read_config_option("path_snmpgetnext")) . " -O fntev $snmp_auth -v $version -t $timeout -r $retries " . cacti_escapeshellarg($hostname) . ":$port " . cacti_escapeshellarg($oid), $snmp_value);
 		}
 	}
 
@@ -216,17 +244,23 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 		}
 	}
 
+	if (substr_count($snmp_value, "Timeout:")) {
+		cacti_log("WARNING: SNMP GetNext Timeout for Host:'$hostname', and OID:'$oid'", false);
+	}
+
 	/* strip out non-snmp data */
-	$snmp_value = format_snmp_string($snmp_value);
+	$snmp_value = format_snmp_string($snmp_value, false);
 
 	return $snmp_value;
 }
 
-function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $password, $auth_proto, $priv_pass, $priv_proto, $context, $port = 161, $timeout = 500, $retries = 0, $environ = SNMP_POLLER) {
-	global $config;
+function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $password, $auth_proto, $priv_pass, $priv_proto, $context, $port = 161, $timeout = 500, $retries = 0, $max_oids = 10, $environ = SNMP_POLLER) {
+	global $config, $banned_snmp_strings;
 
-	$snmp_array = array();
-	$temp_array = array();
+	$snmp_oid_included = true;
+	$snmp_auth	       = '';
+	$snmp_array        = array();
+	$temp_array        = array();
 
 	/* determine default retries */
 	if (($retries == 0) || (!is_numeric($retries))) {
@@ -234,9 +268,28 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 		if ($retries == "") $retries = 3;
 	}
 
+	/* determine default max_oids */
+	if (($max_oids == 0) || (!is_numeric($max_oids))) {
+		$max_oids = read_config_option("max_get_size");
+
+		if ($max_oids == "") $max_oids = 10;
+	}
+
+	/* do not attempt to poll invalid combinations */
+	if (($version == 0) || (!is_numeric($version)) ||
+		(!is_numeric($max_oids)) ||
+		(!is_numeric($port)) ||
+		(!is_numeric($retries)) ||
+		(!is_numeric($timeout)) ||
+		(($community == "") && ($version != 3))
+		) {
+		return array();
+	}
+
 	$path_snmpbulkwalk = read_config_option("path_snmpbulkwalk");
 
 	if ((snmp_get_method($version) == SNMP_METHOD_PHP) &&
+		(!strlen($context) || ($version != 3)) &&
 		(($version == 1) ||
 		(version_compare(phpversion(), "5.1") >= 0) ||
 		(!file_exists($path_snmpbulkwalk)))) {
@@ -248,6 +301,10 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 			snmp_set_oid_numeric_print(TRUE);
 		}
 
+		if (function_exists("snmprealwalk")) {
+			$snmp_oid_included = false;
+		}
+
 		snmp_set_quick_print(0);
 
 		if ($version == "1") {
@@ -255,7 +312,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 		}elseif ($version == "2") {
 			$temp_array = @snmp2_real_walk("$hostname:$port", "$community", "$oid", ($timeout * 1000), $retries);
 		}else{
-			if ($priv_proto == "[None]") {
+			if ($priv_proto == "[None]" || $priv_pass == '') {
 				$proto = "authNoPriv";
 				$priv_proto = "";
 			}else{
@@ -265,10 +322,28 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 			$temp_array = @snmp3_real_walk("$hostname:$port", "$username", $proto, $auth_proto, "$password", $priv_proto, "$priv_pass", "$oid", ($timeout * 1000), $retries);
 		}
 
+		if ($temp_array === false) {
+			cacti_log("WARNING: SNMP Walk Timeout for Host:'$hostname', and OID:'$oid'", false);
+		}
+
+		/* check for bad entries */
+		if (is_array($temp_array) && sizeof($temp_array)) {
+		foreach($temp_array as $key => $value) {
+			foreach($banned_snmp_strings as $item) {
+				if(strstr($value, $item) != "") {
+					unset($temp_array[$key]);
+					continue 2;
+				}
+			}
+		}
+		}
+
 		$o = 0;
 		for (@reset($temp_array); $i = @key($temp_array); next($temp_array)) {
-			$snmp_array[$o]["oid"] = ereg_replace("^\.", "", $i);
-			$snmp_array[$o]["value"] = format_snmp_string($temp_array[$i]);
+			if ($temp_array[$i] != "NULL") {
+				$snmp_array[$o]["oid"] = preg_replace("/^\./", "", $i);
+				$snmp_array[$o]["value"] = format_snmp_string($temp_array[$i], $snmp_oid_included);
+			}
 			$o++;
 		}
 	}else{
@@ -281,7 +356,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 			$snmp_auth = (read_config_option("snmp_version") == "ucd-snmp") ? snmp_escape_string($community): "-c " . snmp_escape_string($community); /* v1/v2 - community string */
 			$version = "2c"; /* ucd/net snmp prefers this over '2' */
 		}elseif ($version == "3") {
-			if ($priv_proto == "[None]") {
+			if ($priv_proto == "[None]" || $priv_pass == '') {
 				$proto = "authNoPriv";
 				$priv_proto = "";
 			}else{
@@ -309,45 +384,89 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 		}
 
 		if (read_config_option("snmp_version") == "ucd-snmp") {
-			$temp_array = exec_into_array(read_config_option("path_snmpwalk") . " -v$version -t $timeout -r $retries $hostname:$port $snmp_auth $oid");
+			/* escape the command to be executed and vulnerable parameters
+			 * numeric parameters are not subject to command injection
+			 * snmp_auth is treated seperately, see above */
+			$temp_array = exec_into_array(cacti_escapeshellcmd(read_config_option("path_snmpwalk")) . " -v$version -t $timeout -r $retries " . cacti_escapeshellarg($hostname) . ":$port $snmp_auth " . cacti_escapeshellarg($oid));
 		}else {
-			if (file_exists($path_snmpbulkwalk) && ($version > 1)) {
-				$temp_array = exec_into_array($path_snmpbulkwalk . " -O Qn $snmp_auth -v $version -t $timeout -r $retries -Cr50 $hostname:$port $oid");
+			if (file_exists($path_snmpbulkwalk) && ($version > 1) && ($max_oids > 1)) {
+				$temp_array = exec_into_array(cacti_escapeshellcmd($path_snmpbulkwalk) . " -O Qn $snmp_auth -v $version -t $timeout -r $retries -Cr$max_oids " . cacti_escapeshellarg($hostname) . ":$port " . cacti_escapeshellarg($oid));
 			}else{
-				$temp_array = exec_into_array(read_config_option("path_snmpwalk") . " -O Qn $snmp_auth -v $version -t $timeout -r $retries $hostname:$port $oid");
+				$temp_array = exec_into_array(cacti_escapeshellcmd(read_config_option("path_snmpwalk")) . " -O Qn $snmp_auth -v $version -t $timeout -r $retries " . cacti_escapeshellarg($hostname) . ":$port " . cacti_escapeshellarg($oid));
 			}
 		}
 
-		if ((sizeof($temp_array) == 0) ||
-			(substr_count($temp_array[0], "No Such")) ||
-			(trim($temp_array[0]) == "NULL") ||
-			(substr_count($temp_array[0], "No more variables")) ||
-			(substr_count($temp_array[0], "End of MIB")) ||
-			(substr_count($temp_array[0], "Wrong Type"))) {
-			return array();
+		if (substr_count(implode(" ", $temp_array), "Timeout:")) {
+			cacti_log("WARNING: SNMP Walk Timeout for Host:'$hostname', and OID:'$oid'", false);
+		}
+
+		/* check for bad entries */
+		if (is_array($temp_array) && sizeof($temp_array)) {
+		foreach($temp_array as $key => $value) {
+			foreach($banned_snmp_strings as $item) {
+				if(strstr($value, $item) != "") {
+					unset($temp_array[$key]);
+					continue 2;
+				}
+			}
+		}
 		}
 
 		for ($i=0; $i < count($temp_array); $i++) {
-			$snmp_array[$i]["oid"] = trim(ereg_replace("(.*) =.*", "\\1", $temp_array[$i]));
-			$snmp_array[$i]["value"] = format_snmp_string($temp_array[$i]);
+			if ($temp_array[$i] != "NULL") {
+				$snmp_array[$i]["oid"]   = trim(preg_replace("/(.*) =.*/", "\\1", $temp_array[$i]));
+				$snmp_array[$i]["value"] = format_snmp_string($temp_array[$i], true);
+			}
 		}
 	}
 
 	return $snmp_array;
 }
 
-function format_snmp_string($string) {
-	/* strip off all leading junk (the oid and stuff) */
-	$string = trim(ereg_replace(".*= ?", "", $string));
+function format_snmp_string($string, $snmp_oid_included) {
+	global $banned_snmp_strings;
 
-	/* remove ALL quotes */
+	$string = preg_replace(REGEXP_SNMP_TRIM, "", trim($string));
+
+	if (substr($string, 0, 7) == "No Such") {
+		return "";
+	}
+
+	if ($snmp_oid_included) {
+		/* strip off all leading junk (the oid and stuff) */
+		$string_array = explode("=", $string);
+		if (sizeof($string_array) == 1) {
+			/* trim excess first */
+			$string = trim($string);
+		}else if ((substr($string, 0, 1) == ".") || (strpos($string, "::") !== false)) {
+			/* drop the OID from the array */
+			array_shift($string_array);
+			$string = trim(implode("=", $string_array));
+		}else {
+			$string = trim(implode("=", $string_array));
+		}
+	}
+
+	/* return the easiest value */
+	if ($string == "") {
+		return $string;
+	}
+
+	/* now check for the second most obvious */
+	if (is_numeric($string)) {
+		return trim($string);
+	}
+
+	/* remove ALL quotes, and other special delimiters */
 	$string = str_replace("\"", "", $string);
 	$string = str_replace("'", "", $string);
 	$string = str_replace(">", "", $string);
 	$string = str_replace("<", "", $string);
 	$string = str_replace("\\", "", $string);
+	$string = str_replace("\n", " ", $string);
+	$string = str_replace("\r", " ", $string);
 
-	/* Account for invalid type messages */
+	/* account for invalid MIB files */
 	if (substr_count($string, "Wrong Type")) {
 		$string = strrev($string);
 		if ($position = strpos($string, ":")) {
@@ -367,12 +486,14 @@ function format_snmp_string($string) {
 	$string = trim($string);
 
 	if ((substr_count($string, "Hex-STRING:")) ||
+		(substr_count($string, "Hex-")) ||
 		(substr_count($string, "Hex:"))) {
 		/* strip of the 'Hex-STRING:' */
-		$string = eregi_replace("Hex-STRING: ?", "", $string);
-		$string = eregi_replace("Hex: ?", "", $string);
+		$string = preg_replace("/Hex-STRING: ?/i", "", $string);
+		$string = preg_replace("/Hex: ?/i", "", $string);
+		$string = preg_replace("/Hex- ?/i", "", $string);
 
-		$string_array = split(" ", $string);
+		$string_array = explode(" ", $string);
 
 		/* loop through each string character and make ascii */
 		$string = "";
@@ -399,11 +520,11 @@ function format_snmp_string($string) {
 		}
 
 		if ($ishex) $string = $hexval;
-	}elseif (preg_match("/(hex:\?)?([a-fA-F0-9]{1,2}(:|\s)){5}/", $string)) {
+	}elseif (preg_match("/(hex:\?)?([a-fA-F0-9]{1,2}(:|\s)){5}/i", $string)) {
 		$octet = "";
 
-		/* strip of the 'hex:' */
-		$string = eregi_replace("hex: ?", "", $string);
+		/* strip off the 'hex:' */
+		$string = preg_replace("/hex: ?/i", "", $string);
 
 		/* split the hex on the delimiter */
 		$octets = preg_split("/\s|:/", $string);
@@ -423,12 +544,27 @@ function format_snmp_string($string) {
 		$string = $matches[1];
 	}
 
-	$string = eregi_replace(REGEXP_SNMP_TRIM, "", $string);
+	foreach($banned_snmp_strings as $item) {
+		if(strstr($string, $item) != "") {
+			$string = "";
+			break;
+		}
+	}
 
-	return trim($string);
+	return $string;
 }
 
 function snmp_escape_string($string) {
+	global $config;
+
+	if (! defined("SNMP_ESCAPE_CHARACTER")) {
+		if ($config["cacti_server_os"] == "win32") {
+			define("SNMP_ESCAPE_CHARACTER", "\"");
+		}else{
+			define("SNMP_ESCAPE_CHARACTER", "'");
+		}
+	}
+
 	if (substr_count($string, SNMP_ESCAPE_CHARACTER)) {
 		$string = substr_replace(SNMP_ESCAPE_CHARACTER, "\\" . SNMP_ESCAPE_CHARACTER, $string);
 	}
