@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,33 +23,44 @@
 */
 
 function repopulate_poller_cache() {
-	db_execute("truncate table poller_item");
-
 	$poller_data = db_fetch_assoc("select id from data_local");
+	$poller_items   = array();
+	$local_data_ids = array();
 
 	if (sizeof($poller_data) > 0) {
 	foreach ($poller_data as $data) {
-		update_poller_cache($data["id"], true);
+			$poller_items = array_merge($poller_items, update_poller_cache($data["id"]));
 	}
+
+		poller_update_poller_cache_from_buffer($local_data_ids, $poller_items);
+
 	}
 }
 
 function update_poller_cache_from_query($host_id, $data_query_id) {
 	$poller_data = db_fetch_assoc("select id from data_local where host_id = '$host_id' and snmp_query_id = '$data_query_id'");
 
+	$poller_items = array();
+
 	if (sizeof($poller_data) > 0) {
 		foreach ($poller_data as $data) {
-			update_poller_cache($data["id"]);
+			$local_data_ids[] = $data["id"];
+
+			$poller_items = array_merge($poller_items, update_poller_cache($data["id"]));
 		}
+
+		poller_update_poller_cache_from_buffer($local_data_ids, $poller_items);
 	}
 }
 
-function update_poller_cache($local_data_id, $truncate_performed = false) {
+function update_poller_cache($local_data_id, $commit = false) {
 	global $config;
 
 	include_once($config["library_path"] . "/data_query.php");
 	include_once($config["library_path"] . "/api_poller.php");
 
+	$poller_items = array();
+
 	$data_input = db_fetch_row("select
 		data_input.id,
 		data_input.type_id,
@@ -63,22 +74,14 @@ function update_poller_cache($local_data_id, $truncate_performed = false) {
 
 	$data_source = db_fetch_row("select host_id,snmp_query_id,snmp_index from data_local where id=$local_data_id");
 
-	/* clear cache for this local_data_id */
-	if (!$truncate_performed) {
-		db_execute("delete from poller_item where local_data_id=$local_data_id");
-	}
-
 	/* we have to perform some additional sql queries if this is a "query" */
 	if (($data_input["type_id"] == DATA_INPUT_TYPE_SNMP_QUERY) ||
 		($data_input["type_id"] == DATA_INPUT_TYPE_SCRIPT_QUERY) ||
 		($data_input["type_id"] == DATA_INPUT_TYPE_QUERY_SCRIPT_SERVER)){
 		$field = data_query_field_list($data_input["data_template_data_id"]);
 
-		if (($data_input["type_id"] != DATA_INPUT_TYPE_PHP_SCRIPT_SERVER) &&
-			(empty($field["output_type"]))) { return; }
-
 		if (strlen($field["output_type"])) {
-			$output_type_sql = "and snmp_query_graph_rrd.snmp_query_graph_id=" . $field["output_type"];
+			$output_type_sql = "and snmp_query_graph_rrd.snmp_query_graph_id='" . $field["output_type"] . "'";
 		}else{
 			$output_type_sql = "";
 		}
@@ -90,7 +93,8 @@ function update_poller_cache($local_data_id, $truncate_performed = false) {
 			where snmp_query_graph_rrd.data_template_rrd_id=data_template_rrd.local_data_template_rrd_id
 			$output_type_sql
 			and snmp_query_graph_rrd.data_template_id=" . $data_input["data_template_id"] . "
-			and data_template_rrd.local_data_id=$local_data_id");
+			and data_template_rrd.local_data_id=$local_data_id
+			order by data_template_rrd.id");
 	}
 
 	if ($data_input["active"] == "on") {
@@ -116,47 +120,137 @@ function update_poller_cache($local_data_id, $truncate_performed = false) {
 				$data_source_item_name = "";
 			}
 
-			api_poller_cache_item_add($data_source["host_id"], array(), $local_data_id, $data_input["rrd_step"], $action, $data_source_item_name, 1, addslashes($script_path));
+			$poller_items[] = api_poller_cache_item_add($data_source["host_id"], array(), $local_data_id, $data_input["rrd_step"], $action, $data_source_item_name, 1, addslashes($script_path));
 		}else if ($data_input["type_id"] == DATA_INPUT_TYPE_SNMP) { /* snmp */
-			$host_fields = array_rekey(db_fetch_assoc("select
+			/* get the host override fields */
+			$data_template_id = db_fetch_cell("SELECT data_template_id FROM data_template_data WHERE local_data_id=$local_data_id");
+
+			/* get host fields first */
+			$host_fields = array_rekey(db_fetch_assoc("SELECT
 				data_input_fields.type_code,
 				data_input_data.value
-				from data_input_fields left join data_input_data
-				on (data_input_fields.id=data_input_data.data_input_field_id and data_input_data.data_template_data_id=" . $data_input["data_template_data_id"] . ")
-				where (data_input_fields.type_code='snmp_oid'
-					or data_input_fields.type_code='hostname'
-					or data_input_fields.type_code='snmp_community'
-					or data_input_fields.type_code='snmp_username'
-					or data_input_fields.type_code='snmp_password'
-					or data_input_fields.type_code='snmp_auth_protocol'
-					or data_input_fields.type_code='snmp_priv_passphrase'
-					or data_input_fields.type_code='snmp_priv_protocol'
-					or data_input_fields.type_code='snmp_context'
-					or data_input_fields.type_code='snmp_version'
-					or data_input_fields.type_code='snmp_port'
-					or data_input_fields.type_code='snmp_timeout')
-				and data_input_data.value != ''"), "type_code", "value");
+				FROM data_input_fields
+				LEFT JOIN data_input_data
+				ON (data_input_fields.id=data_input_data.data_input_field_id and data_input_data.data_template_data_id=" . $data_input["data_template_data_id"] . ")
+				WHERE ((type_code LIKE 'snmp_%') OR (type_code='hostname') OR (type_code='host_id'))
+				AND data_input_data.value != ''"), "type_code", "value");
+
+			$data_template_fields = array_rekey(db_fetch_assoc("SELECT
+				data_input_fields.type_code,
+				data_input_data.value
+				FROM data_input_fields
+				LEFT JOIN data_input_data
+				ON (data_input_fields.id=data_input_data.data_input_field_id and data_input_data.data_template_data_id=$data_template_id)
+				WHERE ((type_code LIKE 'snmp_%') OR (type_code='hostname'))
+				AND data_template_data_id=$data_template_id
+				AND data_input_data.value != ''"), "type_code", "value");
+
+			if (sizeof($host_fields)) {
+				if (sizeof($data_template_fields)) {
+				foreach($data_template_fields as $key => $value) {
+					if (!isset($host_fields[$key])) {
+						$host_fields[$key] = $value;
+					}
+				}
+				}
+			} elseif (sizeof($data_template_fields)) {
+				$host_fields = $data_template_fields;
+			}
 
 			$data_template_rrd_id = db_fetch_cell("select id from data_template_rrd where local_data_id=$local_data_id");
 
-			api_poller_cache_item_add($data_source["host_id"], $host_fields, $local_data_id, $data_input["rrd_step"], 0, get_data_source_item_name($data_template_rrd_id), 1, (isset($host_fields["snmp_oid"]) ? $host_fields["snmp_oid"] : ""));
+			$poller_items[] = api_poller_cache_item_add($data_source["host_id"], $host_fields, $local_data_id, $data_input["rrd_step"], 0, get_data_source_item_name($data_template_rrd_id), 1, (isset($host_fields["snmp_oid"]) ? $host_fields["snmp_oid"] : ""));
 		}else if ($data_input["type_id"] == DATA_INPUT_TYPE_SNMP_QUERY) { /* snmp query */
 			$snmp_queries = get_data_query_array($data_source["snmp_query_id"]);
 
+			/* get the host override fields */
+			$data_template_id = db_fetch_cell("SELECT data_template_id FROM data_template_data WHERE local_data_id=$local_data_id");
+
+			/* get host fields first */
+			$host_fields = array_rekey(db_fetch_assoc("SELECT
+				data_input_fields.type_code,
+				data_input_data.value
+				FROM data_input_fields
+				LEFT JOIN data_input_data
+				ON (data_input_fields.id=data_input_data.data_input_field_id and data_input_data.data_template_data_id=" . $data_input["data_template_data_id"] . ")
+				WHERE ((type_code LIKE 'snmp_%') OR (type_code='hostname'))
+				AND data_input_data.value != ''"), "type_code", "value");
+
+			$data_template_fields = array_rekey(db_fetch_assoc("SELECT
+				data_input_fields.type_code,
+				data_input_data.value
+				FROM data_input_fields
+				LEFT JOIN data_input_data
+				ON (data_input_fields.id=data_input_data.data_input_field_id and data_input_data.data_template_data_id=$data_template_id)
+				WHERE ((type_code LIKE 'snmp_%') OR (type_code='hostname'))
+				AND data_template_data_id=$data_template_id
+				AND data_input_data.value != ''"), "type_code", "value");
+
+			if (sizeof($host_fields)) {
+				if (sizeof($data_template_fields)) {
+				foreach($data_template_fields as $key => $value) {
+					if (!isset($host_fields[$key])) {
+						$host_fields[$key] = $value;
+					}
+				}
+				}
+			} elseif (sizeof($data_template_fields)) {
+				$host_fields = $data_template_fields;
+			}
+
 			if (sizeof($outputs) > 0) {
 			foreach ($outputs as $output) {
 				if (isset($snmp_queries["fields"]{$output["snmp_field_name"]}["oid"])) {
 					$oid = $snmp_queries["fields"]{$output["snmp_field_name"]}["oid"] . "." . $data_source["snmp_index"];
+
+					if (isset($snmp_queries["fields"]{$output["snmp_field_name"]}["oid_suffix"])) {
+						$oid .= "." . $snmp_queries["fields"]{$output["snmp_field_name"]}["oid_suffix"];
+					}
 				}
 
 				if (!empty($oid)) {
-					api_poller_cache_item_add($data_source["host_id"], array(), $local_data_id, $data_input["rrd_step"], 0, get_data_source_item_name($output["data_template_rrd_id"]), sizeof($outputs), $oid);
+					$poller_items[] = api_poller_cache_item_add($data_source["host_id"], $host_fields, $local_data_id, $data_input["rrd_step"], 0, get_data_source_item_name($output["data_template_rrd_id"]), sizeof($outputs), $oid);
 				}
 			}
 			}
 		}else if (($data_input["type_id"] == DATA_INPUT_TYPE_SCRIPT_QUERY) || ($data_input["type_id"] == DATA_INPUT_TYPE_QUERY_SCRIPT_SERVER)) { /* script query */
 			$script_queries = get_data_query_array($data_source["snmp_query_id"]);
 
+			/* get the host override fields */
+			$data_template_id = db_fetch_cell("SELECT data_template_id FROM data_template_data WHERE local_data_id=$local_data_id");
+
+			/* get host fields first */
+			$host_fields = array_rekey(db_fetch_assoc("SELECT
+				data_input_fields.type_code,
+				data_input_data.value
+				FROM data_input_fields
+				LEFT JOIN data_input_data
+				ON (data_input_fields.id=data_input_data.data_input_field_id and data_input_data.data_template_data_id=" . $data_input["data_template_data_id"] . ")
+				WHERE ((type_code LIKE 'snmp_%') OR (type_code='hostname'))
+				AND data_input_data.value != ''"), "type_code", "value");
+
+			$data_template_fields = array_rekey(db_fetch_assoc("SELECT
+				data_input_fields.type_code,
+				data_input_data.value
+				FROM data_input_fields
+				LEFT JOIN data_input_data
+				ON (data_input_fields.id=data_input_data.data_input_field_id and data_input_data.data_template_data_id=$data_template_id)
+				WHERE ((type_code LIKE 'snmp_%') OR (type_code='hostname'))
+				AND data_template_data_id=$data_template_id
+				AND data_input_data.value != ''"), "type_code", "value");
+
+			if (sizeof($host_fields)) {
+				if (sizeof($data_template_fields)) {
+				foreach($data_template_fields as $key => $value) {
+					if (!isset($host_fields[$key])) {
+						$host_fields[$key] = $value;
+					}
+				}
+				}
+			} elseif (sizeof($data_template_fields)) {
+				$host_fields = $data_template_fields;
+			}
+
 			if (sizeof($outputs) > 0) {
 				foreach ($outputs as $output) {
 					if (isset($script_queries["fields"]{$output["snmp_field_name"]}["query_name"])) {
@@ -176,47 +270,170 @@ function update_poller_cache($local_data_id, $truncate_performed = false) {
 					}
 
 					if (isset($script_path)) {
-						api_poller_cache_item_add($data_source["host_id"], array(), $local_data_id, $data_input["rrd_step"], $action, get_data_source_item_name($output["data_template_rrd_id"]), sizeof($outputs), addslashes($script_path));
+						$poller_items[] = api_poller_cache_item_add($data_source["host_id"], $host_fields, $local_data_id, $data_input["rrd_step"], $action, get_data_source_item_name($output["data_template_rrd_id"]), sizeof($outputs), addslashes($script_path));
 					}
 				}
 			}
 		}
 	}
+
+	if ($commit) {
+		poller_update_poller_cache_from_buffer((array)$local_data_id, $poller_items);
+	} else {
+		return $poller_items;
+	}
+}
+
+function push_out_data_input_method($data_input_id) {
+	$local_data_ids = db_fetch_assoc("SELECT DISTINCT local_data_id
+		FROM data_template_data
+		WHERE data_input_id='$data_input_id'
+		AND local_data_id>0");
+
+	$poller_items = array();
+	$_my_local_data_ids = array();
+
+	if (sizeof($local_data_ids)) {
+		foreach($local_data_ids as $row) {
+			$_my_local_data_ids[] = $row["local_data_id"];
+
+			$poller_items = array_merge($poller_items, update_poller_cache($row["local_data_id"]));
+		}
+
+		poller_update_poller_cache_from_buffer($_my_local_data_ids, $poller_items);
+	}
+}
+
+function poller_update_poller_cache_from_buffer($local_data_ids, &$poller_items) {
+	/* set all fields present value to 0, to mark the outliers when we are all done */
+	$ids = array();
+	if (sizeof($local_data_ids)) {
+		$count = 0;
+		foreach($local_data_ids as $id) {
+			if ($count == 0) {
+				$ids = $id;
+			} else {
+				$ids .= ", " . $id;
+			}
+			$count++;
+		}
+
+		db_execute("UPDATE poller_item SET present=0 WHERE local_data_id IN ($ids)");
+	} else {
+		db_execute("UPDATE poller_item SET present=0");
+	}
+
+	/* setup the database call */
+	$sql_prefix   = "INSERT INTO poller_item (local_data_id, poller_id, host_id, action, hostname, " .
+			"snmp_community, snmp_version, snmp_timeout, snmp_username, snmp_password, " .
+			"snmp_auth_protocol, snmp_priv_passphrase, snmp_priv_protocol, snmp_context, " .
+			"snmp_port, rrd_name, rrd_path, rrd_num, rrd_step, rrd_next_step, arg1, arg2, arg3, present) " .
+			"VALUES";
+
+	$sql_suffix   = " ON DUPLICATE KEY UPDATE poller_id=VALUES(poller_id), host_id=VALUES(host_id), action=VALUES(action), hostname=VALUES(hostname), " .
+		"snmp_community=VALUES(snmp_community), snmp_version=VALUES(snmp_version), snmp_timeout=VALUES(snmp_timeout), " .
+		"snmp_username=VALUES(snmp_username), snmp_password=VALUES(snmp_password), snmp_auth_protocol=VALUES(snmp_auth_protocol), " .
+		"snmp_priv_passphrase=VALUES(snmp_priv_passphrase), snmp_priv_protocol=VALUES(snmp_priv_protocol), " .
+		"snmp_context=VALUES(snmp_context), snmp_port=VALUES(snmp_port), rrd_path=VALUES(rrd_path), rrd_num=VALUES(rrd_num), " .
+		"rrd_step=VALUES(rrd_step), rrd_next_step=VALUES(rrd_next_step), arg1=VALUES(arg1), arg2=VALUES(arg2), " .
+		"arg3=VALUES(arg3), present=VALUES(present)";
+
+	/* use a reasonable insert buffer, the default is 1MByte */
+	$max_packet   = 256000;
+
+	/* setup somme defaults */
+	$overhead     = strlen($sql_prefix) + strlen($sql_suffix);
+	$buf_len      = 0;
+	$buf_count    = 0;
+	$buffer       = "";
+
+	if (sizeof($poller_items)) {
+	foreach($poller_items AS $record) {
+		/* take care of invalid entries */
+		if (strlen($record) == 0) continue;
+
+		if ($buf_count == 0) {
+			$delim = " ";
+		} else {
+			$delim = ", ";
+		}
+
+		$buffer .= $delim . $record;
+
+		$buf_len += strlen($record);
+
+		if (($overhead + $buf_len) > ($max_packet - 1024)) {
+			db_execute($sql_prefix . $buffer . $sql_suffix);
+
+			$buffer    = "";
+			$buf_len   = 0;
+			$buf_count = 0;
+		} else {
+			$buf_count++;
+		}
+	}
+	}
+
+	if ($buf_count > 0) {
+		db_execute($sql_prefix . $buffer . $sql_suffix);
+	}
+
+	/* remove stale records from the poller cache */
+	if (sizeof($ids)) {
+		db_execute("DELETE FROM poller_item WHERE present=0 AND local_data_id IN ($ids)");
+	}else{
+		db_execute("DELETE FROM poller_item WHERE present=0");
+	}
 }
 
 function push_out_host($host_id, $local_data_id = 0, $data_template_id = 0) {
 	/* ok here's the deal: first we need to find every data source that uses this host.
 	then we go through each of those data sources, finding each one using a data input method
 	with "special fields". if we find one, fill it will the data here from this host */
+	/* setup the poller items array */
+	$poller_items   = array();
+	$local_data_ids = array();
+	$hosts          = array();
+	$sql_where      = "";
 
-	if (!empty($data_template_id)) {
-		$hosts = db_fetch_assoc("select host_id from data_local where data_template_id=$data_template_id group by host_id");
+	/* setup the sql where, and if using a host, get it's host information */
+	if ($host_id != 0) {
+		/* get all information about this host so we can write it to the data source */
+		$hosts[$host_id] = db_fetch_row("select id AS host_id, host.* from host where id=$host_id");
 
-		if (sizeof($hosts) > 0) {
-		foreach ($hosts as $host) {
-			push_out_host($host["host_id"]);
-		}
-		}
+		$sql_where .= " AND data_local.host_id=$host_id";
 	}
 
-	if (empty($host_id)) { return 0; }
+	/* sql where fom local_data_id */
+	if ($local_data_id != 0) {
+		$sql_where .= " AND data_local.id=$local_data_id";
+	}
 
-	/* get all information about this host so we can write it to the data source */
-	$host = db_fetch_row("select * from host where id=$host_id");
+	/* sql where fom data_template_id */
+	if ($data_template_id != 0) {
+		$sql_where .= " AND data_template_data.data_template_id=$data_template_id";
+	}
 
-	$data_sources = db_fetch_assoc("select
+	$data_sources = db_fetch_assoc("SELECT
 		data_template_data.id,
 		data_template_data.data_input_id,
 		data_template_data.local_data_id,
-		data_template_data.local_data_template_data_id
-		from (data_local,data_template_data)
-		where " . (empty($local_data_id) ? "data_local.host_id=$host_id" : "data_local.id=$local_data_id") . "
-		and data_local.id=data_template_data.local_data_id
-		and data_template_data.data_input_id>0");
+		data_template_data.local_data_template_data_id,
+		data_local.host_id
+		FROM (data_local, data_template_data)
+		WHERE data_local.id=data_template_data.local_data_id
+		AND data_template_data.data_input_id>0
+		$sql_where");
 
 	/* loop through each matching data source */
 	if (sizeof($data_sources) > 0) {
 	foreach ($data_sources as $data_source) {
+		/* set the host information */
+		if (!isset($hosts[$data_source["host_id"]])) {
+			$hosts[$data_source["host_id"]] = db_fetch_row("select * from host where id=" . $data_source["host_id"]);
+		}
+		$host = $hosts[$data_source["host_id"]];
+
 		/* get field information from the data template */
 		if (!isset($template_fields{$data_source["local_data_template_data_id"]})) {
 			$template_fields{$data_source["local_data_template_data_id"]} = db_fetch_assoc("select
@@ -239,16 +456,21 @@ function push_out_host($host_id, $local_data_id = 0, $data_template_id = 0) {
 		 - the field is set to 'templated' */
 		if (sizeof($template_fields{$data_source["local_data_template_data_id"]})) {
 		foreach ($template_fields{$data_source["local_data_template_data_id"]} as $template_field) {
-			if ((eregi('^' . VALID_HOST_FIELDS . '$', $template_field["type_code"])) && ($template_field["value"] == "") && ($template_field["t_value"] == "")) {
+			if ((preg_match('/^' . VALID_HOST_FIELDS . '$/i', $template_field["type_code"])) && ($template_field["value"] == "") && ($template_field["t_value"] == "")) {
 				db_execute("replace into data_input_data (data_input_field_id,data_template_data_id,value) values (" . $template_field["id"] . "," . $data_source["id"] . ",'" . $host{$template_field["type_code"]} . "')");
 			}
 		}
 		}
 
-		/* make sure to update the poller cache as well */
-		update_poller_cache($data_source["local_data_id"], false);
+		/* flag an update to the poller cache as well */
+		$local_data_ids[] = $data_source["local_data_id"];
+		$poller_items     = array_merge($poller_items, update_poller_cache($data_source["local_data_id"]));
 	}
 	}
+
+	if (sizeof($local_data_ids)) {
+		poller_update_poller_cache_from_buffer($local_data_ids, $poller_items);
+	}
 }
 
 function duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title) {
@@ -308,6 +530,8 @@ function duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title) {
 		reset($struct_graph_item);
 
 		$save["id"] = 0;
+		/* save a hash only for graph_template copy operations */
+		$save["hash"] = (!empty($_graph_template_id) ? get_hash_graph_template(0, "graph_template_item") : 0);
 		$save["local_graph_id"] = (isset($local_graph_id) ? $local_graph_id : 0);
 		$save["graph_template_id"] = (!empty($_local_graph_id) ? $graph_template_item["graph_template_id"] : $graph_template_id);
 		$save["local_graph_template_item_id"] = (isset($graph_template_item["local_graph_template_item_id"]) ? $graph_template_item["local_graph_template_item_id"] : 0);
@@ -326,13 +550,14 @@ function duplicate_graph($_local_graph_id, $_graph_template_id, $graph_title) {
 		foreach ($graph_template_inputs as $graph_template_input) {
 			unset($save);
 
-			$save["id"] = 0;
+			$save["id"]                = 0;
 			$save["graph_template_id"] = $graph_template_id;
-			$save["name"] = $graph_template_input["name"];
-			$save["description"] = $graph_template_input["description"];
-			$save["column_name"] = $graph_template_input["column_name"];
+			$save["name"]              = $graph_template_input["name"];
+			$save["description"]       = $graph_template_input["description"];
+			$save["column_name"]       = $graph_template_input["column_name"];
+			$save["hash"]              = get_hash_graph_template(0, "graph_template_input");
 
-			$graph_template_input_id = sql_save($save, "graph_template_input");
+			$graph_template_input_id   = sql_save($save, "graph_template_input");
 
 			$graph_template_input_defs = db_fetch_assoc("select * from graph_template_input_defs where graph_template_input_id=" . $graph_template_input["id"]);
 
@@ -417,13 +642,22 @@ function duplicate_data_source($_local_data_id, $_data_template_id, $data_source
 		unset($save);
 		reset($struct_data_source_item);
 
-		$save["id"] = 0;
-		$save["local_data_id"] = (isset($local_data_id) ? $local_data_id : 0);
+		$save["id"]                         = 0;
+		$save["local_data_id"]              = (isset($local_data_id) ? $local_data_id : 0);
 		$save["local_data_template_rrd_id"] = (isset($data_template_rrd["local_data_template_rrd_id"]) ? $data_template_rrd["local_data_template_rrd_id"] : 0);
-		$save["data_template_id"] = (!empty($_local_data_id) ? $data_template_rrd["data_template_id"] : $data_template_id);
+		$save["data_template_id"]           = (!empty($_local_data_id) ? $data_template_rrd["data_template_id"] : $data_template_id);
+		if ($save["local_data_id"] == 0) {
+			$save["hash"]                   = get_hash_data_template($data_template_rrd["local_data_template_rrd_id"], "data_template_item");
+		} else {
+			$save["hash"] = '';
+		}
 
 		while (list($field, $array) = each($struct_data_source_item)) {
 			$save{$field} = $data_template_rrd{$field};
+
+			if (isset($data_template_rrd{"t_" . $field})) {
+				$save{"t_" . $field} = $data_template_rrd{"t_" . $field};
+			}
 		}
 
 		$data_template_rrd_id = sql_save($save, "data_template_rrd");
@@ -468,7 +702,7 @@ function duplicate_host_template($_host_template_id, $host_template_title) {
 
 	reset($fields_host_template_edit);
 	while (list($field, $array) = each($fields_host_template_edit)) {
-		if (!ereg("^hidden", $array["method"])) {
+		if (!preg_match("/^hidden/", $array["method"])) {
 			$save[$field] = $host_template[$field];
 		}
 	}
@@ -490,4 +724,43 @@ function duplicate_host_template($_host_template_id, $host_template_title) {
 	}
 }
 
+function duplicate_cdef($_cdef_id, $cdef_title) {
+	global $fields_cdef_edit;
+
+	$cdef = db_fetch_row("select * from cdef where id=$_cdef_id");
+	$cdef_items = db_fetch_assoc("select * from cdef_items where cdef_id=$_cdef_id");
+
+	/* substitute the title variable */
+	$cdef["name"] = str_replace("<cdef_title>", $cdef["name"], $cdef_title);
+
+	/* create new entry: host_template */
+	$save["id"] = 0;
+	$save["hash"] = get_hash_cdef(0);
+
+	reset($fields_cdef_edit);
+	while (list($field, $array) = each($fields_cdef_edit)) {
+		if (!preg_match("/^hidden/", $array["method"])) {
+			$save[$field] = $cdef[$field];
+		}
+	}
+
+	$cdef_id = sql_save($save, "cdef");
+
+	/* create new entry(s): cdef_items */
+	if (sizeof($cdef_items) > 0) {
+		foreach ($cdef_items as $cdef_item) {
+			unset($save);
+
+			$save["id"] = 0;
+			$save["hash"] = get_hash_cdef(0, "cdef_item");
+			$save["cdef_id"] = $cdef_id;
+			$save["sequence"] = $cdef_item["sequence"];
+			$save["type"] = $cdef_item["type"];
+			$save["value"] = $cdef_item["value"];
+
+			sql_save($save, "cdef_items");
+		}
+	}
+}
+
 ?>
