@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -66,6 +66,7 @@ function update_data_source_title_cache_from_host($host_id) {
    @arg $local_data_id - (int) the ID of the data source to update the title cache for */
 function update_data_source_title_cache($local_data_id) {
 	db_execute("update data_template_data set name_cache='" . addslashes(get_data_source_title($local_data_id)) . "' where local_data_id=$local_data_id");
+	api_plugin_hook_function('update_data_source_title_cache', $local_data_id);
 }
 
 /* update_graph_title_cache_from_template - updates the title cache for all graphs
@@ -120,7 +121,7 @@ function update_graph_title_cache($local_graph_id) {
 function null_out_substitutions($string) {
 	global $regexps;
 
-	return eregi_replace("\|host_" . VALID_HOST_FIELDS . "\|( - )?", "", $string);
+	return preg_replace("/\|host_" . VALID_HOST_FIELDS . "\|( - )?/i", "", $string);
 }
 
 /* expand_title - takes a string and substitutes all data query variables contained in it or cleans
@@ -161,25 +162,29 @@ function substitute_script_query_path($path) {
    @arg $host_id - (int) the host ID to match
    @returns - the original string with all of the variable substitutions made */
 function substitute_host_data($string, $l_escape_string, $r_escape_string, $host_id) {
-	if (!isset($_SESSION["sess_host_cache_array"][$host_id])) {
-		$host = db_fetch_row("select * from host where id=$host_id");
-		$_SESSION["sess_host_cache_array"][$host_id] = $host;
-	}
+	if (!empty($host_id)) {
+		if (!isset($_SESSION["sess_host_cache_array"][$host_id])) {
+			$host = db_fetch_row("SELECT * FROM host WHERE id=$host_id");
+			$_SESSION["sess_host_cache_array"][$host_id] = $host;
+		}
 
-	$string = str_replace($l_escape_string . "host_management_ip" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["hostname"], $string); /* for compatability */
-	$string = str_replace($l_escape_string . "host_hostname" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["hostname"], $string);
-	$string = str_replace($l_escape_string . "host_description" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["description"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_community" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_community"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_version" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_version"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_username" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_username"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_password" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_password"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_auth_protocol" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_auth_protocol"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_priv_passphrase" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_priv_passphrase"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_priv_protocol" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_priv_protocol"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_context" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_context"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_port" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_port"], $string);
-	$string = str_replace($l_escape_string . "host_snmp_timeout" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_timeout"], $string);
-	$string = str_replace($l_escape_string . "host_id" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["id"], $string);
+		$string = str_replace($l_escape_string . "host_management_ip" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["hostname"], $string); /* for compatability */
+		$string = str_replace($l_escape_string . "host_hostname" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["hostname"], $string);
+		$string = str_replace($l_escape_string . "host_description" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["description"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_community" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_community"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_version" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_version"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_username" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_username"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_password" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_password"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_auth_protocol" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_auth_protocol"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_priv_passphrase" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_priv_passphrase"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_priv_protocol" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_priv_protocol"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_context" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_context"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_port" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_port"], $string);
+		$string = str_replace($l_escape_string . "host_snmp_timeout" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["snmp_timeout"], $string);
+		$string = str_replace($l_escape_string . "host_ping_retries" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["ping_retries"], $string);
+		$string = str_replace($l_escape_string . "host_max_oids" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["max_oids"], $string);
+		$string = str_replace($l_escape_string . "host_id" . $r_escape_string, $_SESSION["sess_host_cache_array"][$host_id]["id"], $string);
+	}
 
 	return $string;
 }
@@ -209,4 +214,55 @@ function substitute_snmp_query_data($string, $host_id, $snmp_query_id, $snmp_ind
 	return $string;
 }
 
+/* substitute_data_input_data - takes a string and substitutes all data input variables contained in it
+   @arg $string - the original string that contains the data input variables
+   @arg $local_data_id - (int) the local data id to match
+   @arg $max_chars - the maximum number of characters to substitute
+   @returns - the original string with all of the variable substitutions made */
+function substitute_data_input_data($string, $graph, $local_data_id, $max_chars = 0) {
+	if (empty($local_data_id)) {
+		if (isset($graph['local_graph_id'])) {
+			$local_data_ids = array_rekey(db_fetch_assoc("SELECT DISTINCT local_data_id
+				FROM data_template_rrd
+				INNER JOIN graph_templates_item
+				ON data_template_rrd.id=graph_templates_item.task_item_id
+				WHERE local_graph_id=" . $graph["local_graph_id"]), "local_data_id", "local_data_id");
+
+			if (sizeof($local_data_ids)) {
+				$data_template_data_id = db_fetch_cell("SELECT id FROM data_template_data WHERE local_data_id IN (" . implode(",", $local_data_ids) . ")");
+			}else{
+				$data_template_data_id = 0;
+			}
+		}else{
+			$data_template_data_id = 0;
+		}
+	}else{
+		$data_template_data_id = db_fetch_cell("SELECT id FROM data_template_data WHERE local_data_id=$local_data_id");
+	}
+
+	if (!empty($data_template_data_id)) {
+		$data = db_fetch_assoc("SELECT
+			dif.data_name, did.value
+			FROM data_input_fields AS dif
+			INNER JOIN data_input_data AS did
+			ON dif.id=did.data_input_field_id
+			WHERE data_template_data_id=$data_template_data_id
+			AND input_output='in'");
+
+		if (sizeof($data)) {
+			foreach ($data as $item) {
+				if ($item["value"] != "") {
+					if ($max_chars > 0) {
+						$item["value"] = substr($item["field_value"], 0, $max_chars);
+					}
+
+					$string = stri_replace("|input_" . $item["data_name"] . "|", $item["value"], $string);
+				}
+			}
+		}
+	}
+
+	return $string;
+}
+
 ?>
