@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -24,16 +24,26 @@
 
 include("./include/auth.php");
 
+api_plugin_hook('logout_pre_session_destroy');
+
 /* Clear session */
 setcookie(session_name(),"",time() - 3600,"/");
+session_destroy();
+
+api_plugin_hook('logout_post_session_destroy');
 
 /* Check to see if we are using Web Basic Auth */
 if (read_config_option("auth_method") == "2") {
+	if (api_plugin_hook_function('custom_logout_message', OPER_MODE_NATIVE) == OPER_MODE_RESKIN) {
+		exit;
+	}
 
 	?>
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
 <head>
 	<title>Logout of Cacti</title>
+	<meta http-equiv="Content-Type" content="text/html;charset=utf-8">
 	<STYLE TYPE="text/css">
 	<!--
 		BODY, TABLE, TR, TD {font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 12px;}
@@ -57,7 +67,7 @@ if (read_config_option("auth_method") == "2") {
 		<?php
 
 }else{
-        /* Default action */
+	/* Default action */
 	header("Location: index.php");
 	exit;
 }
