@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -28,29 +28,6 @@ include_once("./lib/export.php");
 /* set default action */
 if (!isset($_REQUEST["action"])) { $_REQUEST["action"] = ""; }
 
-$export_types = array(
-	"graph_template" => array(
-		"name" => "Graph Template",
-		"title_sql" => "select name from graph_templates where id=|id|",
-		"dropdown_sql" => "select id,name from graph_templates order by name"
-		),
-	"data_template" => array(
-		"name" => "Data Template",
-		"title_sql" => "select name from data_template where id=|id|",
-		"dropdown_sql" => "select id,name from data_template order by name"
-		),
-	"host_template" => array(
-		"name" => "Host Template",
-		"title_sql" => "select name from host_template where id=|id|",
-		"dropdown_sql" => "select id,name from host_template order by name"
-		),
-	"data_query" => array(
-		"name" => "Data Query",
-		"title_sql" => "select name from snmp_query where id=|id|",
-		"dropdown_sql" => "select id,name from snmp_query order by name"
-		)
-	);
-
 switch ($_REQUEST["action"]) {
 	case 'save':
 		form_save();
@@ -70,9 +47,14 @@ switch ($_REQUEST["action"]) {
    -------------------------- */
 
 function form_save() {
-	global $export_types;
+	global $export_types, $export_errors;
+
+    /* ================= input validation ================= */
+    input_validate_input_number(get_request_var_post("export_item_id"));
+    /* ==================================================== */
 
 	if (isset($_POST["save_component_export"])) {
+		$export_errors = 0;
 		$xml_data = get_item_xml($_POST["export_type"], $_POST["export_item_id"], (((isset($_POST["include_deps"]) ? $_POST["include_deps"] : "") == "") ? false : true));
 
 		if ($_POST["output_format"] == "1") {
@@ -81,11 +63,16 @@ function form_save() {
 			include_once("./include/bottom_footer.php");
 		}elseif ($_POST["output_format"] == "2") {
 			header("Content-type: application/xml");
+			if ($export_errors) echo "WARNING: Export Errors Encountered.  Refresh Browser Window for Details!\n";
 			print $xml_data;
 		}elseif ($_POST["output_format"] == "3") {
-			header("Content-type: application/xml");
-			header("Content-Disposition: attachment; filename=cacti_" . $_POST["export_type"] . "_" . strtolower(clean_up_file_name(db_fetch_cell(str_replace("|id|", $_POST["export_item_id"], $export_types{$_POST["export_type"]}["title_sql"])))) . ".xml");
-			print $xml_data;
+			if ($export_errors) {
+				header("Location: templates_export.php");
+			}else{
+				header("Content-type: application/xml");
+				header("Content-Disposition: attachment; filename=cacti_" . $_POST["export_type"] . "_" . strtolower(clean_up_file_name(db_fetch_cell(str_replace("|id|", $_POST["export_item_id"], $export_types{$_POST["export_type"]}["title_sql"])))) . ".xml");
+				print $xml_data;
+			}
 		}
 	}
 }
@@ -103,16 +90,16 @@ function export() {
 	}
 
 	?>
-	<form name="form_graph_id">
+	<form name="form_graph_id" action="templates_export.php">
 	<table width='100%' style='background-color: #f5f5f5; border: 1px solid #bbbbbb;' align='center'>
-		<tr bgcolor="<?php print $colors["light"];?>">
+		<tr bgcolor="#<?php print $colors["light"];?>">
 			<td class="textArea" style="padding: 3px;">
 				What would you like to export?&nbsp;
 
 				<select name="cbo_graph_id" onChange="window.location=document.form_graph_id.cbo_graph_id.options[document.form_graph_id.cbo_graph_id.selectedIndex].value">
 					<?php
 					while (list($key, $array) = each($export_types)) {
-						print "<option value='templates_export.php?export_type=$key'"; if ($_REQUEST["export_type"] == $key) { print " selected"; } print ">" . $array["name"] . "</option>\n";
+						print "<option value='templates_export.php?export_type=" . htmlspecialchars($key) . "'"; if ($_REQUEST["export_type"] == $key) { print " selected"; } print ">" . $array["name"] . "</option>\n";
 					}
 					?>
 				</select>
@@ -156,16 +143,15 @@ function export() {
 			form_radio_button("output_format", "3", "1", "Output to the Browser (within Cacti)","1",true); print "<br>";
 			form_radio_button("output_format", "3", "2", "Output to the Browser (raw XML)","1",true); print "<br>";
 			form_radio_button("output_format", "3", "3", "Save File Locally","1",true);
+			form_hidden_box("export_type", $_REQUEST["export_type"], "");
+			form_hidden_box("save_component_export","1","");
 			?>
 		</td>
 	</tr>
 	<?php
 
-	form_hidden_box("export_type", $_REQUEST["export_type"], "");
-	form_hidden_box("save_component_export","1","");
-
 	html_end_box();
 
-	form_save_button("templates_export.php");
+	form_save_button("", "export");
 }
 ?>
