@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -87,6 +87,12 @@ switch ($_REQUEST["action"]) {
     The Save Function
    -------------------------- */
 function form_save() {
+
+	/* clear graph tree cache on save - affects current user only, other users should see changes in <5 minutes */
+	if (isset($_SESSION['dhtml_tree'])) {
+		unset($_SESSION['dhtml_tree']);
+	}
+
 	if (isset($_POST["save_component_tree"])) {
 		$save["id"] = $_POST["id"];
 		$save["name"] = form_input_validate($_POST["name"], "name", "", false, 3);
@@ -105,11 +111,7 @@ function form_save() {
 			}
 		}
 
-		if ((is_error_message()) || (empty($_POST["id"]))) {
-			header("Location: tree.php?action=edit&id=" . (empty($tree_id) ? $_POST["id"] : $tree_id));
-		}else{
-			header("Location: tree.php");
-		}
+		header("Location: tree.php?action=edit&id=" . (empty($tree_id) ? $_POST["id"] : $tree_id));
 	}elseif (isset($_POST["save_component_tree_item"])) {
 		$tree_item_id = api_tree_item_save($_POST["id"], $_POST["graph_tree_id"], $_POST["type"], $_POST["parent_item_id"],
 			(isset($_POST["title"]) ? $_POST["title"] : ""), (isset($_POST["local_graph_id"]) ? $_POST["local_graph_id"] : "0"),
@@ -139,7 +141,7 @@ function item_edit() {
 	/* ==================================================== */
 
 	if (!empty($_GET["id"])) {
-		$tree_item = db_fetch_row("select * from graph_tree_items where id=" . $_GET["id"]);
+		$tree_item = db_fetch_row("select * from graph_tree_items where id=" . get_request_var("id"));
 
 		if ($tree_item["local_graph_id"] > 0) { $db_type = TREE_ITEM_TYPE_GRAPH; }
 		if ($tree_item["title"] != "") { $db_type = TREE_ITEM_TYPE_HEADER; }
@@ -154,12 +156,12 @@ function item_edit() {
 		$current_type = TREE_ITEM_TYPE_HEADER;
 	}
 
-	$tree_sort_type = db_fetch_cell("select sort_type from graph_tree where id='" . $_GET["tree_id"] . "'");
-
-	html_start_box("<strong>Tree Items</strong>", "100%", $colors["header"], "3", "center", "");
+	$tree_sort_type = db_fetch_cell("select sort_type from graph_tree where id='" . get_request_var("tree_id") . "'");
 
 	print "<form method='post' action='tree.php' name='form_tree'>\n";
 
+	html_start_box("<strong>Tree Items</strong>", "100%", $colors["header"], "3", "center", "");
+
 	form_alternate_row_color($colors["form_alternate1"],$colors["form_alternate2"],0); ?>
 		<td width="50%">
 			<font class="textEditTitle">Parent Item</font><br>
@@ -249,7 +251,7 @@ function item_edit() {
 		<?php form_alternate_row_color($colors["form_alternate1"],$colors["form_alternate2"],1); ?>
 			<td width="50%">
 				<font class="textEditTitle">Round Robin Archive</font><br>
-				Choose a round robin archive to control how this graph is displayed.
+				Choose a round robin archive to control how the Graph Thumbnail is displayed when using Tree Export.
 			</td>
 			<td>
 				<?php form_dropdown("rra_id", db_fetch_assoc("select id,name from rra order by timespan"), "name", "id", (isset($tree_item["rra_id"]) ? $tree_item["rra_id"] : ""), "", "");?>
@@ -276,6 +278,15 @@ function item_edit() {
 				<?php form_dropdown("host_grouping_type", $host_group_types, "", "", (isset($tree_item["host_grouping_type"]) ? $tree_item["host_grouping_type"] : "1"), "", "");?>
 			</td>
 		</tr>
+		<?php form_alternate_row_color($colors["form_alternate1"],$colors["form_alternate2"],1); ?>
+			<td width="50%">
+				<font class="textEditTitle">Round Robin Archive</font><br>
+				Choose a round robin archive to control how Graph Thumbnails are displayed when using Tree Export.
+			</td>
+			<td>
+				<?php form_dropdown("rra_id", db_fetch_assoc("select id,name from rra order by timespan"), "name", "id", (isset($tree_item["rra_id"]) ? $tree_item["rra_id"] : ""), "", "");?>
+			</td>
+		</tr>
 		<?php
 		break;
 	}
@@ -301,6 +312,12 @@ function item_moveup() {
 
 	$order_key = db_fetch_cell("SELECT order_key FROM graph_tree_items WHERE id=" . $_GET["id"]);
 	if ($order_key > 0) { branch_up($order_key, 'graph_tree_items', 'order_key', 'graph_tree_id=' . $_GET["tree_id"]); }
+
+	/* clear graph tree cache on save - affects current user only, other users should see changes in <5 minutes */
+	if (isset($_SESSION['dhtml_tree'])) {
+		unset($_SESSION['dhtml_tree']);
+	}
+
 }
 
 function item_movedown() {
@@ -311,6 +328,12 @@ function item_movedown() {
 
 	$order_key = db_fetch_cell("SELECT order_key FROM graph_tree_items WHERE id=" . $_GET["id"]);
 	if ($order_key > 0) { branch_down($order_key, 'graph_tree_items', 'order_key', 'graph_tree_id=' . $_GET["tree_id"]); }
+
+	/* clear graph tree cache on save - affects current user only, other users should see changes in <5 minutes */
+	if (isset($_SESSION['dhtml_tree'])) {
+		unset($_SESSION['dhtml_tree']);
+	}
+
 }
 
 function item_remove() {
@@ -319,7 +342,7 @@ function item_remove() {
 	input_validate_input_number(get_request_var("tree_id"));
 	/* ==================================================== */
 
-	if ((read_config_option("remove_verification") == "on") && (!isset($_GET["confirm"]))) {
+	if ((read_config_option("deletion_verification") == "on") && (!isset($_GET["confirm"]))) {
 		$graph_tree_item = db_fetch_row("select title,local_graph_id,host_id from graph_tree_items where id=" . $_GET["id"]);
 
 		if (!empty($graph_tree_item["local_graph_id"])) {
@@ -331,15 +354,20 @@ function item_remove() {
 		}
 
 		include("./include/top_header.php");
-		form_confirm("Are You Sure?", $text, "tree.php?action=edit&id=" . $_GET["tree_id"], "tree.php?action=item_remove&id=" . $_GET["id"] . "&tree_id=" . $_GET["tree_id"]);
+		form_confirm("Are You Sure?", $text, htmlspecialchars("tree.php?action=edit&id=" . $_GET["tree_id"]), htmlspecialchars("tree.php?action=item_remove&id=" . $_GET["id"] . "&tree_id=" . $_GET["tree_id"]));
 		include("./include/bottom_footer.php");
 		exit;
 	}
 
-	if ((read_config_option("remove_verification") == "") || (isset($_GET["confirm"]))) {
+	if ((read_config_option("deletion_verification") == "") || (isset($_GET["confirm"]))) {
 		delete_branch($_GET["id"]);
 	}
 
+	/* clear graph tree cache on save - affects current user only, other users should see changes in <5 minutes */
+	if (isset($_SESSION['dhtml_tree'])) {
+		unset($_SESSION['dhtml_tree']);
+	}
+
 	header("Location: tree.php?action=edit&id=" . $_GET["tree_id"]); exit;
 }
 
@@ -353,17 +381,23 @@ function tree_remove() {
 	input_validate_input_number(get_request_var("id"));
 	/* ==================================================== */
 
-	if ((read_config_option("remove_verification") == "on") && (!isset($_GET["confirm"]))) {
+	if ((read_config_option("deletion_verification") == "on") && (!isset($_GET["confirm"]))) {
 		include("./include/top_header.php");
-		form_confirm("Are You Sure?", "Are you sure you want to delete the tree <strong>'" . db_fetch_cell("select name from graph_tree where id=" . $_GET["id"]) . "'</strong>?", "tree.php", "tree.php?action=remove&id=" . $_GET["id"]);
+		form_confirm("Are You Sure?", "Are you sure you want to delete the tree <strong>'" . db_fetch_cell("select name from graph_tree where id=" . $_GET["id"]) . "'</strong>?", htmlspecialchars("tree.php"), htmlspecialchars("tree.php?action=remove&id=" . $_GET["id"]));
 		include("./include/bottom_footer.php");
 		exit;
 	}
 
-	if ((read_config_option("remove_verification") == "") || (isset($_GET["confirm"]))) {
+	if ((read_config_option("deletion_verification") == "") || (isset($_GET["confirm"]))) {
 		db_execute("delete from graph_tree where id=" . $_GET["id"]);
 		db_execute("delete from graph_tree_items where graph_tree_id=" . $_GET["id"]);
 	}
+
+	/* clear graph tree cache on save - affects current user only, other users should see changes in <5 minutes */
+	if (isset($_SESSION['dhtml_tree'])) {
+		unset($_SESSION['dhtml_tree']);
+	}
+
 }
 
 function tree_edit() {
@@ -380,7 +414,7 @@ function tree_edit() {
 
 	if (!empty($_GET["id"])) {
 		$tree = db_fetch_row("select * from graph_tree where id=" . $_GET["id"]);
-		$header_label = "[edit: " . $tree["name"] . "]";
+		$header_label = "[edit: " . htmlspecialchars($tree["name"]) . "]";
 	}else{
 		$header_label = "[new]";
 	}
@@ -395,12 +429,12 @@ function tree_edit() {
 	html_end_box();
 
 	if (!empty($_GET["id"])) {
-		html_start_box("<strong>Tree Items</strong>", "100%", $colors["header"], "3", "center", "tree.php?action=item_edit&tree_id=" . $tree["id"] . "&parent_id=0");
+		html_start_box("<strong>Tree Items</strong>", "100%", $colors["header"], "3", "center", "tree.php?action=item_edit&tree_id=" . htmlspecialchars($tree["id"]) . "&parent_id=0");
 
 		?>
 		<td>
-		<a href='tree.php?action=edit&id=<?php print $_GET["id"];?>&subaction=expand_all'><img src='images/button_expand_all.gif' border='0' alt='Expand All'></a>
-		<a href='tree.php?action=edit&id=<?php print $_GET["id"];?>&subaction=colapse_all'><img src='images/button_colapse_all.gif' border='0' alt='Colapse All'></a>
+		<input type='button' onClick='return document.location="tree.php?action=edit&id=<?php print htmlspecialchars(get_request_var("id"));?>&subaction=expand_all"' value='Expand All' title='Expand All Trees'>
+		<input type='button' onClick='return document.location="tree.php?action=edit&id=<?php print htmlspecialchars(get_request_var("id"));?>&subaction=collapse_all"' value='Collapse All' title='Collapse All Trees'></a>
 		</td>
 		<?php
 
@@ -414,7 +448,7 @@ function tree_edit() {
 		html_end_box();
 	}
 
-	form_save_button("tree.php");
+	form_save_button("tree.php", "return");
 }
 
 function tree() {
@@ -435,10 +469,10 @@ function tree() {
 		form_alternate_row_color($colors["alternate"],$colors["light"],$i); $i++;
 			?>
 			<td>
-				<a class="linkEditMain" href="tree.php?action=edit&id=<?php print $tree["id"];?>"><?php print $tree["name"];?></a>
+				<a class="linkEditMain" href="<?php print htmlspecialchars("tree.php?action=edit&id=" . $tree["id"]);?>"><?php print htmlspecialchars($tree["name"]);?></a>
 			</td>
 			<td align="right">
-				<a href="tree.php?action=remove&id=<?php print $tree["id"];?>"><img src="images/delete_icon.gif" width="10" height="10" border="0" alt="Delete"></a>
+				<a href="<?php print htmlspecialchars("tree.php?action=remove&id=" . $tree["id"]);?>"><img src="images/delete_icon.gif" style="height:10px;width:10px;" border="0" alt="Delete"></a>
 			</td>
 		</tr>
 	<?php
