@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2008 The Cacti Group                                 |
+ | Copyright (C) 2004-2012 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -34,6 +34,9 @@ $user_actions = array(
 	5 => "Batch Copy"
 	);
 
+/* remember the tab we came from */
+load_current_session_value("tab", "sess_user_admin_tab", "user_realms_edit");
+
 switch (get_request_var_request("action")) {
 	case 'actions':
 		form_actions();
@@ -47,24 +50,6 @@ switch (get_request_var_request("action")) {
 		perm_remove();
 		break;
 
-	case 'user_realms_edit':
-		include_once("include/top_header.php");
-		user_edit();
-		include_once("include/bottom_footer.php");
-		break;
-
-	case 'graph_settings_edit':
-		include_once("include/top_header.php");
-		user_edit();
-		include_once("include/bottom_footer.php");
-		break;
-
-	case 'graph_perms_edit':
-		include_once("include/top_header.php");
-		user_edit();
-		include_once("include/bottom_footer.php");
-		break;
-
 	case 'user_edit':
 		include_once("include/top_header.php");
 		user_edit();
@@ -72,9 +57,11 @@ switch (get_request_var_request("action")) {
 		break;
 
 	default:
-		include_once("include/top_header.php");
-		user();
-		include_once("include/bottom_footer.php");
+		if (!api_plugin_hook_function('user_admin_action', get_request_var_request("action"))) {
+			include_once("include/top_header.php");
+			user();
+			include_once("include/bottom_footer.php");
+		}
 		break;
 }
 
@@ -98,6 +85,8 @@ function form_actions() {
 				/* ==================================================== */
 
 				user_remove($selected_items[$i]);
+
+				api_plugin_hook_function('user_remove', $selected_items[$i]);
 			}
 		}
 
@@ -171,7 +160,6 @@ function form_actions() {
 			}
 		}
 
-
 		header("Location: user_admin.php");
 		exit;
 	}
@@ -181,7 +169,7 @@ function form_actions() {
 	$user_array = array();
 	$i = 0;
 	while (list($var,$val) = each($_POST)) {
-		if (ereg("^chk_([0-9]+)$", $var, $matches)) {
+		if (preg_match("/^chk_([0-9]+)$/", $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
@@ -190,9 +178,19 @@ function form_actions() {
 				$user_list .= "<li>" . db_fetch_cell("SELECT username FROM user_auth WHERE id=" . $matches[1]) . "<br>";
 			}
 			$user_array[$i] = $matches[1];
-		}
 
-		$i++;
+			$i++;
+		}
+	}
+
+	/* Check for deleting of Graph Export User */
+	if ((get_request_var_post("drp_action") == "1") && isset($user_array) && sizeof($user_array)) { /* delete */
+		$exportuser = read_config_option('export_user_id');
+		if (in_array($exportuser, $user_array)) {
+			raise_message(22);
+			header("Location: user_admin.php");
+			exit;
+		}
 	}
 
 	include_once("./include/top_header.php");
@@ -201,93 +199,96 @@ function form_actions() {
 
 	print "<form action='user_admin.php' method='post'>\n";
 
-	if ((get_request_var_post("drp_action") == "1") && (sizeof($user_array))) { /* delete */
-		print "
-			<tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					<p>Are you sure you want to delete the following users?</p>
-					<p>$user_list</p>
-				</td>
-			</tr>\n";
-	}
-	$user_id = "";
-	if ((get_request_var_post("drp_action") == "2") && (sizeof($user_array))) { /* copy */
-		$user_id = $user_array[0];
-		$user_realm = db_fetch_cell("SELECT realm FROM user_auth WHERE id = " . $user_id);
+	if (isset($user_array) && sizeof($user_array)) {
+		if ((get_request_var_post("drp_action") == "1") && (sizeof($user_array))) { /* delete */
+			print "
+				<tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						<p>When you click \"Continue\", the selected User(s) will be deleted.</p>
+						<p><ul>$user_list</ul></p>
+					</td>
+				</tr>\n";
+			$save_html = "<input type='button' value='Cancel' onClick='window.history.back()'>&nbsp;<input type='submit' value='Continue' title='Delete User(s)'>";
+		}
+		$user_id = "";
 
-		print "
-			<tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					Would you like to copy this user?<br><br>
-				</td>
-			</tr><tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					Template Username: <i>" . db_fetch_cell("SELECT username FROM user_auth WHERE id=" . $user_id) . "</i>
-				</td>
-			</tr><tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-				New Username: ";
-		print form_text_box("new_username", "", "", 25);
-		print "				</td>
-			</tr><tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					New Full Name: ";
-		print form_text_box("new_fullname", "", "", 35);
-		print "				</td>
-			</tr><tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					New Realm: \n";
-		print form_dropdown("new_realm", $auth_realms, "", "", $user_realm, "", 0);
-		print "				</td>
+		if ((get_request_var_post("drp_action") == "2") && (sizeof($user_array))) { /* copy */
+			$user_id = $user_array[0];
+			$user_realm = db_fetch_cell("SELECT realm FROM user_auth WHERE id = " . $user_id);
 
-			</tr>\n";
-	}
+			print "
+				<tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						When you click \"Continue\" the selected User will be copied to the new User below<br><br>
+					</td>
+				</tr><tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						Template Username: <i>" . db_fetch_cell("SELECT username FROM user_auth WHERE id=" . $user_id) . "</i>
+					</td>
+				</tr><tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+					New Username: ";
+			print form_text_box("new_username", "", "", 25);
+			print "				</td>
+				</tr><tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						New Full Name: ";
+			print form_text_box("new_fullname", "", "", 35);
+			print "				</td>
+				</tr><tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						New Realm: \n";
+			print form_dropdown("new_realm", $auth_realms, "", "", $user_realm, "", 0);
+			print "				</td>
 
-	if ((get_request_var_post("drp_action") == "3") && (sizeof($user_array))) { /* enable */
-		print "
-			<tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					<p>Are you sure you want to enable the following users?</p>
-					<p>$user_list</p>
-				</td>
-			</tr>\n";
-	}
+				</tr>\n";
+			$save_html = "<input type='button' value='Cancel' onClick='window.history.back()'>&nbsp;<input type='submit' value='Continue' title='Copy User'>";
+		}
 
-	if ((get_request_var_post("drp_action") == "4") && (sizeof($user_array))) { /* disable */
-		print "
-			<tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					<p>Are you sure you want to disable the following users?</p>
-					<p>$user_list</p>
-				</td>
-			</tr>\n";
-	}
+		if ((get_request_var_post("drp_action") == "3") && (sizeof($user_array))) { /* enable */
+			print "
+				<tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						<p>When you click \"Continue\" the selected User(s) will be enabled.</p>
+						<p><ul>$user_list</ul></p>
+					</td>
+				</tr>\n";
+			$save_html = "<input type='button' value='Cancel' onClick='window.history.back()'>&nbsp;<input type='submit' value='Continue' title='Enable User(s)'>";
+		}
 
-	if ((get_request_var_post("drp_action") == "5") && (sizeof($user_array))) { /* batch copy */
-		$usernames = db_fetch_assoc("SELECT id,username FROM user_auth WHERE realm = 0 ORDER BY username");
-		print "
-			<tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>Are you sure you want to overwrite the selected users with the selected template users settings and permissions?  Original user Full Name, Password, Realm and Enable status will be retained, all other fields will be overwritten from template user.<br><br></td>
-			</tr><tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					Template User: \n";
-		print form_dropdown("template_user", $usernames, "username", "id", "", "", 0);
-		print "		</td>
+		if ((get_request_var_post("drp_action") == "4") && (sizeof($user_array))) { /* disable */
+			print "
+				<tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						<p>When you click \"Continue\" the selected User(s) will be disabled.</p>
+						<p><ul>$user_list</ul></p>
+					</td>
+				</tr>\n";
+			$save_html = "<input type='button' value='Cancel' onClick='window.history.back()'>&nbsp;<input type='submit' value='Continue' title='Disable User(s)'>";
+		}
 
-			</tr><tr>
-				<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
-					<p>Users to update:
-					$user_list</p>
-				</td>
-			</tr>\n";
-	}
-
-	if (sizeof($user_array) == 0) {
-		print "<tr><td bgcolor='#" . $colors["form_alternate1"]. "'><span class='textError'>You must select at least one user.</span></td></tr>\n";
-		$save_html = "<a href='user_admin.php'><img src='images/button_cancel.gif' alt='Cancel' align='absmiddle' border='0'></a>";
+		if ((get_request_var_post("drp_action") == "5") && (sizeof($user_array))) { /* batch copy */
+			$usernames = db_fetch_assoc("SELECT id,username FROM user_auth WHERE realm = 0 ORDER BY username");
+			print "
+				<tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>When you click \"Continue\" you will overwrite selected the User(s) settings with the selected template User settings and permissions?  Original user Full Name, Password, Realm and Enable status will be retained, all other fields will be overwritten from Template User.<br><br></td>
+				</tr><tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						Template User: \n";
+			print form_dropdown("template_user", $usernames, "username", "id", "", "", 0);
+			print "		</td>
 
+				</tr><tr>
+					<td class='textArea' bgcolor='#" . $colors["form_alternate1"] . "'>
+						<p>User(s) to update:
+						<ul>$user_list</ul></p>
+					</td>
+				</tr>\n";
+			$save_html = "<input type='button' value='Cancel' onClick='window.history.back()'>&nbsp;<input type='submit' value='Continue' title='Reset User(s) Settings'>";
+		}
 	}else{
-		$save_html = "<a href='user_admin.php'><img src='images/button_no.gif' alt='Cancel' align='absmiddle' border='0'></a> <input type='image' src='images/button_yes.gif' alt='Save' align='absmiddle'>";
+		print "<tr><td bgcolor='#" . $colors["form_alternate1"]. "'><span class='textError'>You must select at least one user.</span></td></tr>\n";
+		$save_html = "<input type='button' value='Return' onClick='window.history.back()'>";
 	}
 
 	print " <tr>
@@ -307,10 +308,8 @@ function form_actions() {
 	html_end_box();
 
 	include_once("./include/bottom_footer.php");
-
 }
 
-
 /* --------------------------
     Save Function
    -------------------------- */
@@ -334,22 +333,22 @@ function form_save() {
 
 		$add_button_clicked = false;
 
-		if (isset($_POST["add_graph_y"])) {
+		if (isset($_POST["add_graph_x"])) {
 			db_execute("REPLACE INTO user_auth_perms (user_id,item_id,type) VALUES (" . get_request_var_post("id") . "," . get_request_var_post("perm_graphs") . ",1)");
 			$add_button_clicked = true;
-		}elseif (isset($_POST["add_tree_y"])) {
+		}elseif (isset($_POST["add_tree_x"])) {
 			db_execute("REPLACE INTO user_auth_perms (user_id,item_id,type) VALUES (" . get_request_var_post("id") . "," . get_request_var_post("perm_trees") . ",2)");
 			$add_button_clicked = true;
-		}elseif (isset($_POST["add_host_y"])) {
+		}elseif (isset($_POST["add_host_x"])) {
 			db_execute("REPLACE INTO user_auth_perms (user_id,item_id,type) VALUES (" . get_request_var_post("id") . "," . get_request_var_post("perm_hosts") . ",3)");
 			$add_button_clicked = true;
-		}elseif (isset($_POST["add_graph_template_y"])) {
+		}elseif (isset($_POST["add_graph_template_x"])) {
 			db_execute("REPLACE INTO user_auth_perms (user_id,item_id,type) VALUES (" . get_request_var_post("id") . "," . get_request_var_post("perm_graph_templates") . ",4)");
 			$add_button_clicked = true;
 		}
 
 		if ($add_button_clicked == true) {
-			header("Location: user_admin.php?action=graph_perms_edit&id=" . get_request_var_post("id"));
+			header("Location: user_admin.php?action=user_edit&tab=graph_perms_edit&id=" . get_request_var_post("id"));
 			exit;
 		}
 	}
@@ -407,6 +406,7 @@ function form_save() {
 		$save["policy_graph_templates"] = form_input_validate(get_request_var_post("policy_graph_templates", get_request_var_post("_policy_graph_templates")), "policy_graph_templates", "", true, 3);
 		$save["realm"] = get_request_var_post("realm", 0);
 		$save["enabled"] = form_input_validate(get_request_var_post("enabled", ""), "enabled", "", true, 3);
+		$save = api_plugin_hook_function('user_admin_setup_sql_save', $save);
 
 		if (!is_error_message()) {
 			$user_id = sql_save($save, "user_auth");
@@ -421,9 +421,9 @@ function form_save() {
 				db_execute("DELETE FROM user_auth_realm WHERE user_id = " . $user_id);
 
 				while (list($var, $val) = each($_POST)) {
-					if (eregi("^[section]", $var)) {
+					if (preg_match("/^[section]/i", $var)) {
 						if (substr($var, 0, 7) == "section") {
-						    db_execute("REPLACE INTO user_auth_realm (user_id,realm_id) VALUES (" . $user_id . "," . substr($var, 7) . ")");
+							db_execute("REPLACE INTO user_auth_realm (user_id,realm_id) VALUES (" . $user_id . "," . substr($var, 7) . ")");
 						}
 					}
 				}
@@ -449,16 +449,14 @@ function form_save() {
 					policy_hosts = " . get_request_var_post("policy_hosts") . ",
 					policy_graph_templates = " . get_request_var_post("policy_graph_templates") . "
 					WHERE id = " . get_request_var_post("id"));
+			} else {
+				api_plugin_hook('user_admin_user_save');
 			}
 		}
 	}
 
 	/* redirect to the appropriate page */
-	if (is_error_message()) {
-		header("Location: user_admin.php?action=user_edit&id=" . (empty($user_id) ? $_POST["id"] : $user_id));
-	}else{
-		header("Location: user_admin.php");
-	}
+	header("Location: user_admin.php?action=user_edit&id=" . (empty($user_id) ? $_POST["id"] : $user_id));
 }
 
 /* --------------------------
@@ -481,7 +479,7 @@ function perm_remove() {
 		db_execute("DELETE FROM user_auth_perms WHERE type = 4 AND user_id=" . get_request_var("user_id") . " and item_id = " . get_request_var("id"));
 	}
 
-	header("Location: user_admin.php?action=graph_perms_edit&id=" . get_request_var("user_id"));
+	header("Location: user_admin.php?action=user_edit&tab=graph_perms_edit&id=" . get_request_var("user_id"));
 }
 
 function graph_perms_edit() {
@@ -499,6 +497,13 @@ function graph_perms_edit() {
 		$policy = db_fetch_row("SELECT policy_graphs,policy_trees,policy_hosts,policy_graph_templates FROM user_auth WHERE id = " . get_request_var("id"));
 
 		$header_label = "[edit: " . db_fetch_cell("SELECT username FROM user_auth WHERE id = " . get_request_var("id")) . "]";
+	} else {
+		$policy = array(
+			'policy_graphs' => '1', 
+			'policy_trees'  => '1', 
+			'policy_hosts'  => '1', 
+			'policy_graph_templates' => '1'
+		);
 	}
 
 	?>
@@ -525,7 +530,6 @@ function graph_perms_edit() {
 
 	?>
 	<form method="post" action="user_admin.php">
-
 	<tr bgcolor="#<?php print $colors["form_alternate1"];?>">
 		<td width="50%">
 			<font class="textEditTitle">Default Policy</font><br>
@@ -545,7 +549,7 @@ function graph_perms_edit() {
 					$i++;
 					print "	<tr>
 							<td><span style='font-weight: bold; color: " . (($policy["policy_graphs"] == "1") ? "red" : "blue") . ";'>$i)</span> " . $item["title_cache"] . "</td>
-							<td align='right'><a href='user_admin.php?action=perm_remove&type=graph&id=" . $item["local_graph_id"] . "&user_id=" . $_GET["id"] . "'><img src='images/delete_icon.gif' width='10' height='10' border='0' alt='Delete'></a>&nbsp;</td>
+							<td align='right'><a href='" . htmlspecialchars("user_admin.php?action=perm_remove&type=graph&id=" . $item["local_graph_id"] . "&user_id=" . $_GET["id"]) . "'><img src='images/delete_icon.gif' style='height:10px;width:10px;' border='0' alt='Delete'></a>&nbsp;</td>
 						</tr>\n";
 				}
 				}else{ print "<tr><td><em>No Graphs</em></td></tr>";
@@ -562,10 +566,10 @@ function graph_perms_edit() {
 	<table align='center' width='100%'>
 		<tr>
 			<td nowrap>Add Graph:&nbsp;
-				<?php form_dropdown("perm_graphs",db_fetch_assoc("SELECT local_graph_id,title_cache FROM graph_templates_graph WHERE local_graph_id > 0 ORDER BY title_cache"),"title_cache","local_graph_id","","","");?>
+				<?php form_dropdown("perm_graphs",db_fetch_assoc("SELECT local_graph_id, title_cache FROM graph_templates_graph WHERE local_graph_id > 0 AND local_graph_id NOT IN (SELECT item_id FROM user_auth_perms WHERE user_auth_perms.type=1 AND user_auth_perms.user_id=".get_request_var("id",0).") ORDER BY title_cache"),"title_cache","local_graph_id","","","");?>
 			</td>
 			<td align="right">
-				&nbsp;<input type="image" src="images/button_add.gif" alt="Add" name="add_graph" align="absmiddle">
+				&nbsp;<input type="submit" value="Add" name="add_graph_x" title="Add New Graph Permission">
 			</td>
 		</tr>
 	</table>
@@ -603,7 +607,7 @@ function graph_perms_edit() {
 						$i++;
 						print "	<tr>
 							<td><span style='font-weight: bold; color: " . (($policy["policy_hosts"] == "1") ? "red" : "blue") . ";'>$i)</span> " . $item["name"] . "</td>
-							<td align='right'><a href='user_admin.php?action=perm_remove&type=host&id=" . $item["id"] . "&user_id=" . $_GET["id"] . "'><img src='images/delete_icon.gif' width='10' height='10' border='0' alt='Delete'></a>&nbsp;</td>
+							<td align='right'><a href='" . htmlspecialchars("user_admin.php?action=perm_remove&type=host&id=" . $item["id"] . "&user_id=" . $_GET["id"]) . "'><img src='images/delete_icon.gif' style='height:10px;width:10px;' border='0' alt='Delete'></a>&nbsp;</td>
 						</tr>\n";
 					}
 				}else{
@@ -622,10 +626,10 @@ function graph_perms_edit() {
 	<table align='center' width='100%'>
 		<tr>
 			<td nowrap>Add Host:&nbsp;
-				<?php form_dropdown("perm_hosts",db_fetch_assoc("SELECT id,CONCAT('',description,' (',hostname,')') AS name FROM host ORDER BY description,hostname"),"name","id","","","");?>
+				<?php form_dropdown("perm_hosts",db_fetch_assoc("SELECT id, CONCAT('',description,' (',hostname,')') AS name FROM host WHERE host.id NOT IN (SELECT item_id FROM user_auth_perms WHERE user_auth_perms.type=3 AND user_auth_perms.user_id=".get_request_var("id",0).") ORDER BY description,hostname"),"name","id","","","");?>
 			</td>
 			<td align="right">
-				&nbsp;<input type="image" src="images/button_add.gif" alt="Add" name="add_host" align="absmiddle">
+				&nbsp;<input type="submit" value="Add" name="add_host_x" title="Add New Host Permission">
 			</td>
 		</tr>
 	</table>
@@ -663,7 +667,7 @@ function graph_perms_edit() {
 					$i++;
 					print "	<tr>
 							<td><span style='font-weight: bold; color: " . (($policy["policy_graph_templates"] == "1") ? "red" : "blue") . ";'>$i)</span> " . $item["name"] . "</td>
-							<td align='right'><a href='user_admin.php?action=perm_remove&type=graph_template&id=" . $item["id"] . "&user_id=" . $_GET["id"] . "'><img src='images/delete_icon.gif' width='10' height='10' border='0' alt='Delete'></a>&nbsp;</td>
+							<td align='right'><a href='" . htmlspecialchars("user_admin.php?action=perm_remove&type=graph_template&id=" . $item["id"] . "&user_id=" . $_GET["id"]) . "'><img src='images/delete_icon.gif' style='height:10px;width:10px;' border='0' alt='Delete'></a>&nbsp;</td>
 						</tr>\n";
 				}
 				}else{ print "<tr><td><em>No Graph Templates</em></td></tr>";
@@ -681,10 +685,10 @@ function graph_perms_edit() {
 	<table align='center' width='100%'>
 		<tr>
 			<td nowrap>Add Graph Template:&nbsp;
-				<?php form_dropdown("perm_graph_templates",db_fetch_assoc("SELECT id,name FROM graph_templates ORDER BY name"),"name","id","","","");?>
+				<?php form_dropdown("perm_graph_templates",db_fetch_assoc("SELECT id, name FROM graph_templates WHERE id NOT IN (SELECT item_id FROM user_auth_perms WHERE user_auth_perms.type=4 AND user_auth_perms.user_id=".get_request_var("id",0).") ORDER BY name"),"name","id","","","");?>
 			</td>
 			<td align="right">
-				&nbsp;<input type="image" src="images/button_add.gif" alt="Add" name="add_graph_template" align="absmiddle">
+				&nbsp;<input type="submit" value="Add" name="add_graph_template_x" title="Add New Graph Template Permission">
 			</td>
 		</tr>
 	</table>
@@ -722,7 +726,7 @@ function graph_perms_edit() {
 					$i++;
 					print "	<tr>
 							<td><span style='font-weight: bold; color: " . (($policy["policy_trees"] == "1") ? "red" : "blue") . ";'>$i)</span> " . $item["name"] . "</td>
-							<td align='right'><a href='user_admin.php?action=perm_remove&type=tree&id=" . $item["id"] . "&user_id=" . $_GET["id"] . "'><img src='images/delete_icon.gif' width='10' height='10' border='0' alt='Delete'></a>&nbsp;</td>
+							<td align='right'><a href='" . htmlspecialchars("user_admin.php?action=perm_remove&type=tree&id=" . $item["id"] . "&user_id=" . $_GET["id"]) . "'><img src='images/delete_icon.gif' style='height:10px;width:10px;' border='0' alt='Delete'></a>&nbsp;</td>
 						</tr>\n";
 				}
 				}else{ print "<tr><td><em>No Trees</em></td></tr>";
@@ -740,10 +744,10 @@ function graph_perms_edit() {
 	<table align='center' width='100%'>
 		<tr>
 			<td nowrap>Add Tree:&nbsp;
-				<?php form_dropdown("perm_trees",db_fetch_assoc("SELECT id,name FROM graph_tree ORDER BY name"),"name","id","","","");?>
+				<?php form_dropdown("perm_trees",db_fetch_assoc("SELECT id, name FROM graph_tree WHERE id NOT IN (SELECT item_id FROM user_auth_perms WHERE user_auth_perms.type=2 AND user_auth_perms.user_id=".get_request_var("id",0)." ) ORDER BY name"),"name","id","","","");?>
 			</td>
 			<td align="right">
-				&nbsp;<input type="image" src="images/button_add.gif" alt="Add" name="add_tree" align="absmiddle">
+				&nbsp;<input type="submit" value="Add" name="add_tree_x" title="Add New Tree Permission">
 			</td>
 		</tr>
 	</table>
@@ -837,7 +841,7 @@ function graph_settings_edit() {
 
 	while (list($tab_short_name, $tab_fields) = each($settings_graphs)) {
 		?>
-		<tr bgcolor='<?php print $colors["header_panel"];?>'>
+		<tr bgcolor='#<?php print $colors["header_panel"];?>'>
 			<td colspan='2' class='textSubHeaderDark' style='padding: 3px;'>
 				<?php print $tabs_graphs[$tab_short_name];?>
 			</td>
@@ -899,6 +903,8 @@ function user_edit() {
 		$header_label = "[new]";
 	}
 
+	api_plugin_hook_function('user_admin_edit', (isset($user) ? get_request_var("id") : 0));
+
 	html_start_box("<strong>User Management</strong> $header_label", "100%", $colors["header"], "3", "center", "");
 
 	draw_edit_form(array(
@@ -914,34 +920,37 @@ function user_edit() {
 		<table class='tabs' width='100%' cellspacing='0' cellpadding='3' align='center'>
 			<tr>
 				<td width='1'></td>
-				<td <?php print (((get_request_var("action") == "user_realms_edit") || (get_request_var("action") == "user_edit")) ? "bgcolor='silver'" : "bgcolor='#DFDFDF'");?> nowrap='nowrap' width='150' align='center' class='tab'>
-					<span class='textHeader'><a href='user_admin.php?action=user_realms_edit&id=<?php print $_GET["id"];?>'>Realm Permissions</a></span>
+				<td <?php print ((get_request_var_request("tab") == "user_realms_edit") ? "bgcolor='silver'" : "bgcolor='#DFDFDF'");?> nowrap='nowrap' width='150' align='center' class='tab'>
+					<span class='textHeader'><a href='<?php print htmlspecialchars("user_admin.php?action=user_edit&tab=user_realms_edit&id=" . $_GET["id"]);?>'>Realm Permissions</a></span>
 				</td>
 				<td width='1'></td>
-				<td <?php print ((get_request_var("action") == "graph_perms_edit") ? "bgcolor='silver'" : "bgcolor='#DFDFDF'");?> nowrap='nowrap' width='150' align='center' class='tab'>
-					<span class='textHeader'><a href='user_admin.php?action=graph_perms_edit&id=<?php print $_GET["id"];?>'>Graph Permissions</a></span>
+				<td <?php print ((get_request_var_request("tab") == "graph_perms_edit") ? "bgcolor='silver'" : "bgcolor='#DFDFDF'");?> nowrap='nowrap' width='150' align='center' class='tab'>
+					<span class='textHeader'><a href='<?php print htmlspecialchars("user_admin.php?action=user_edit&tab=graph_perms_edit&id=" . $_GET["id"]);?>'>Graph Permissions</a></span>
 				</td>
 				<td width='1'></td>
-				<td <?php print ((get_request_var("action") == "graph_settings_edit") ? "bgcolor='silver'" : "bgcolor='#DFDFDF'");?> nowrap='nowrap' width='130' align='center' class='tab'>
-					<span class='textHeader'><a href='user_admin.php?action=graph_settings_edit&id=<?php print $_GET["id"];?>'>Graph Settings</a></span>
+				<td <?php print ((get_request_var_request("tab") == "graph_settings_edit") ? "bgcolor='silver'" : "bgcolor='#DFDFDF'");?> nowrap='nowrap' width='130' align='center' class='tab'>
+					<span class='textHeader'><a href='<?php print htmlspecialchars("user_admin.php?action=user_edit&tab=graph_settings_edit&id=" . $_GET["id"]);?>'>Graph Settings</a></span>
 				</td>
+				<?php api_plugin_hook('user_admin_tab');?>				
 				<td></td>
 			</tr>
 		</table>
 		<?php
 	}
 
-	if (get_request_var("action") == "graph_settings_edit") {
+	if (get_request_var_request("tab") == "graph_settings_edit") {
 		graph_settings_edit();
-	}elseif (get_request_var("action") == "user_realms_edit") {
+	}elseif (get_request_var_request("tab") == "user_realms_edit") {
 		user_realms_edit();
-	}elseif (get_request_var("action") == "graph_perms_edit") {
+	}elseif (get_request_var_request("tab") == "graph_perms_edit") {
 		graph_perms_edit();
 	}else{
-		user_realms_edit();
+		if (api_plugin_hook_function('user_admin_run_action', get_request_var_request("tab"))) {
+			user_realms_edit();
+		}
 	}
 
-	form_save_button("user_admin.php");
+	form_save_button("user_admin.php", "return");
 }
 
 function user() {
@@ -987,17 +996,42 @@ function user() {
 
 	html_start_box("<strong>User Management</strong>", "100%", $colors["header"], "3", "center", "user_admin.php?action=user_edit");
 
-	include("./include/html/inc_user_admin_filter_table.php");
+	?>
+	<tr bgcolor="#<?php print $colors["panel"];?>">
+		<td>
+		<form name="form_user_admin" action="user_admin.php">
+			<table width="100%" cellpadding="0" cellspacing="0">
+				<tr>
+					<td nowrap style='white-space: nowrap;' width="50">
+						Search:&nbsp;
+					</td>
+					<td width="1">
+						<input type="text" name="filter" size="40" value="<?php print htmlspecialchars(get_request_var_request("filter"));?>">
+					</td>
+					<td nowrap style='white-space: nowrap;'>
+						&nbsp;<input type="submit" value="Go" title="Set/Refresh Filters">
+						<input type="submit" name="clear_x" value="Clear" title="Clear Filters">
+					</td>
+				</tr>
+			</table>
+			<input type='hidden' name='page' value='1'>
+		</form>
+		</td>
+	</tr>
+	<?php
 
 	html_end_box();
 
 	/* form the 'where' clause for our main sql query */
-	if (strlen($_REQUEST["filter"])) {
+	if (strlen(get_request_var_request("filter"))) {
 		$sql_where = "WHERE (user_auth.username LIKE '%" . get_request_var_request("filter") . "%' OR user_auth.full_name LIKE '%" . get_request_var_request("filter") . "%')";
 	}else{
 		$sql_where = "";
 	}
 
+	/* print checkbox form for validation */
+	print "<form name='chk' method='post' action='user_admin.php'>\n";
+
 	html_start_box("", "100%", $colors["header"], "3", "center", "");
 
 	$total_rows = db_fetch_cell("SELECT
@@ -1029,13 +1063,13 @@ function user() {
 			<table width='100%' cellspacing='0' cellpadding='0' border='0'>
 				<tr>
 					<td align='left' class='textHeaderDark'>
-						<strong>&lt;&lt; "; if (get_request_var_request("page") > 1) { $nav .= "<a class='linkOverDark' href='user_admin.php?filter=" . get_request_var_request("filter") . "&page=" . (get_request_var_request("page") - 1) . "'>"; } $nav .= "Previous"; if (get_request_var_request("page") > 1) { $nav .= "</a>"; } $nav .= "</strong>
+						<strong>&lt;&lt; "; if (get_request_var_request("page") > 1) { $nav .= "<a class='linkOverDark' href='" . htmlspecialchars("user_admin.php?filter=" . get_request_var_request("filter") . "&page=" . (get_request_var_request("page") - 1)) . "'>"; } $nav .= "Previous"; if (get_request_var_request("page") > 1) { $nav .= "</a>"; } $nav .= "</strong>
 					</td>\n
 					<td align='center' class='textHeaderDark'>
 						Showing Rows " . ((read_config_option("num_rows_device") * (get_request_var_request("page") - 1)) + 1) . " to " . ((($total_rows < read_config_option("num_rows_device")) || ($total_rows < (read_config_option("num_rows_device") * get_request_var_request("page")))) ? $total_rows : (read_config_option("num_rows_device") * get_request_var_request("page"))) . " of $total_rows [$url_page_select]
 					</td>\n
 					<td align='right' class='textHeaderDark'>
-						<strong>"; if ((get_request_var_request("page") * read_config_option("num_rows_device")) < $total_rows) { $nav .= "<a class='linkOverDark' href='user_admin.php?filter=" . get_request_var_request("filter") . "&page=" . (get_request_var_request("page") + 1) . "'>"; } $nav .= "Next"; if ((get_request_var_request("page") * read_config_option("num_rows_device")) < $total_rows) { $nav .= "</a>"; } $nav .= " &gt;&gt;</strong>
+						<strong>"; if ((get_request_var_request("page") * read_config_option("num_rows_device")) < $total_rows) { $nav .= "<a class='linkOverDark' href='" . htmlspecialchars("user_admin.php?filter=" . get_request_var_request("filter") . "&page=" . (get_request_var_request("page") + 1)) . "'>"; } $nav .= "Next"; if ((get_request_var_request("page") * read_config_option("num_rows_device")) < $total_rows) { $nav .= "</a>"; } $nav .= " &gt;&gt;</strong>
 					</td>\n
 				</tr>
 			</table>
@@ -1052,8 +1086,7 @@ function user() {
 		"policy_graphs" => array("Default Graph Policy", "ASC"),
 		"dtime" => array("Last Login", "DESC"));
 
-	html_header_sort_checkbox($display_text, get_request_var_request("sort_column"), get_request_var_request("sort_direction"));
-
+	html_header_sort_checkbox($display_text, get_request_var_request("sort_column"), get_request_var_request("sort_direction"), false);
 
 	$i = 0;
 	if (sizeof($user_list) > 0) {
@@ -1070,10 +1103,10 @@ function user() {
 			}
 
 			form_alternate_row_color($colors["alternate"], $colors["light"], $i, 'line' . $user["id"]); $i++;
-			form_selectable_cell("<a class='linkEditMain' href='user_admin.php?action=user_edit&id=" . $user["id"] . "'>" .
-			(strlen(get_request_var_request("filter")) ? eregi_replace("(" . preg_quote(get_request_var_request("filter")) . ")", "<span style='background-color: #F8D93D;'>\\1</span>",  $user["username"]) : $user["username"])
+			form_selectable_cell("<a class='linkEditMain' href='" . htmlspecialchars("user_admin.php?action=user_edit&tab=user_realms_edit&id=" . $user["id"]) . "'>" .
+			(strlen(get_request_var_request("filter")) ? preg_replace("/(" . preg_quote(get_request_var_request("filter"), "/") . ")/i", "<span style='background-color: #F8D93D;'>\\1</span>",  htmlspecialchars($user["username"])) : htmlspecialchars($user["username"]))
 			, $user["id"]);
-			form_selectable_cell((strlen(get_request_var_request("filter")) ? eregi_replace("(" . preg_quote(get_request_var_request("filter")) . ")", "<span style='background-color: #F8D93D;'>\\1</span>",  $user["full_name"]) : $user["full_name"]), $user["id"]);
+			form_selectable_cell((strlen(get_request_var_request("filter")) ? preg_replace("/(" . preg_quote(get_request_var_request("filter"), "/") . ")/i", "<span style='background-color: #F8D93D;'>\\1</span>", htmlspecialchars($user["full_name"])) : htmlspecialchars($user["full_name"])), $user["id"]);
 			form_selectable_cell($enabled, $user["id"]);
 			form_selectable_cell($auth_realms[$user["realm"]], $user["id"]);
 			if ($user["policy_graphs"] == "1") {
@@ -1096,3 +1129,4 @@ function user() {
 
 }
 ?>
+
